@@ -35,13 +35,13 @@ export PYCXX=${WORKDIR}/Import/pycxx_${PYCXXVER}
 
 export MEINC_INSTALLER_DIR=${WORKDIR}/Import/MEINC_Installer
 export PYCHECKER_DIR=${WORKDIR}/Import/PyChecker
-for _DIR in ${WORKDIR}/../Extension/Source ${WORKDIR}/../pysvn/py${PYSVN_PY_VER}/Source
+for _DIR in ${WORKDIR}/../Extension/Source ${WORKDIR}/../py${PYSVN_PY_VER}_pysvn/Source
 do
-	if [ -e "${_DIR}" ]
-	then
-		export PYTHONPATH=$(cd ${_DIR};pwd)
-		export PYSVNLIB=$(cd ${_DIR};pwd)
-	fi
+    if [ -e "${_DIR}" ]
+    then
+        export PYTHONPATH=$(cd ${_DIR};pwd)
+        export PYSVNLIB=$(cd ${_DIR};pwd)
+    fi
 done
 unset _DIR
 ${PYTHON} -c "import sys;print 'Info: Python Version %r' % sys.version"
