@@ -3,12 +3,25 @@
 #
 import os
 
-print 'Info: setup_version_handling.py'
+print 'Info: setup version info'
 import sys
 sys.path.insert( 0, '../../Source')
 import wb_version
 import pysvn
 import time
+import subprocess
+
+
+proc = subprocess.Popen(
+            'uname -p',
+            shell=True,
+            close_fds=True,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT
+            )
+processor = proc.stdout.read().strip()
+rc = proc.wait()
 
 def os_system( cmd ):
     print 'Info: %s' % cmd
@@ -26,7 +39,7 @@ pysvn_version_string = '%d.%d.%d' % (pysvn.version[0], pysvn.version[1], pysvn.v
 svn_version_package_string = '%d%d%d' % (pysvn.svn_version[0], pysvn.svn_version[1], pysvn.svn_version[2])
 svn_version_string = '%d.%d.%d' % (pysvn.svn_version[0], pysvn.svn_version[1], pysvn.svn_version[2])
 
-pkg_filename = 'pysvn_workbench_svn%s-%s' % (svn_version_package_string, wb_version_string)
+pkg_filename = 'pysvn_workbench_svn%s-%s-%s' % (svn_version_package_string, wb_version_string, processor)
 print 'Info: Packageing %s' % pkg_filename
 build_time  = time.time()
 build_time_str = time.strftime( '%d-%b-%Y %H:%M', time.localtime( build_time ) )
@@ -46,7 +59,6 @@ for kit_dir in [
     if not os.path.exists( kit_dir ):
         os.makedirs( kit_dir )
 
-
 print 'Info: Copy files'
 for cp_src, cp_dst_dir_fmt in [
     ('../../LICENSE.txt',
