@@ -14,15 +14,27 @@ import sys
 import os
 import types
 import logging
-import tempfile
 import threading
 import inspect
 import gettext
+import locale
 
 import wx
 import wx.lib
 import wx.lib.newevent
 
+
+def checkTranslate(msg):
+    print "Warning: Switch translation of <%s> to U_!" % msg
+    return msg
+
+def noTranslate(msg):
+    return msg
+
+import __builtin__
+__builtin__.__dict__['T_'] = checkTranslate
+__builtin__.__dict__['U_'] = noTranslate
+
 import wb_frame
 import wb_preferences
 import wb_platform_specific
@@ -32,6 +44,7 @@ import wb_dialogs
 import wb_background_thread
 import wb_shell_commands
 import wb_subversion_report_revision_changes
+import wb_subversion_utils
 
 # 2.8 has the convenient ACCEL_CMD
 # on 2.6 we can add the feature
@@ -47,6 +60,17 @@ AppCallBackEvent, EVT_APP_CALLBACK = wx.lib.newevent.NewEvent()
 
 class WbApp(wx.App):
     def __init__( self, startup_dir, args ):
+        # Debug settings
+
+        # don't redirect IO into the log window
+        self.__debug_noredirect = '--noredirect' in args
+
+        # enable debug messages
+        self.__debug = '--debug' in args
+        self.__trace = '--trace' in args
+
+        self.__last_client_error = []
+
         self.args = args
         self.app_name = os.path.basename( args[0] )
         self.app_dir = os.path.dirname( args[0] )
@@ -60,18 +84,34 @@ class WbApp(wx.App):
 
         wb_platform_specific.setupPlatform()
 
+        self.setupLogging()
+        self.log.info( T_('Work Bench starting') )
+
+        # init the locale
+        self.initLocale()
+
+        if sys.platform == 'win32':
+            languages = [locale.getdefaultlocale()[0]]
+        else:
+            languages = [locale.getlocale()[0]]
+
         locale_path = wb_platform_specific.getLocalePath( self )
+
+        all_mofiles = gettext.find( 
+                'pysvn_workbench',
+                locale_path,
+                languages,
+                all=1 )
+
         self.translation = gettext.translation(
                 'pysvn_workbench',
                 locale_path,
-                # language defaults 
+                languages,
                 fallback=True )
 
-        import __builtin__
         __builtin__.__dict__['T_'] = self.translation.ugettext
         __builtin__.__dict__['S_'] = self.translation.ungettext
-        __builtin__.__dict__['U_'] = lambda s: s
-
+        # U_ is defined above for pre translation markup
 
         # --project <dir> automatically creates a project entry for <dir>
         # if <dir> is a subversion working copy and no project entry exists for it.
@@ -81,23 +121,15 @@ class WbApp(wx.App):
             if project_arg_index < len( args ) - 1:
                self.auto_project_dir = os.path.abspath( os.path.join( startup_dir, args[ project_arg_index+1 ] ) )
 
-        # Debug settings
+        # debug output for locale issue debugging
+        self.log.info( 'app_name %s' % (self.app_name,) )
+        self.log.info( 'app_dir %s' % (self.app_dir,) )
+        self.log.info( 'locale set to %r' % (locale.getlocale(),) )
+        self.log.info( 'locale_path %s' % (locale_path) )
+        self.log.info( 'languages %s' % (languages,) )
+        self.log.info( 'find %r' % (gettext.find( 'pysvn_workbench', locale_path, languages, all=1 ),) )
+        self.log.info( 'info %r' % (self.translation.info(),) )
 
-        # don't redirect IO into the log window
-        self.__debug_noredirect = '--noredirect' in args
-
-        # enable debug messages
-        self.__debug = '--debug' in args
-        self.__trace = '--trace' in args
-
-        self.__last_client_error = []
-
-        self.setupLogging()
-
-        self.log.info( 'app_name %s app_dir %s' % (self.app_name, self.app_dir) )
-        self.log.info( 'locale_path %s' % locale_path )
-        self.log.info( 'find %r' % gettext.find( 'pysvn_workbench', locale_path ) )
-        self.log.info( 'info %r' % self.translation.info() )
         self.log.info( T_('PySVN WorkBench') )
 
         if '--test' in args:
@@ -140,6 +172,79 @@ class WbApp(wx.App):
         'return true if the caller is running on the main thread'
         return self.main_thread is threading.currentThread()
 
+    # codes determined by:
+    # 1. System Preferences...
+    # 2. Language and Text
+    # 3. Drag lang to the top of the list
+    # 4. look in ~/.CFUserTextEncoding
+    _all_mac_locales = {
+        '0:0':  'en_GB.utf-8',
+        '0:3':  'de_DE.utf-8',
+        }
+
+    def initLocale( self ):
+        self.log.info( 'initLocale ----------------------------------------' )
+        # init the locale
+
+        if sys.platform == 'win32':
+            self.log.info( 'setlocale for windows' )
+            # on windows this will set to the default
+            locale.setlocale( locale.LC_ALL, '' )
+            return
+
+        if sys.platform == 'darwin':
+            # on Mac this will set to the default
+            # note: cannot find any docs on this to confirm its supported
+            if '__CF_USER_TEXT_ENCODING' in os.environ:
+                self.log.info( 'setlocale from __CF_USER_TEXT_ENCODING %s' % os.environ['__CF_USER_TEXT_ENCODING'] )
+                lang_code = os.environ['__CF_USER_TEXT_ENCODING'].split( ':', 1 )[1]
+                locale.setlocale( locale.LC_ALL, self._all_mac_locales.get( lang_code, '0:0' ) )
+                return
+
+        # generic Posix locale code
+        if 'LC_ALL' in os.environ:
+            try:
+                self.log.info( 'setlocale from LC_ALL %s' % os.environ['LC_ALL'] )
+                locale.setlocale( locale.LC_ALL, os.environ['LC_ALL'] )
+                return
+
+            except locale.Error, e:
+                self.log.info( 'setlocale LC_ALL failed - %r' % (e,) )
+                pass
+
+        else:
+            self.log.info( 'LC_ALL is not set' )
+            for name in sorted( os.environ.keys() ):
+                self.log.info( 'Env %s=%s' % (name, os.environ[ name ]) )
+
+        language_code, encoding = locale.getdefaultlocale()
+        self.log.info( 'getdefaultlocale -> %s, %s' % (language_code, encoding) )
+        if language_code is None:
+            language_code = 'en_US'
+
+        if encoding is None:
+            encoding = 'UTF-8'
+        if encoding.lower() == 'utf':
+            encoding = 'UTF-8'
+
+
+        try:
+            # setlocale fails when params it does not understand are passed
+            self.log.info( 'setlocale language_code, encoding -> %s, %s' % (language_code, encoding) )
+            locale.setlocale( locale.LC_ALL, '%s.%s' % (language_code, encoding) )
+
+        except locale.Error, e:
+            self.log.info( 'setlocale language_code - %r' % (e,) )
+
+            try:
+                # force a locale that will work
+                self.log.info( 'setlocale set to en_US.UTF-8' )
+                locale.setlocale( locale.LC_ALL, 'en_US.UTF-8' )
+
+            except locale.Error, e:
+                self.log.info( 'setlocale set to en_US.UTF-8 - %r' % (e,) )
+                locale.setlocale( locale.LC_ALL, 'C' )
+
     def setupLogging( self ):
         self.log = logging.getLogger( 'WorkBench' )
         self.trace = logging.getLogger( 'WorkBench.Trace' )
@@ -172,8 +277,6 @@ class WbApp(wx.App):
             handler.setFormatter( formatter )
             self.trace.addHandler( handler )
 
-        self.log.info( T_('Work Bench starting') )
-
         self.log.debug( 'debug enabled' )
         self.trace.info( 'trace enabled' )
 
@@ -250,7 +353,7 @@ class WbApp(wx.App):
     def getPasteData( self ):
         return self.__paste_data
 
-    # called from wb_subversion_history to avoid circlar imports
+    # called from wb_subversion_history to avoid circular imports
     def showReportRevisionChangesFrame( self, project_info, changed_files, info1, info2 ):
         revision_changes_frame = wb_subversion_report_revision_changes.ReportRevisionChangesFrame(
                                     self, project_info,
@@ -563,3 +666,90 @@ class StdoutLogHandler(logging.Handler):
 
         except:
             self.handleError(record)
+
+#- QQQ -------------------------------------------------------------------------------
+# Locate a .mo file using the gettext strategy
+def find(log, domain, localedir=None, languages=None, all=0):
+    log.info( 'find( %r, %r, %r, %r )' % (domain, localedir, languages, all) )
+
+    # Get some reasonable defaults for arguments that were not supplied
+    if localedir is None:
+        localedir = _default_localedir
+    if languages is None:
+        languages = []
+        for envar in ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG'):
+            val = os.environ.get(envar)
+            if val:
+                languages = val.split(':')
+                break
+        if 'C' not in languages:
+            languages.append('C')
+    # now normalize and expand the languages
+    nelangs = []
+    for lang in languages:
+        for nelang in _expand_lang(log, lang):
+            if nelang not in nelangs:
+                nelangs.append(nelang)
+    # select a language
+    if all:
+        result = []
+    else:
+        result = None
+
+    log.info( 'find: nelangs %r' % (nelangs,) )
+
+    for lang in nelangs:
+        if lang == 'C':
+            break
+        mofile = os.path.join(localedir, lang, 'LC_MESSAGES', '%s.mo' % domain)
+        log.info( 'find: mofile %r' % (mofile,) )
+        if os.path.exists(mofile):
+            if all:
+                result.append(mofile)
+            else:
+                return mofile
+    return result
+
+def _expand_lang(log, locale):
+    from locale import normalize
+    locale = normalize(locale)
+    COMPONENT_CODESET   = 1 << 0
+    COMPONENT_TERRITORY = 1 << 1
+    COMPONENT_MODIFIER  = 1 << 2
+    # split up the locale into its base components
+    mask = 0
+    pos = locale.find('@')
+    if pos >= 0:
+        modifier = locale[pos:]
+        locale = locale[:pos]
+        mask |= COMPONENT_MODIFIER
+    else:
+        modifier = ''
+    pos = locale.find('.')
+    if pos >= 0:
+        codeset = locale[pos:]
+        locale = locale[:pos]
+        mask |= COMPONENT_CODESET
+    else:
+        codeset = ''
+    pos = locale.find('_')
+    if pos >= 0:
+        territory = locale[pos:]
+        locale = locale[:pos]
+        mask |= COMPONENT_TERRITORY
+    else:
+        territory = ''
+    language = locale
+    ret = []
+    for i in range(mask+1):
+        if not (i & ~mask):  # if all components for this combo exist ...
+            val = language
+            if i & COMPONENT_TERRITORY: val += territory
+            if i & COMPONENT_CODESET:   val += codeset
+            if i & COMPONENT_MODIFIER:  val += modifier
+            ret.append(val)
+    ret.reverse()
+    return ret
+
+
+
