@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2005-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2005-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -11,13 +11,13 @@
 
 '''
 import wx
-
+import string
 import wb_exceptions
 
 #
 # all dialog changes are recorded in the BookmarkProperties
 # object when the user clicks OK the changes are set into the
-# preferences. Cancel leaves the prefernces unchanged.
+# preferences. Cancel leaves the preferences unchanged.
 #
 class BookmarkProperties:
     def __init__( self, pi ):
@@ -25,14 +25,37 @@ class BookmarkProperties:
         self.wc_path = pi.wc_path
         self.menu_name = pi.menu_name
         self.menu_folder = pi.menu_folder
+        self.menu_folder2 = pi.menu_folder2
+        self.menu_folder3 = pi.menu_folder3
+
+        self.updated()
+
+    def updated( self ):
+        self.menu_list = _keyBookmarks( self )
+        while len( self.menu_list ) < 4:
+            self.menu_list.append( '' )
+
+def _keyBookmarks( a ):
+    k = []
+    if a.menu_folder != '':
+        k.append( a.menu_folder )
+    if a.menu_folder2 != '':
+        k.append( a.menu_folder2 )
+    if a.menu_folder3 != '':
+        k.append( a.menu_folder3 )
+    k.append( a.menu_name )
+
+    return k
 
 class BookmarkManageDialog(wx.Dialog):
-    COL_FOLDER = 0
-    COL_NAME = 1
-    COL_WC_PATH = 2
+    COL_MENU1 = 0
+    COL_MENU2 = 1
+    COL_MENU3 = 2
+    COL_MENU4 = 3
+    COL_WC_PATH = 4
 
     def __init__( self, parent, app, bookmark_prefs ):
-        wx.Dialog.__init__( self, parent, -1, "Manage Bookmarks" )
+        wx.Dialog.__init__( self, parent, -1, T_("Manage Bookmarks") )
         self.app = app
 
         self.bookmark_prefs = bookmark_prefs
@@ -47,11 +70,15 @@ class BookmarkManageDialog(wx.Dialog):
         self.g_sizer.AddGrowableCol( 1 )
 
         self.bookmark_list_ctrl = BookmarkListCtrl( self )
-        self.bookmark_list_ctrl.InsertColumn( self.COL_FOLDER, "Folder" )
-        self.bookmark_list_ctrl.InsertColumn( self.COL_NAME, "Bookmark Name" )
-        self.bookmark_list_ctrl.InsertColumn( self.COL_WC_PATH, "WC Path" )
-        self.bookmark_list_ctrl.SetColumnWidth( self.COL_FOLDER, 100 )
-        self.bookmark_list_ctrl.SetColumnWidth( self.COL_NAME, 200 )
+        self.bookmark_list_ctrl.InsertColumn( self.COL_MENU1, T_("Menu") )
+        self.bookmark_list_ctrl.InsertColumn( self.COL_MENU2, T_("Menu") )
+        self.bookmark_list_ctrl.InsertColumn( self.COL_MENU3, T_("Menu") )
+        self.bookmark_list_ctrl.InsertColumn( self.COL_MENU4, T_("Menu") )
+        self.bookmark_list_ctrl.InsertColumn( self.COL_WC_PATH, T_("WC Path") )
+        self.bookmark_list_ctrl.SetColumnWidth( self.COL_MENU1, 150 )
+        self.bookmark_list_ctrl.SetColumnWidth( self.COL_MENU2, 150 )
+        self.bookmark_list_ctrl.SetColumnWidth( self.COL_MENU3, 150 )
+        self.bookmark_list_ctrl.SetColumnWidth( self.COL_MENU4, 150 )
         self.bookmark_list_ctrl.SetColumnWidth( self.COL_WC_PATH, 600 )
 
         self.all_bookmark_props = [BookmarkProperties( self.bookmark_prefs.getBookmark( name ) )
@@ -63,14 +90,14 @@ class BookmarkManageDialog(wx.Dialog):
 
         self.bookmark_list_ctrl.SetItemCount( len( self.all_bookmark_props ) )
 
-        self.button_delete = wx.Button( self, wx.NewId(), " Delete " )
+        self.button_delete = wx.Button( self, wx.NewId(), T_(" Delete ") )
         self.button_delete.Enable( False )
 
-        self.button_props = wx.Button( self, wx.NewId(), " Properties " )
+        self.button_props = wx.Button( self, wx.NewId(), T_(" Properties ") )
         self.button_props.Enable( False )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, " OK " )
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, " Cancel " )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(" OK ") )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(" Cancel ") )
         self.button_ok.SetDefault()
 
         self.h_sizer1.Add( self.button_props, 0, wx.EXPAND|wx.WEST, 15)
@@ -105,22 +132,16 @@ class BookmarkManageDialog(wx.Dialog):
         wx.EVT_BUTTON( self, wx.ID_CANCEL, try_wrapper( self.OnCancel ) )
 
     def sortBookmarks( self ):
-        self.all_bookmark_props.sort( self.__cmpBookmarks )
-
-    def __cmpBookmarks( self, a, b ):
-        rc = cmp( a.menu_folder.lower(), b.menu_folder.lower() )
-        if rc == 0:
-            rc = cmp( a.menu_name.lower(), b.menu_name.lower() )
-        return rc
+        self.all_bookmark_props.sort( key=_keyBookmarks )
 
     def OnGetItemText( self, item, col ):
         props = self.all_bookmark_props[ item ]
-        if col == self.COL_NAME:
-            return props.menu_name
-        elif col == self.COL_FOLDER:
-            return props.menu_folder
+        if col in [self.COL_MENU1, self.COL_MENU2, self.COL_MENU3, self.COL_MENU4]:
+            return props.menu_list[ col ]
+
         elif col == self.COL_WC_PATH:
             return props.wc_path
+
         else:
             return ''
 
@@ -196,6 +217,8 @@ class BookmarkManageDialog(wx.Dialog):
         for props in self.all_bookmark_props:
             props.pi.menu_name = props.menu_name
             props.pi.menu_folder = props.menu_folder
+            props.pi.menu_folder2 = props.menu_folder2
+            props.pi.menu_folder3 = props.menu_folder3
 
     def getDeletedBookmarkList( self ):
         return self.bookmark_deleted_list
@@ -218,7 +241,7 @@ class BookmarkListCtrl(wx.ListCtrl):
 
 class BookmarkPropertiesDialog(wx.Dialog):
     def __init__( self, parent, app, props ):
-        wx.Dialog.__init__( self, parent, -1, "Bookmark Properties" )
+        wx.Dialog.__init__( self, parent, -1, T_("Bookmark Properties") )
 
         self.parent = parent
         self.app = app
@@ -227,42 +250,61 @@ class BookmarkPropertiesDialog(wx.Dialog):
         self.initControls()
 
     def initControls( self ):
+        all_menu_folders1 = set( [prop.menu_folder  for prop in self.parent.all_bookmark_props] )
+        all_menu_folders2 = set( [prop.menu_folder2 for prop in self.parent.all_bookmark_props] )
+        all_menu_folders3 = set( [prop.menu_folder3 for prop in self.parent.all_bookmark_props] )
+
+        all_menu_folders = set()
+        all_menu_folders |= all_menu_folders1
+        all_menu_folders |= all_menu_folders2
+        all_menu_folders |= all_menu_folders3
+        all_menu_folders = sorted( all_menu_folders, key=string.lower )
+
         self.v_sizer = wx.BoxSizer( wx.VERTICAL )
         self.h_sizer2 = wx.BoxSizer( wx.HORIZONTAL )
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.static_text1 = wx.StaticText( self, -1, "WC Path: ", style=wx.ALIGN_RIGHT)
         self.wc_path_ctrl = wx.TextCtrl( self, -1, self.props.wc_path, size=(500, -1), style=wx.TE_READONLY )
 
-        self.g_sizer.Add( self.static_text1, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
-        self.g_sizer.Add( self.wc_path_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.menu_folder1_ctrl = wx.ComboBox( self, -1, self.props.menu_folder,
+                                                style=wx.CB_DROPDOWN, choices=all_menu_folders,
+                                                size=(300, -1) )
+
+        self.menu_folder2_ctrl = wx.ComboBox( self, -1, self.props.menu_folder2,
+                                                style=wx.CB_DROPDOWN, choices=all_menu_folders,
+                                                size=(300, -1) )
+
+        self.menu_folder3_ctrl = wx.ComboBox( self, -1, self.props.menu_folder3,
+                                                style=wx.CB_DROPDOWN, choices=all_menu_folders,
+                                                size=(300, -1) )
 
-        self.static_text2 = wx.StaticText( self, -1, "Menu Name: ", style=wx.ALIGN_RIGHT)
         self.menu_name_ctrl = wx.TextCtrl( self, -1, self.props.menu_name, size=(300, -1) )
         self.menu_name_ctrl.SetFocus()
         self.menu_name_ctrl.SetSelection( -1, -1 )
 
+        self.static_text1 = wx.StaticText( self, -1, T_("WC Path: "), style=wx.ALIGN_RIGHT)
+        self.g_sizer.Add( self.static_text1, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.wc_path_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+
+        self.static_text3 = wx.StaticText( self, -1, T_("Menu1: "), style=wx.ALIGN_RIGHT)
+        self.g_sizer.Add( self.static_text3, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.menu_folder1_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+
+        self.static_text4 = wx.StaticText( self, -1, T_("Menu2: "), style=wx.ALIGN_RIGHT)
+        self.g_sizer.Add( self.static_text4, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.menu_folder2_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+
+        self.static_text5 = wx.StaticText( self, -1, T_("Menu3: "), style=wx.ALIGN_RIGHT)
+        self.g_sizer.Add( self.static_text5, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+        self.g_sizer.Add( self.menu_folder3_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
+
+        self.static_text2 = wx.StaticText( self, -1, T_("Menu Name: "), style=wx.ALIGN_RIGHT)
         self.g_sizer.Add( self.static_text2, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.menu_name_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
-        all_menu_folders = {}
-        for props in self.parent.all_bookmark_props:
-            all_menu_folders[ props.menu_folder ] = None
-
-        all_menu_folders = all_menu_folders.keys()
-        all_menu_folders.sort( lambda a, b: cmp( a.lower(), b.lower() ) )
-
-        self.static_text3 = wx.StaticText( self, -1, "Menu Folder: ", style=wx.ALIGN_RIGHT)
-        self.menu_folder_ctrl = wx.ComboBox( self, -1, self.props.menu_folder,
-                                                style=wx.CB_DROPDOWN, choices=all_menu_folders,
-                                                size=(300, -1) )
-
-        self.g_sizer.Add( self.static_text3, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
-        self.g_sizer.Add( self.menu_folder_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
-
-        self.button_ok = wx.Button( self, wx.ID_OK, " OK " )
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, " Cancel " )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(" OK ") )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(" Cancel ") )
         self.button_ok.SetDefault()
 
         self.h_sizer2.Add( (60, 20), 1, wx.EXPAND)
@@ -286,7 +328,10 @@ class BookmarkPropertiesDialog(wx.Dialog):
 
     def updateProps( self ):
         self.props.menu_name = self.menu_name_ctrl.GetValue()
-        self.props.menu_folder = self.menu_folder_ctrl.GetValue()
+        self.props.menu_folder = self.menu_folder1_ctrl.GetValue()
+        self.props.menu_folder2 = self.menu_folder2_ctrl.GetValue()
+        self.props.menu_folder3 = self.menu_folder3_ctrl.GetValue()
+        self.props.updated()
 
     def OnOk( self, event ):
         self.updateProps()
