@@ -13,10 +13,12 @@
 import wx
 import os
 import pysvn
+import wb_subversion_utils
 
 id_log_message_text = wx.NewId()
 id_last_log_message = wx.NewId()
 
+
 class DialogBuildingBlock(wx.Dialog):
     def __init__( self, parent, title ):
         wx.Dialog.__init__( self, parent, -1, title )
@@ -35,9 +37,9 @@ class DialogBuildingBlock(wx.Dialog):
         self.filename_list = None
         if self.add_filename_list_field:
             self.filename_list = wx.ListCtrl( self, -1, wx.DefaultPosition, wx.Size( 600, 200 ), wx.LC_REPORT|wx.NO_BORDER )
-            self.filename_list.InsertColumn( 0, "Status" )
+            self.filename_list.InsertColumn( 0, T_("Status") )
             self.filename_list.SetColumnWidth( 0, 50 )
-            self.filename_list.InsertColumn( 1, "Filename" )
+            self.filename_list.InsertColumn( 1, T_("Filename") )
             self.filename_list.SetColumnWidth( 1, 1000 )
 
             for index, _ in enumerate( self.all_filenames ):
@@ -51,11 +53,11 @@ class DialogBuildingBlock(wx.Dialog):
 
         self.force_checkbox_ctrl = None
         if self.add_force_field:
-            self.force_checkbox_ctrl = wx.CheckBox( self, -1, "Force" )
+            self.force_checkbox_ctrl = wx.CheckBox( self, -1, T_("Force") )
             self.force_checkbox_ctrl.SetValue( False )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, " OK " )
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, " Cancel " )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(" OK ") )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(" Cancel ") )
         self.button_ok.SetDefault()
 
         self.initExtraButtons()
@@ -129,7 +131,7 @@ class LogMessage(DialogBuildingBlock):
 
     def initExtraButtons( self ):
         if self.last_log_message_text is not None:
-            self.button_last_log_message = wx.Button( self, id_last_log_message, "Insert Last Message" )
+            self.button_last_log_message = wx.Button( self, id_last_log_message, T_("Insert Last Message") )
             self.button_last_log_message.Enable( len(self.last_log_message_text) > 0 )
             self.h_sizer.Add( self.button_last_log_message )
 
@@ -159,11 +161,11 @@ class GetCredentials(wx.Dialog):
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.border = wx.StaticBox( self, -1, 'Credentials' )
+        self.border = wx.StaticBox( self, -1, T_('Credentials') )
         self.box = wx.StaticBoxSizer( self.border, wx.VERTICAL )
         self.box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.username_label = wx.StaticText( self, -1, 'Username:' )
+        self.username_label = wx.StaticText( self, -1, T_('Username:') )
         self.username_ctrl = wx.TextCtrl( self, -1, username )
         self.username_ctrl.SetFocus()
         self.username_ctrl.SetSelection( -1, -1 )
@@ -171,20 +173,20 @@ class GetCredentials(wx.Dialog):
         self.g_sizer.Add( self.username_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.username_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
 
-        self.password_label = wx.StaticText(self, -1, 'Password:' )
+        self.password_label = wx.StaticText(self, -1, T_('Password:') )
         self.password_ctrl = wx.TextCtrl(self, -1, '', style=wx.TE_PASSWORD )
 
         self.g_sizer.Add( self.password_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.password_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
 
-        self.save_ctrl = wx.CheckBox( self, -1, "Always uses these credentials" )
+        self.save_ctrl = wx.CheckBox( self, -1, T_("Always uses these credentials") )
         self.save_ctrl.SetValue( may_save )
         self.g_sizer.Add( self.save_ctrl, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( (1, 1) )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (250, 20), 1, wx.EXPAND)
@@ -222,26 +224,26 @@ class GetCredentials(wx.Dialog):
 
 class GetServerTrust(wx.Dialog):
     def __init__( self, parent, realm, info_list, may_save ):
-        wx.Dialog.__init__( self, parent, -1, 'Trust server %s' % realm )
+        wx.Dialog.__init__( self, parent, -1, T_('Trust server %s') % realm )
 
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.border = wx.StaticBox( self, -1, 'Server Certificate' )
+        self.border = wx.StaticBox( self, -1, T_('Server Certificate') )
         self.box = wx.StaticBoxSizer( self.border, wx.VERTICAL )
         self.box.Add( self.g_sizer, 0, wx.EXPAND )
 
         for key, value in info_list:
             self.addRow( key, value )
 
-        self.save_ctrl = wx.CheckBox( self, -1, "Always trust this server" )
+        self.save_ctrl = wx.CheckBox( self, -1, T_("Always trust this server") )
         self.save_ctrl.SetValue( may_save )
         self.g_sizer.Add( self.save_ctrl, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( (1, 1) )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (250, 20), 1, wx.EXPAND)
@@ -285,23 +287,23 @@ class AddDialog(wx.Dialog):
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.add_border = wx.StaticBox( self, -1, 'Add' )
+        self.add_border = wx.StaticBox( self, -1, T_('Add') )
         self.add_box = wx.StaticBoxSizer( self.add_border, wx.VERTICAL )
         self.add_box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.filename_text = wx.StaticText( self, -1, 'From:' )
+        self.filename_text = wx.StaticText( self, -1, T_('From:') )
         self.filename_ctrl = wx.StaticText( self, -1, filename )
 
         self.g_sizer.Add( self.filename_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.filename_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
 
-        self.force_ctrl = wx.CheckBox( self, -1, 'Force Add' )
+        self.force_ctrl = wx.CheckBox( self, -1, T_('Force Add') )
         self.force_ctrl.SetValue( force )
         self.g_sizer.Add( self.force_ctrl, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( (1, 1) )
 
         if recursive is not None:
-            self.recursive_ctrl = wx.CheckBox( self, -1, 'Recursive Add' )
+            self.recursive_ctrl = wx.CheckBox( self, -1, T_('Recursive Add') )
             self.recursive_ctrl.SetValue( recursive )
             self.g_sizer.Add( self.recursive_ctrl, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
             self.g_sizer.Add( (1, 1) )
@@ -309,9 +311,9 @@ class AddDialog(wx.Dialog):
         else:
             self.recursive_ctrl = None
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
@@ -357,17 +359,17 @@ class RenameFile(wx.Dialog):
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.rename_border = wx.StaticBox( self, -1, 'Rename' )
+        self.rename_border = wx.StaticBox( self, -1, T_('Rename') )
         self.rename_box = wx.StaticBoxSizer( self.rename_border, wx.VERTICAL )
         self.rename_box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.old_filename_text = wx.StaticText( self, -1, 'From:' )
+        self.old_filename_text = wx.StaticText( self, -1, T_('From:') )
         self.old_filename_ctrl = wx.StaticText( self, -1, old_filename )
 
         self.g_sizer.Add( self.old_filename_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.old_filename_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
 
-        self.new_filename_text = wx.StaticText( self, -1, 'To:' )
+        self.new_filename_text = wx.StaticText( self, -1, T_('To:') )
         self.new_filename_ctrl = wx.TextCtrl( self, -1, old_filename )
         self.new_filename_ctrl.SetSelection( -1, -1 )
         self.new_filename_ctrl.SetFocus()
@@ -378,14 +380,14 @@ class RenameFile(wx.Dialog):
         if force is None:
             self.force_ctrl = None
         else:
-            self.force_ctrl = wx.CheckBox( self, -1, "Force rename" )
+            self.force_ctrl = wx.CheckBox( self, -1, T_("Force rename") )
             self.force_ctrl.SetValue( force )
             self.g_sizer.Add( self.force_ctrl, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
             self.g_sizer.Add( (1, 1) )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
@@ -431,17 +433,17 @@ class GetFilename(wx.Dialog):
         self.rename_box = wx.StaticBoxSizer( self.rename_border, wx.VERTICAL )
         self.rename_box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.new_filename_text = wx.StaticText( self, -1, 'Name:' )
-        self.new_filename_ctrl = wx.TextCtrl( self, -1, 'New Folder' )
+        self.new_filename_text = wx.StaticText( self, -1, T_('Name:') )
+        self.new_filename_ctrl = wx.TextCtrl( self, -1, T_('New Folder') )
         self.new_filename_ctrl.SetSelection( -1, -1 )
         self.new_filename_ctrl.SetFocus()
 
         self.g_sizer.Add( self.new_filename_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.new_filename_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
@@ -475,16 +477,16 @@ class NewFile(wx.Dialog):
     template_suffix = '.template'
 
     def __init__( self, parent, template_dir ):
-        wx.Dialog.__init__( self, parent, -1, 'New File' )
+        wx.Dialog.__init__( self, parent, -1, T_('New File') )
 
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.newfile_border = wx.StaticBox( self, -1, 'New File' )
+        self.newfile_border = wx.StaticBox( self, -1, T_('New File') )
         self.newfile_box = wx.StaticBoxSizer( self.newfile_border, wx.VERTICAL )
         self.newfile_box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.newfile_text = wx.StaticText( self, -1, 'New Filename:' )
+        self.newfile_text = wx.StaticText( self, -1, T_('New Filename:') )
         self.newfile_ctrl = wx.TextCtrl( self, -1, '' )
         self.newfile_ctrl.SetFocus()
         self.newfile_ctrl.SetSelection( -1, -1 )
@@ -499,16 +501,16 @@ class NewFile(wx.Dialog):
         except EnvironmentError:
             self.template_file_list = []
 
-        self.template_text = wx.StaticText( self, -1, 'Template:' )
+        self.template_text = wx.StaticText( self, -1, T_('Template:') )
         self.template_list = wx.Choice( self, -1, choices=self.template_file_list )
         self.template_list.SetSelection( 0 )
 
         self.g_sizer.Add( self.template_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.template_list, 0, wx.EXPAND|wx.ALL, 5 )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
@@ -546,32 +548,63 @@ class NewFile(wx.Dialog):
             return None
 
 class UpdateTo(wx.Dialog):
+    def __init__( self, parent, title ):
+        wx.Dialog.__init__( self, parent, -1, title )
 
-    def __init__( self, parent ):
-        wx.Dialog.__init__( self, parent, -1, T_('Update to') )
+        self.all_depth_types =  [(pysvn.depth.empty,        T_('Empty directory'))
+                               #,(pysvn.depth.exclude,      T_('Exclude (not used yet)'))
+                                ,(pysvn.depth.files,        T_('Children files only'))
+                                ,(pysvn.depth.immediates,   T_('Immediate children'))
+                                ,(pysvn.depth.unknown,      T_('Only already checked out descendants'))
+                                ,(pysvn.depth.infinity,     T_('All descendants (Full recursion)'))]
+
+        self.depth_enabled = wb_subversion_utils.version_info.has_depth
 
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.newfile_border = wx.StaticBox( self, -1, T_('Update to') )
-        self.newfile_box = wx.StaticBoxSizer( self.newfile_border, wx.VERTICAL )
+        self.revision_border = wx.StaticBox( self, -1, title )
+        self.revision_box = wx.StaticBoxSizer( self.revision_border, wx.VERTICAL )
 
         # Line 1: checkbox for head revision
-        self.force_checkbox_ctrl = wx.CheckBox( self, -1, T_("HEAD revision") )
-        self.force_checkbox_ctrl.SetValue( True )
+        self.head_checkbox_ctrl = wx.CheckBox( self, -1, T_("HEAD revision") )
+        self.head_checkbox_ctrl.SetValue( True )
 
-        self.newfile_box.Add( self.force_checkbox_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+        self.revision_box.Add( self.head_checkbox_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
 
         # Line 2: text entry for giving a revision no. manually
-        self.newfile_box.Add( self.g_sizer, 0, wx.EXPAND )
+        self.revision_box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.newfile_text = wx.StaticText( self, -1, T_('Revision:') )
-        self.newfile_ctrl = wx.TextCtrl( self, -1, '' )
-        self.newfile_ctrl.SetSelection( -1, -1 )
-        self.newfile_ctrl.Enable( False )
+        self.revision_text = wx.StaticText( self, -1, T_('Revision:') )
+        self.revision_ctrl = wx.TextCtrl( self, -1, '' )
+        self.revision_ctrl.SetSelection( -1, -1 )
+        self.revision_ctrl.Enable( False )
 
-        self.g_sizer.Add( self.newfile_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
-        self.g_sizer.Add( self.newfile_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+        self.g_sizer.Add( self.revision_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
+        self.g_sizer.Add( self.revision_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        if self.depth_enabled:
+            self.r_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
+            self.r_sizer.AddGrowableCol( 1 )
+    
+            self.recursive_border = wx.StaticBox( self, -1, T_('Apply on') )
+            self.recursive_box = wx.StaticBoxSizer( self.recursive_border, wx.VERTICAL )
+            
+            self.recursive_checkbox_ctrl = wx.CheckBox( self, -1, T_('Recursive (all)') )
+            self.recursive_checkbox_ctrl.SetValue( True )
+    
+            self.recursive_box.Add( self.recursive_checkbox_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+            self.recursive_box.Add( self.r_sizer, 0, wx.EXPAND )
+    
+            self.depth_text = wx.StaticText( self, -1, T_('Depth:') )
+            self.depth_ctrl = wx.Choice( self, -1, choices=[name for depth, name in self.all_depth_types] )
+            for index, (depth, name) in enumerate( self.all_depth_types ):
+                if depth == pysvn.depth.unknown:
+                    self.depth_ctrl.SetSelection( index )
+            self.depth_ctrl.Enable( False )
+    
+            self.r_sizer.Add( self.depth_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
+            self.r_sizer.Add( self.depth_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
 
         # Line 3: Ok/Cancel button
         self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
@@ -584,7 +617,9 @@ class UpdateTo(wx.Dialog):
         self.h_sizer_buttons.Add( self.button_cancel, 0, wx.EXPAND|wx.EAST, 2 )
 
         self.v_sizer = wx.BoxSizer( wx.VERTICAL )
-        self.v_sizer.Add( self.newfile_box, 0, wx.EXPAND|wx.ALL, 5 )
+        self.v_sizer.Add( self.revision_box, 0, wx.EXPAND|wx.ALL, 5 )
+        if self.depth_enabled:
+            self.v_sizer.Add( self.recursive_box, 0, wx.EXPAND|wx.ALL, 5 )
         self.v_sizer.Add( self.h_sizer_buttons, 0, wx.EXPAND|wx.ALL, 5 )
 
         self.SetAutoLayout( True )
@@ -598,45 +633,68 @@ class UpdateTo(wx.Dialog):
         wx.EVT_BUTTON( self, wx.ID_OK, self.OnOk )
         wx.EVT_BUTTON( self, wx.ID_CANCEL, self.OnCancel )
 
-        # Catch checkbox event
-        wx.EVT_CHECKBOX ( self, self.force_checkbox_ctrl.GetId(), self.cbClicked )
+        # Catch checkbox events
+        wx.EVT_CHECKBOX ( self, self.head_checkbox_ctrl.GetId(), self.onHeadRevisionClicked )
+        if self.depth_enabled:
+            wx.EVT_CHECKBOX ( self, self.recursive_checkbox_ctrl.GetId(), self.recursiveClicked )
+        
 
     def OnOk( self, event ):
         # Check revision value
-        if self.force_checkbox_ctrl.GetValue() == False:
-            sval = self.newfile_ctrl.GetValue()
-            if not sval.isdigit():
+        if not self.head_checkbox_ctrl.GetValue():
+            try:
+                val = int( self.revision_ctrl.GetValue() )
+                if val < 1:
+                    wx.MessageBox( T_('Please enter a revision number > 0!'),
+                                   style=wx.OK|wx.ICON_ERROR )
+                    return
+
+            except ValueError:
                 wx.MessageBox( T_('Please enter digits only!'),
-                               style=wx.OK|wx.ICON_ERROR );
-
+                                style=wx.OK|wx.ICON_ERROR )
                 return
-            if int(sval) < 1:
-                wx.MessageBox( T_('Please enter a revision number > 0!'),
-                               style=wx.OK|wx.ICON_ERROR );
 
-                return
         self.EndModal( wx.ID_OK )
 
     def OnCancel( self, event ):
         self.EndModal( wx.ID_CANCEL )
 
-    def cbClicked( self, event ):
-        if self.force_checkbox_ctrl.GetValue():
-            self.newfile_ctrl.Enable(False)
-        else:
-            self.newfile_ctrl.Enable(True)
+    def onHeadRevisionClicked( self, event ):
+        self.revision_ctrl.Enable( not self.head_checkbox_ctrl.GetValue() )
 
     def getRevision( self ):
-        if self.force_checkbox_ctrl.GetValue():
+        if self.head_checkbox_ctrl.GetValue():
             return pysvn.Revision( pysvn.opt_revision_kind.head )
         else:
-            rev = int(self.newfile_ctrl.GetValue())
+            rev = int( self.revision_ctrl.GetValue() )
             return pysvn.Revision( pysvn.opt_revision_kind.number, rev )
 
+    def getSvnDepth( self ):
+        if self.depth_enabled:
+            return (self.getRecursive(), self.getDepth( pysvn.depth.unknown ))
+        else:
+            return (True, None)
+
+    def recursiveClicked( self, event ):
+        self.depth_ctrl.Enable( not self.recursive_checkbox_ctrl.GetValue() )
+            
+    def getRecursive( self ):
+        return self.recursive_checkbox_ctrl.GetValue()
+
+    def getDepth( self, default ):
+        if self.recursive_checkbox_ctrl.GetValue():
+            return default
+        else:
+            return self.all_depth_types[ self.depth_ctrl.GetSelection() ][0]
+
 class CopyUrl(wx.Dialog):
-    def __init__( self, parent, title, copy_from_url, copy_to_url ):
+    def __init__( self, parent, app, title, copy_from_url, copy_to_url ):
         wx.Dialog.__init__( self, parent, -1, '%s %s' % (title, copy_from_url) )
 
+        self.app = app
+        self.copy_to_url = copy_to_url
+        p = self.app.prefs.getAdvanced()
+        self.arbitrary_path = p.arbitrary_tag_branch
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
@@ -644,17 +702,27 @@ class CopyUrl(wx.Dialog):
         self.copyurl_box = wx.StaticBoxSizer( self.copyurl_border, wx.VERTICAL )
         self.copyurl_box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.copy_from_label = wx.StaticText( self, -1, 'Copy From:' )
+        self.copy_from_label = wx.StaticText( self, -1, T_('Copy From:') )
         self.copy_from_value = wx.StaticText( self, -1, copy_from_url )
 
-        self.copy_to_label = wx.StaticText( self, -1, 'Copy To:' )
-        self.copy_to_root = wx.StaticText( self, -1, copy_to_url + '/' )
-        self.copy_to_leaf = wx.TextCtrl( self, -1, '' )
+        self.copy_to_label = wx.StaticText( self, -1, T_('Copy To:') )
+        if not self.arbitrary_path:
+            self.copy_to_root = wx.StaticText( self, -1, copy_to_url + '/' )
+            self.copy_to_leaf = wx.TextCtrl( self, -1, '', size=(300, -1) )
+        else:
+            # should place repos_root_URL as a static prefix
+            self.copy_to_browse = wx.StaticText( self, -1, '' )
+            self.copy_to_leaf = wx.TextCtrl( self, -1, copy_to_url + '/', size=(500, -1) )
+
         self.copy_to_leaf.SetFocus()
 
         self.h_sizer_copy_to = wx.BoxSizer( wx.HORIZONTAL )
-        self.h_sizer_copy_to.Add( self.copy_to_root, 0, wx.EXPAND|wx.EAST, 15 )
-        self.h_sizer_copy_to.Add( self.copy_to_leaf, 0, wx.EXPAND|wx.EAST, 2 )
+        if not self.arbitrary_path:
+            self.h_sizer_copy_to.Add( self.copy_to_root, 0, wx.EXPAND|wx.EAST, 15 )
+            self.h_sizer_copy_to.Add( self.copy_to_leaf, 0, wx.EXPAND|wx.EAST, 2 )
+        else:
+            self.h_sizer_copy_to.Add( self.copy_to_leaf, 1, wx.EXPAND|wx.EAST, 2 )
+            self.h_sizer_copy_to.Add( self.copy_to_browse, 0, wx.EXPAND|wx.EAST, 2 )
 
         self.g_sizer.Add( self.copy_from_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.copy_from_value, 0, wx.EXPAND|wx.ALL, 5 )
@@ -662,13 +730,13 @@ class CopyUrl(wx.Dialog):
         self.g_sizer.Add( self.copy_to_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.h_sizer_copy_to, 0, wx.EXPAND|wx.ALL, 5 )
 
-        self.label_ctrl = wx.StaticText( self, -1, 'Log message', style=wx.ALIGN_LEFT )
+        self.label_ctrl = wx.StaticText( self, -1, T_('Log message'), style=wx.ALIGN_LEFT )
         self.log_message_ctrl = wx.TextCtrl( self, -1, style=wx.TE_MULTILINE )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
         self.button_ok.Enable( False )
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
@@ -705,6 +773,12 @@ class CopyUrl(wx.Dialog):
 
     def OnCancel( self, event ):
         self.EndModal( wx.ID_CANCEL )
+    
+    def getCopyTo( self ):
+        if not self.arbitrary_path:
+            return '%s/%s' % (self.copy_to_url, self.copy_to_leaf.GetValue().strip())
+        else:
+            return self.copy_to_leaf.GetValue().strip()
 
     def getCopyToLeaf( self ):
         return self.copy_to_leaf.GetValue().strip()
@@ -713,9 +787,9 @@ class CopyUrl(wx.Dialog):
         return self.log_message_ctrl.GetValue()
 
 class CreateTag(CopyUrl):
-    def __init__( self, parent, copy_from_url, copy_to_url ):
-        CopyUrl.__init__( self, parent, 'Create Tag', copy_from_url, copy_to_url )
+    def __init__( self, parent, app, copy_from_url, copy_to_url ):
+        CopyUrl.__init__( self, parent, app, T_('Create Tag'), copy_from_url, copy_to_url )
 
 class CreateBranch(CopyUrl):
-    def __init__( self, parent, copy_from_url, copy_to_url ):
-        CopyUrl.__init__( self, parent, 'Create Branch', copy_from_url, copy_to_url )
+    def __init__( self, parent, app, copy_from_url, copy_to_url ):
+        CopyUrl.__init__( self, parent, app, T_('Create Branch'), copy_from_url, copy_to_url )
