@@ -46,21 +46,29 @@ class DiffFrame(wx.Frame):
         extra_style = 0
         if diff_prefs.maximized:
             extra_style = wx.MAXIMIZE
-        wx.Frame.__init__(self, None, -1, "Diff %s and %s" % (title_left, title_right),
+
+        wx.Frame.__init__(self, None, -1, T_("Diff %(title1)s and %(title2)s") %
+                            {'title1': title_left
+                            ,'title2': title_right},
                 diff_prefs.frame_position,
-                diff_prefs.frame_size,
+                diff_prefs.getFrameSize(),
                 wx.DEFAULT_FRAME_STYLE|extra_style )
 
+        # Reset the size after startup to workaround a potential
+        # problem on OSX with incorrect first size event saving the
+        # wrong size in the preferences
+        wx.CallAfter( self.SetSize, diff_prefs.getFrameSize() )
+
         # Set up the toolbar
         self.toolbar = self.CreateToolBar( wx.TB_HORIZONTAL|wx.NO_BORDER|wx.TB_FLAT )
 
-        self.toolbar.AddSimpleTool( id_expand_folds_command, wb_diff_images.getExpandBitmap(), "Expand folds", "Expand all folds" )
-        self.toolbar.AddSimpleTool( id_collapse_folds_command, wb_diff_images.getCollapseBitmap(), "Collapse folds", "Collapse all folds" )
+        self.toolbar.AddSimpleTool( id_expand_folds_command, wb_diff_images.getExpandBitmap(), T_("Expand folds"), T_("Expand all folds") )
+        self.toolbar.AddSimpleTool( id_collapse_folds_command, wb_diff_images.getCollapseBitmap(), T_("Collapse folds"), T_("Collapse all folds") )
         self.toolbar.AddSeparator()
-        self.toolbar.AddSimpleTool( id_whitespace_command, wb_diff_images.getWhiteSpaceBitmap(), "Toggle whitespace", "Show/hide whitespace" )
+        self.toolbar.AddSimpleTool( id_whitespace_command, wb_diff_images.getWhiteSpaceBitmap(), T_("Toggle whitespace"), T_("Show/hide whitespace") )
         self.toolbar.AddSeparator()
-        self.toolbar.AddSimpleTool( id_previous_command, wb_diff_images.getUpArrowBitmap(), "Previous difference", "Positions the cursor at the previous difference between the files" )
-        self.toolbar.AddSimpleTool( id_next_command, wb_diff_images.getDownArrowBitmap(), "Next difference", "Positions the cursor at the next difference between the files" )
+        self.toolbar.AddSimpleTool( id_previous_command, wb_diff_images.getUpArrowBitmap(), T_("Previous difference"), T_("Positions the cursor at the previous difference between the files") )
+        self.toolbar.AddSimpleTool( id_next_command, wb_diff_images.getDownArrowBitmap(), T_("Next difference"), T_("Positions the cursor at the next difference between the files") )
 
         self.toolbar.Realize()
 
@@ -80,10 +88,10 @@ class DiffFrame(wx.Frame):
         self.setChangeCounts( 0, 0 )
 
         self.status_bar_key_field = DiffBodyText( s )
-        self.status_bar_key_field.InsertStyledText( 'Key: ', self.status_bar_key_field.style_line_normal )
-        self.status_bar_key_field.InsertStyledText( 'Inserted text ', self.status_bar_key_field.style_line_insert )
-        self.status_bar_key_field.InsertStyledText( 'Deleted text ', self.status_bar_key_field.style_line_delete )
-        self.status_bar_key_field.InsertStyledText( 'Changed text', self.status_bar_key_field.style_line_changed )
+        self.status_bar_key_field.InsertStyledText( T_('Key: '), self.status_bar_key_field.style_line_normal )
+        self.status_bar_key_field.InsertStyledText( T_('Inserted text '), self.status_bar_key_field.style_line_insert )
+        self.status_bar_key_field.InsertStyledText( T_('Deleted text '), self.status_bar_key_field.style_line_delete )
+        self.status_bar_key_field.InsertStyledText( T_('Changed text'), self.status_bar_key_field.style_line_changed )
         self.status_bar_key_field.SetReadOnly( True )
         self.status_bar_key_field.Enable( False )
 
@@ -116,7 +124,7 @@ class DiffFrame(wx.Frame):
             return
 
         self.setChangeCounts( None, self.processor.getChangeCount() )
-        self.SetZoom(diff_prefs.zoom)
+        self.SetZoom( diff_prefs.zoom )
 
         # Move to the first change in the editor.
         event = wx.CommandEvent( wx.wxEVT_COMMAND_TOOL_CLICKED, id_next_command )
@@ -146,8 +154,8 @@ class DiffFrame(wx.Frame):
         wx.EVT_SIZE( self, self.OnFrameSize )
         wx.EVT_MOVE( self, self.OnFrameMove )
 
-        wx.stc.EVT_STC_ZOOM(self, self.panel_left.ed.GetId(), self.OnZoomChange)
-        wx.stc.EVT_STC_ZOOM(self, self.panel_right.ed.GetId(), self.OnZoomChange)
+        wx.stc.EVT_STC_ZOOM( self, self.panel_left.ed.GetId(), self.OnZoomChange )
+        wx.stc.EVT_STC_ZOOM( self, self.panel_right.ed.GetId(), self.OnZoomChange )
 
 
     def isOk( self ):
@@ -171,7 +179,9 @@ class DiffFrame(wx.Frame):
         if total_change_number is not None:
             self.total_change_number = total_change_number
 
-        self.SetStatusText( 'Diff %d of %d' % (self.current_change_number, self.total_change_number), 2 )
+        self.SetStatusText( T_('Diff %(change1)d of %(change2)d') %
+                                {'change1': self.current_change_number
+                                ,'change2': self.total_change_number}, 2 )
 
     def _repositionStatusBar(self):
         rect = self.GetStatusBar().GetFieldRect( 1 )
@@ -179,8 +189,6 @@ class DiffFrame(wx.Frame):
         self.status_bar_key_field.SetSize(wx.Size(rect.width-4, rect.height-4))
 
     #------------------------------------------------------------
-
-
     def OnCloseWindow( self, event ):
         diff_prefs = self.app.prefs.getDiffWindow()
         # Size and Position are already saved
@@ -199,16 +207,22 @@ class DiffFrame(wx.Frame):
         event.Skip()
 
     def OnFrameSize( self, event ):
-        self.app.prefs.getDiffWindow().frame_size = event.GetSize()
+        pref = self.app.prefs.getDiffWindow()
+        if not self.IsMaximized():
+            pref.setFrameSize( self.GetSize() )
+
         event.Skip()
 
     def OnFrameMove( self, event ):
+        pref = self.app.prefs.getDiffWindow()
         if not self.IsMaximized() and not self.IsIconized():
             # don't use the event.GetPosition() as it
             # is off by the window frame thinkness
             pt = self.GetPosition()
-            self.app.prefs.getDiffWindow().frame_position = pt
-        self.app.prefs.getDiffWindow().is_maximized = self.IsMaximized()
+            pref.frame_position = pt
+
+        pref.maximized = self.IsMaximized()
+
         event.Skip()
 
     def OnToolDownArrow( self, event ):
@@ -237,19 +251,21 @@ class DiffFrame(wx.Frame):
         self.panel_left.ed.ShowAllFolds( show )
         self.panel_right.ed.ShowAllFolds( show )
 
-    def OnZoomChange(self, evt):
+    def OnZoomChange( self, evt ):
         zoom = evt.GetEventObject().GetZoom()
-        self.SetZoom(zoom)
+        self.SetZoom( zoom )
         diff_prefs = self.app.prefs.getDiffWindow()
         diff_prefs.zoom = zoom
         
-    def SetZoom(self, zoom):
+    def SetZoom( self, zoom ):
         if zoom != self.panel_left.ed.GetZoom():
-            self.panel_left.ed.SetZoom(zoom)
+            self.panel_left.ed.SetZoom( zoom )
+
         if zoom != self.panel_right.ed.GetZoom():
-            self.panel_right.ed.SetZoom(zoom)
-        self.panel_left.ed.diff_line_numbers.SetZoom(zoom)
-        self.panel_right.ed.diff_line_numbers.SetZoom(zoom)
+            self.panel_right.ed.SetZoom( zoom )
+
+        self.panel_left.ed.diff_line_numbers.SetZoom( zoom )
+        self.panel_right.ed.diff_line_numbers.SetZoom( zoom )
             
 #----------------------------------------------------------------------
 
