@@ -22,11 +22,20 @@ if not hasattr(sys, 'frozen'):
     import wxversion
     wxversion.select( ['2.6', '2.8'] )
 
+def noTranslate(msg):
+    return msg
+
+import __builtin__
+__builtin__.__dict__['T_'] = noTranslate
+__builtin__.__dict__['U_'] = noTranslate
+
 import wx
 import wb_diff_frame
 import wb_preferences
 import wb_platform_specific
 
+
+
 class WbDiffApp:
     def __init__( self ):
         self.log = self
