@@ -26,6 +26,7 @@ import wb_preferences_dialog
 import wb_source_control_providers
 import wb_platform_specific
 import wb_bookmarks_dialogs
+import wb_toolbars
 
 import wb_config
 
@@ -49,13 +50,13 @@ class WbFrame(wx.Frame):
 
         wx.Frame.__init__(self, None, -1, title,
                 win_prefs.frame_position,
-                win_prefs.frame_size,
+                win_prefs.getFrameSize(),
                 wx.DEFAULT_FRAME_STYLE|extra_style )
 
         # Reset the size after startup to workaround a potential
         # problem on OSX with incorrect first size event saving the
-        # wrong size in teh preferences
-        wx.CallAfter(self.SetSize, win_prefs.frame_size)
+        # wrong size in the preferences
+        wx.CallAfter( self.SetSize, win_prefs.getFrameSize() )
         
         self.menu_edit = wx.Menu()
         self.menu_edit.Append( wb_ids.id_SP_EditCopy, T_("&Copy"), T_("Copy Files") )
@@ -99,8 +100,9 @@ class WbFrame(wx.Frame):
         self.menu_actions.Append( wb_ids.id_SP_Properties, T_('Properties...'), T_('Properties...') )
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Update, T_('Update'), T_('Update') )
-        self.menu_actions.Append( wb_ids.id_SP_Update_To, T_('Update to...'), T_('Update to...') )
+        self.menu_actions.Append( wb_ids.id_SP_UpdateTo, T_('Update to...'), T_('Update to...') )
         self.menu_actions.Append( wb_ids.id_SP_Checkout, T_('Checkout'), T_('Checkout') )
+        self.menu_actions.Append( wb_ids.id_SP_CheckoutTo, T_('Checkout to...'), T_('Checkout to...') )
         self.menu_actions.AppendSeparator()
         self.menu_actions.Append( wb_ids.id_SP_Checkin, T_('Checkin...'), T_('Checkin...') )
         self.menu_actions.AppendSeparator()
@@ -145,10 +147,11 @@ class WbFrame(wx.Frame):
         self.menu_view.AppendCheckItem( wb_ids.id_View_AutoRefresh, T_("&Automatic Refresh"), T_("Automatic refresh") )
 
 
-
-        self.all_bookmark_ids = {}
+        self.bookmark_menu_tree = BookmarkMenu('')
+        self.all_bookmarks_id_to_pi = {}
         self.all_bookmark_top_level_menu_ids = []
         self.all_bookmark_folders = {}
+        self.all_bookmark_folders2 = {}
 
         self.menu_bookmarks = wx.Menu()
         self.menu_bookmarks.Append( wb_ids.id_Bookmark_Add, T_('Add'), T_('Add Bookmark') )
@@ -182,93 +185,21 @@ class WbFrame(wx.Frame):
         # Set the application icon
         self.SetIcon( wb_images.getIcon( 'wb.png') )
 
-        # Add tool bar
-        t = self.CreateToolBar( name="main",
-                                style=wx.TB_HORIZONTAL ) # | wx.NO_BORDER | wx.TB_TEXT )
-
-        bitmap_size = (32, 32)
-        t.SetToolBitmapSize( bitmap_size )
-        t.AddSimpleTool( wb_ids.id_SP_EditCut,
-            wb_images.getBitmap( 'toolbar_images/editcut.png', bitmap_size ),
-            T_('Cut Files and Folders'), T_('Cut Files and Folders') )
-        t.AddSimpleTool( wb_ids.id_SP_EditCopy,
-            wb_images.getBitmap( 'toolbar_images/editcopy.png', bitmap_size ),
-            T_('Copy Files and Folders'), T_('Copy Files and Folders') )
-        t.AddSimpleTool( wb_ids.id_SP_EditPaste,
-            wb_images.getBitmap( 'toolbar_images/editpaste.png', bitmap_size ),
-            T_('Paste Files and Folders'), T_('Paste Files and Folders') )
-        t.AddSeparator()
-        t.AddSimpleTool( wb_ids.id_Command_Shell,
-            wb_images.getBitmap( 'toolbar_images/terminal.png', bitmap_size ),
-            T_('Command Shell'), T_('Start new command shell') )
-        t.AddSimpleTool( wb_ids.id_File_Browser,
-            wb_images.getBitmap( 'toolbar_images/file_browser.png', bitmap_size ),
-            T_('File Browser'), T_('File Browser') )
-        t.AddSeparator()
-        t.AddSimpleTool( wb_ids.id_File_Edit,
-            wb_images.getBitmap( 'toolbar_images/edit.png', bitmap_size ),
-            T_('Edit File'), T_('Edit File') )
-        t.AddSimpleTool( wb_ids.id_Shell_Open,
-            wb_images.getBitmap( 'toolbar_images/open.png', bitmap_size ),
-            T_('Open File'), T_('Open File') )
-        t.AddSeparator()
-        t.AddSimpleTool( wb_ids.id_SP_DiffWorkBase,
-            wb_images.getBitmap( 'toolbar_images/diff.png', bitmap_size ),
-            T_('Diff changes against base'), T_('Diff changes against base') )
-        t.AddSimpleTool( wb_ids.id_SP_History,
-            wb_images.getBitmap( 'toolbar_images/history.png', bitmap_size ),
-            T_('Show History log'), T_('Show History log') )
-        t.AddSimpleTool( wb_ids.id_SP_Info,
-            wb_images.getBitmap( 'toolbar_images/info.png', bitmap_size ),
-            T_('File Information'), T_('File Information') )
-        t.AddSimpleTool( wb_ids.id_SP_Properties,
-            wb_images.getBitmap( 'toolbar_images/property.png', bitmap_size ),
-            T_('File Properties'), T_('File Properties') )
-        t.AddSeparator()
-        t.AddSimpleTool( wb_ids.id_SP_Add,
-            wb_images.getBitmap( 'toolbar_images/add.png', bitmap_size ),
-            T_('Add Files and Folders'), T_('Add Files and Folders') )
-        t.AddSimpleTool( wb_ids.id_SP_Delete,
-            wb_images.getBitmap( 'toolbar_images/delete.png', bitmap_size ),
-            T_('Delete selected Files and Folders'), T_('Delete selected Files and Folders') )
-        t.AddSimpleTool( wb_ids.id_SP_Revert,
-            wb_images.getBitmap( 'toolbar_images/revert.png', bitmap_size ),
-            T_('Revert selected Files and Folders'), T_('Revert selected Files and Folders') )
-        t.AddSeparator()
-        t.AddSimpleTool( wb_ids.id_SP_Lock,
-            wb_images.getBitmap( 'toolbar_images/lock.png', bitmap_size ),
-            T_('Lock File'), T_('Lock File') )
-        t.AddSimpleTool( wb_ids.id_SP_Unlock,
-            wb_images.getBitmap( 'toolbar_images/unlock.png', bitmap_size ),
-            T_('Unlock File'), T_('Unlock File') )
-        t.AddSeparator()
-        t.AddSimpleTool( wb_ids.id_SP_Checkin,
-            wb_images.getBitmap( 'toolbar_images/checkin.png', bitmap_size ),
-            T_('Checkin changes'), T_('Checkin changes') )
-        t.AddSimpleTool( wb_ids.id_SP_Update,
-            wb_images.getBitmap( 'toolbar_images/update.png', bitmap_size ),
-            T_('Update working copy'), T_('Update working copy') )
-        t.AddSeparator()
-        t.AddSimpleTool( wb_ids.id_View_Recursive,
-            wb_images.getBitmap( 'toolbar_images/flatview.png', bitmap_size ),
-            T_('Use recursive (flat) view'), T_('Use recursive (flat) view'),
-            isToggle=True )
-        t.AddSimpleTool( wb_ids.id_View_OnlyChanges,
-            wb_images.getBitmap( 'toolbar_images/onlychanges.png', bitmap_size ),
-            T_('Show only changed files'), T_('Show only changed files'),
-            isToggle=True )
-
-        t.Realize()
-
+        # Initialize tool bar
+        
+        # Remark: The order of the groups and their activity (enabled/disabled)
+        # is managed in the preferences...
+        self.compileToolBar()
+        
         # Add the status bar
         s = self.CreateStatusBar()
         s.SetFieldsCount( WbFrame.status_num_fields )
         s.SetStatusWidths( WbFrame.status_widths )
-        s.SetStatusText(T_("Work Bench"), WbFrame.status_general)
-        s.SetStatusText("", WbFrame.status_progress)
-        s.SetStatusText(T_("Ready"), WbFrame.status_action)
+        s.SetStatusText( T_("Work Bench"), WbFrame.status_general )
+        s.SetStatusText( "", WbFrame.status_progress )
+        s.SetStatusText( T_("Ready"), WbFrame.status_action )
         if WbFrame.status_search != WbFrame.status_general:
-            s.SetStatusText("", WbFrame.status_search)
+            s.SetStatusText( "", WbFrame.status_search )
 
         # Create the splitter windows
         if 'wxMac' in wx.PlatformInfo:
@@ -365,6 +296,8 @@ class WbFrame(wx.Frame):
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Checkin, self.app.eventWrapper( self.OnUpdateUiSpCheckin ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Checkout, self.app.eventWrapper( self.OnSpCheckout ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Checkout, self.app.eventWrapper( self.OnUpdateUiSpCheckout ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_CheckoutTo, self.app.eventWrapper( self.OnSpCheckoutTo ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_CheckoutTo, self.app.eventWrapper( self.OnUpdateUiSpCheckoutTo ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Cleanup, self.app.eventWrapper( self.OnSpCleanup ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Cleanup, self.app.eventWrapper( self.OnUpdateUiSpCleanup ) )
         wx.EVT_MENU( self, wb_ids.id_SP_CreateTag, self.app.eventWrapper( self.OnSpCreateTag ) )
@@ -409,8 +342,8 @@ class WbFrame(wx.Frame):
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Unlock, self.app.eventWrapper( self.OnUpdateUiSpUnlock ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnSpUpdate ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Update, self.app.eventWrapper( self.OnUpdateUiSpUpdate ) )
-        wx.EVT_MENU( self, wb_ids.id_SP_Update_To, self.app.eventWrapper( self.OnSpUpdateTo ) )
-        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Update_To, self.app.eventWrapper( self.OnUpdateUiSpUpdateTo ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_UpdateTo, self.app.eventWrapper( self.OnSpUpdateTo ) )
+        wx.EVT_UPDATE_UI( self, wb_ids.id_SP_UpdateTo, self.app.eventWrapper( self.OnUpdateUiSpUpdateTo ) )
 
         wx.EVT_MENU( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnSpReportUpdates ) )
         wx.EVT_UPDATE_UI( self, wb_ids.id_SP_Report_Updates, self.app.eventWrapper( self.OnUpdateUiSpReportUpdates ) )
@@ -455,6 +388,28 @@ class WbFrame(wx.Frame):
         # should not have to reach through these levels
         self.list_panel.list_ctrl.SetFocus()
 
+
+    def compileToolBar( self ):
+        #
+        # Create the toolbar, if it is enabled.
+        #
+        toolbar_prefs = self.app.prefs.getToolbar()
+        if not toolbar_prefs.toolbar_enable:
+            return
+
+        if toolbar_prefs.horizontal_orientation:
+            tb_style = wx.TB_HORIZONTAL
+
+        else:
+            tb_style = wx.TB_VERTICAL
+
+        toolbar = self.CreateToolBar( name="main", style=tb_style )
+        toolbar.SetToolBitmapSize( (toolbar_prefs.bitmap_size, toolbar_prefs.bitmap_size) )
+
+        wb_toolbars.toolbar_main.populateToolBar( toolbar_prefs, toolbar )
+
+        toolbar.Realize()
+
     def setEventHandler( self, handler ):
         if wb_config.debug_selection:
             print 'ZF: setEventHandler from %r' % self.event_handler
@@ -529,17 +484,24 @@ class WbFrame(wx.Frame):
         self.tree_panel.updateTree()
 
     def OnSize( self, event ):
+        pref = self.app.prefs.getWindow()
+
         if not self.IsMaximized():
-            self.app.prefs.getWindow().frame_size = self.GetSize()
+            pref.setFrameSize( self.GetSize() )
+
         event.Skip()
 
     def OnMove( self, event ):
+        pref = self.app.prefs.getWindow()
+
         if not self.IsMaximized() and not self.IsIconized():
             # don't use the event.GetPosition() as it
-            # is off by the window frame thinkness
+            # is off by the window frame thickness
             pt = self.GetPosition()
-            self.app.prefs.getWindow().frame_position = pt
-        self.app.prefs.getWindow().is_maximized = self.IsMaximized()
+            pref.frame_position = pt
+
+        pref.maximized = self.IsMaximized()
+
         event.Skip()
 
     def OnHorizSashPositionChanged( self, event ):
@@ -679,64 +641,34 @@ class WbFrame(wx.Frame):
         self.tree_panel.selectTreeNode( filename )
 
     #------------------------------------------------------------------------
-    def __addBookmarkMenuItem( self, pi ):
-        bm_id = wx.NewId()
-        self.all_bookmark_ids[ bm_id ] = pi
-
-        if pi.menu_folder == '':
-            menu = self.menu_bookmarks
-            self.all_bookmark_top_level_menu_ids.append( bm_id )
-        else:
-            if pi.menu_folder not in self.all_bookmark_folders:
-                menu_id = wx.NewId()
-                self.all_bookmark_top_level_menu_ids.append( menu_id )
-
-                menu = wx.Menu()
-
-                self.all_bookmark_folders[ pi.menu_folder ] = menu
-                self.menu_bookmarks.AppendMenu( menu_id, pi.menu_folder, menu )
-            else:
-                menu = self.all_bookmark_folders[ pi.menu_folder ]
-
-        menu.Append( bm_id, pi.menu_name, pi.wc_path )
-        try_wrapper = wb_exceptions.TryWrapperFactory( self.app.log )
-        wx.EVT_MENU( self, bm_id, try_wrapper( self.OnBookmarkGoto ) )
-
     def __bookmarkMenuReorder( self ):
-        for menu_id in self.all_bookmark_top_level_menu_ids:
-            self.menu_bookmarks.Delete( menu_id )
+        self.bookmark_menu_tree.unrealise()
 
-        self.all_bookmark_ids = {}
-        self.all_bookmark_folders = {}
-        self.all_bookmark_top_level_menu_ids = []
+        self.all_bookmarks_id_to_pi = {}
 
         bm_prefs = self.app.prefs.getBookmarks()
-        bookmark_list = []
+        self.bookmark_menu_tree = BookmarkMenu( '' )
+
         for bm_name in bm_prefs.getBookmarkNames():
             if bm_name == 'last position':
                 continue
 
-            bookmark_list.append( bm_prefs.getBookmark( bm_name ) )
+            pi = bm_prefs.getBookmark( bm_name )
+            path = []
+            if pi.menu_folder != '':
+                path.append( pi.menu_folder )
 
-        def sortFunction( a, b ):
-            #
-            #   Sort only by name - do not sort folder then name
-            #
-            a_name = a.menu_folder
-            if a_name == '':
-                a_name = a.menu_name
+            if pi.menu_folder2 != '':
+                path.append( pi.menu_folder2 )
 
-            b_name = b.menu_folder
-            if b_name == '':
-                b_name = b.menu_name
+            if pi.menu_folder3 != '':
+                path.append( pi.menu_folder3 )
 
-            rc = cmp( a_name.lower(), b_name.lower() )
-            return rc
+            path.append( pi.menu_name )
 
-        bookmark_list.sort( sortFunction )
+            self.bookmark_menu_tree.add( path, pi )
 
-        for pi in bookmark_list:
-            self.__addBookmarkMenuItem( pi )
+        self.bookmark_menu_tree.realise( self.menu_bookmarks, self )
 
     def OnBookmarkAdd( self, event ):
         pi = self.tree_panel.getSelectionProjectInfo()
@@ -748,7 +680,6 @@ class WbFrame(wx.Frame):
             print T_('Adding bookmark to %s') % pi.wc_path
             bm_prefs.addBookmark( pi )
 
-            self.__addBookmarkMenuItem( pi )
             self.__bookmarkMenuReorder()
             self.app.savePreferences()
 
@@ -764,7 +695,7 @@ class WbFrame(wx.Frame):
         self.__bookmarkMenuReorder()
 
     def OnBookmarkGoto( self, event ):
-        self.tree_panel.gotoBookmark( self.all_bookmark_ids[event.GetId()].wc_path )
+        self.tree_panel.gotoBookmark( self.all_bookmarks_id_to_pi[event.GetId()].wc_path )
 
     #------------------------------------------------------------------------
     def OnCmdClearLog( self, event ):
@@ -869,6 +800,14 @@ class WbFrame(wx.Frame):
                         and not self.ui_state_tree.file_exists
                         and self.ui_state_tree.versioned )
 
+    def OnSpCheckoutTo( self, event ):
+        self.clearUpdateUiState()
+        return self.tree_panel.OnSpCheckoutTo()
+
+    def OnUpdateUiSpCheckoutTo( self, event ):
+        # same rules are checkout
+        self.OnUpdateUiSpCheckout( event )
+
     def OnSpCleanup( self, event ):
         return self.Sp_Dispatch( 'OnSpCleanup' )
 
@@ -895,7 +834,7 @@ class WbFrame(wx.Frame):
 
     def OnUpdateUiSpDelete( self, event ):
         self.getUpdateUiState()
-        event.Enable( self.ui_state_focus.file_exists )
+        event.Enable( self.ui_state_focus.file_exists or self.ui_state_focus.versioned )
 
     def OnSpDiffMineNew( self, event ):
         return self.Sp_Dispatch( 'OnSpDiffMineNew' )
@@ -1065,10 +1004,7 @@ class WbFrame(wx.Frame):
         if self.ui_state_focus.need_checkout:
             event.Enable( False )
         else:
-            event.Enable( self.ui_state_focus.need_checkin
-                or self.ui_state_focus.conflict
-                or (not self.ui_state_focus.file_exists
-                    and self.ui_state_focus.versioned) )
+            event.Enable( self.ui_state_focus.revertable )
 
     def OnSpUnlock( self, event ):
         return self.Sp_Dispatch( 'OnSpUnlock' )
@@ -1110,7 +1046,7 @@ class WbFrame(wx.Frame):
         self.clearUpdateUiState()
 
         if self.event_handler is None:
-            print 'No event_handler, cannot call', sp_func_name
+            print 'No event_handler, cannot call %r' % (sp_func_name,)
             return None
 
         fn = getattr( self.event_handler, sp_func_name, None )
@@ -1334,5 +1270,82 @@ class StyledLogCtrl(wx.stc.StyledTextCtrl):
     def ClearText( self ):
         self.SetReadOnly(False)
         self.ClearAll()
-        self.SetReadOnly(True)
+        self.SetReadOnly( True )
 
+class BookmarkMenu:
+    def __init__( self, name ):
+        self.name = name
+        self.menu_items = []
+        self.menu_folders = {}
+
+        self.parent_menu = None
+        self.all_menu_ids = []
+
+    def add( self, path, pi ):
+        if len(path) == 1:
+            self.menu_items.append( (path[0], pi) )
+
+        else:
+            folder = path[0]
+            if folder not in self.menu_folders:
+                self.menu_folders[ folder ] = BookmarkMenu( folder )
+                self.menu_items.append( (self.menu_folders[ folder ], None) )
+
+            self.menu_folders[ folder ].add( path[1:], pi )
+
+    def realise( self, parent_menu, frame ):
+        self.parent_menu = parent_menu
+
+        self.menu_items.sort( key=_keyMenuItem )
+
+        for name_or_menu, pi in self.menu_items:
+            if isinstance( name_or_menu, BookmarkMenu ):
+                menu_id = wx.NewId()
+                submenu = wx.Menu()
+
+                self.all_menu_ids.append( menu_id )
+
+                parent_menu.AppendMenu( menu_id, name_or_menu.name, submenu )
+                name_or_menu.realise( submenu, frame )
+
+            else:
+                bm_id = wx.NewId()
+                frame.all_bookmarks_id_to_pi[ bm_id ] = pi
+
+                self.all_menu_ids.append( bm_id )
+
+                parent_menu.Append( bm_id, pi.menu_name, pi.wc_path )
+                try_wrapper = wb_exceptions.TryWrapperFactory( frame.app.log )
+                wx.EVT_MENU( frame, bm_id, try_wrapper( frame.OnBookmarkGoto ) )
+
+    def unrealise( self ):
+        for name_or_menu, pi in self.menu_items:
+            if isinstance( name_or_menu, BookmarkMenu ):
+                name_or_menu.unrealise()
+
+            else:
+                # unrealise a bm item
+                pass
+
+        for menu_id in self.all_menu_ids:
+            self.parent_menu.Delete( menu_id )
+        
+    def dump( self, indent ):
+        prefix = ' '*indent
+        for name, pi in self.menu_items:
+            if isinstance( name, BookmarkMenu ):
+                print '%s  Menu: %r' % (prefix, name)
+                name.dump( indent + 4 )
+
+            else:
+                print '%s  Item: %r' % (prefix, name)
+
+    def __repr__( self ):
+        return '<Menu %s>' % self.name
+
+
+def _keyMenuItem( item ):
+    if isinstance( item[0], BookmarkMenu ):
+        return item[0].name
+    else:
+        return item[0]
