@@ -53,6 +53,7 @@ id_SP_Add = wx.NewId()
 id_SP_Annotate = wx.NewId()
 id_SP_Checkin = wx.NewId()
 id_SP_Checkout = wx.NewId()
+id_SP_CheckoutTo = wx.NewId()
 id_SP_Cleanup = wx.NewId()
 id_SP_Delete = wx.NewId()
 id_SP_DiffMineNew = wx.NewId()
@@ -73,7 +74,7 @@ id_SP_Resolved = wx.NewId()
 id_SP_Revert = wx.NewId()
 id_SP_Unlock = wx.NewId()
 id_SP_Update = wx.NewId()
-id_SP_Update_To = wx.NewId()
+id_SP_UpdateTo = wx.NewId()
 id_SP_CreateTag = wx.NewId()
 id_SP_CreateBranch = wx.NewId()
 
