@@ -35,7 +35,7 @@ class WbListPanel(wb_list_panel_common.WbListPanelCommon):
                 (wx.ACCEL_CMD, ord('I'), wb_ids.id_SP_Info),
                 (wx.ACCEL_CMD, ord('P'), wb_ids.id_SP_Properties),
                 (wx.ACCEL_CMD, ord('R'), wb_ids.id_SP_Revert),
-                (wx.ACCEL_CMD, ord('T'), wb_ids.id_SP_Update_To),
+                (wx.ACCEL_CMD, ord('T'), wb_ids.id_SP_UpdateTo),
                 (wx.ACCEL_CMD, ord('U'), wb_ids.id_SP_Update),
                 (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
                 (wx.ACCEL_CMD, ord('O'), wb_ids.id_Shell_Open),
