@@ -58,6 +58,7 @@ class ListItemState:
         self.file_exists = False
         self.is_folder = False
         self.is_project_parent = False
+        self.revertable = False
 
     def printState( self, title='' ):
         print '-----------',title
@@ -105,7 +106,7 @@ class WbListPanelCommon(wx.Panel):
         self.frame = frame
         try_wrapper = wb_exceptions.TryWrapperFactory( self.app.log )
 
-        self.filter_field = 'Name'
+        self.filter_field = T_('Name')
         self.filter_text = ''
 
         self.header_panel = HeaderPanel( self, app, self.filter_field )
@@ -266,7 +267,7 @@ class WbListPanelCommon(wx.Panel):
         view_prefs.sort_field = self.sort_data.getField()
 
     def getProjectInfo( self ):
-        if self.list_handler:
+        if self.list_handler is not None:
             return self.list_handler.getProjectInfo()
         return None
 
@@ -278,7 +279,7 @@ class WbListPanelCommon(wx.Panel):
 
     def updateHandler( self ):
         self.app.log.debug( 'WbListPanelCommon.updateHandler() %r' % self.list_handler )
-        if self.list_handler:
+        if self.list_handler is not None:
             self.list_handler.setupColumns()
             self.list_handler.updateStatus()
 
@@ -452,7 +453,7 @@ class WbListPanelCommon(wx.Panel):
         return self.Sp_Dispatch( 'Cmd_File_Update' )
 
     def OnSpUpdateTo( self ):
-        return self.Sp_Dispatch( 'Cmd_File_Update_To' )
+        return self.Sp_Dispatch( 'Cmd_File_UpdateTo' )
 
     def Sp_Dispatch( self, sp_func_name ):
         self.app.trace.info( 'WbListPanel.Sp_Dispatch( %s ) event' % sp_func_name )
@@ -508,7 +509,7 @@ class HeaderPanel(wx.Panel):
         self.filter_changed_handler = None
 
         # ToDo:  A wx.SearchCtrl would go great here instead of these widgets
-        self.filter_field_choices = ['Name','Author']
+        self.filter_field_choices = [ T_('Name'), T_('Author') ]
         self.filter_choice_ctrl = wx.Choice( self, wx.NewId(), choices=self.filter_field_choices )
         self.filter_choice_ctrl.SetSelection( self.filter_field_choices.index( filter_field ) )
         self.filter_text_ctrl = wx.TextCtrl( self )
