@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -15,15 +15,28 @@ import sys
 import os
 import locale
 
+# need to import so that it
+import _strptime
+
+
 # help debug when stdout goes nowhere useful
 # Mac OS X and Windows are the main problems
-if( os.environ.get( 'PYSVN_WORKBENCH_STDOUT_LOG', None )
+stdout_filename = None
+
+if( os.environ.get( 'PYSVN_WORKBENCH_STDOUT_LOG', None ) is not None
 or (sys.platform == 'darwin' and '--noredirect' not in sys.argv) ):
+    stdout_filename = os.environ.get( 'PYSVN_WORKBENCH_STDOUT_LOG', '/tmp/workbench.tmp' )
+
+elif sys.platform.startswith( 'win' ):
+    stdout_filename = os.path.join( os.environ[ 'TEMP' ], 'workbench.tmp' )
+
+if stdout_filename is not None:
     try:
-        sys.stdout = file( os.environ.get( 'PYSVN_WORKBENCH_STDOUT_LOG', '/tmp/workbench.tmp' ), 'w' )
+        sys.stdout = open( stdout_filename, 'w' )
         sys.stderr = sys.stdout
         print 'PySVN WorkBench starting'
         sys.stdout.flush()
+
     except EnvironmentError:
         pass
 
@@ -31,6 +44,7 @@ or (sys.platform == 'darwin' and '--noredirect' not in sys.argv) ):
 try:
     import wxversion
     wxversion.select( ['2.8'] )
+
 except:
     pass
 
@@ -42,7 +56,7 @@ def prerequesitChecks():
 
 def main( args ):
     startup_dir = os.getcwd()
-    if 1:
+    if True:
         if sys.platform == 'win32':
             os.chdir( os.environ['USERPROFILE'] )
             # Fix for wxPython bug on multi-processor machines - limit us to 1 processor
@@ -69,6 +83,8 @@ def main( args ):
         return 1
 
     app.frame.Show( 1 )
+
+
     app.MainLoop()
 
     return 0
@@ -79,6 +95,13 @@ def initLocale():
         locale.setlocale( locale.LC_ALL, '' )
 
     else:
+        if 'LC_ALL' in os.environ:
+            try:
+                locale.setlocale( locale.LC_ALL, os.environ['LC_ALL'] )
+                return
+            except locale.Error:
+                pass
+
         language_code, encoding = locale.getdefaultlocale()
         if language_code is None:
             language_code = 'en_US'
