@@ -1,7 +1,7 @@
 '''
 
  ====================================================================
- Copyright (c) 2004-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2004-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -19,7 +19,7 @@ def getApplicationDir():
     return os.path.join( os.environ['HOME'], 'Library/Preferences/org.tigris.pysvn.Workbench' )
 
 def getLocalePath( app ):
-    return os.path.join( app.app_dir, 'locale' )
+    return os.path.join( os.environ.get( 'PYTHONHOME', app.app_dir ), 'locale' )
 
 def getNullDevice():
     return '/dev/null'
