@@ -17,5 +17,8 @@ import os
 def getApplicationDir():
     return os.path.join( os.environ['HOME'], '.WorkBench' )
 
+def getLocalePath( app ):
+    return os.path.join( app.app_dir, 'locale' )
+
 def getNullDevice():
     return '/dev/null'
