@@ -18,6 +18,7 @@ import os
 import types
 import ConfigParser
 import UserDict
+import copy
 
 import xml.parsers.expat
 import xml.dom.minidom
@@ -27,7 +28,7 @@ import wx
 
 import wb_platform_specific
 import wb_source_control_providers
-
+import wb_toolbars
 
 new_save = True
 
@@ -60,7 +61,9 @@ class Preferences:
         self.pref_handlers['Editor'] = EditorPreferences( self.app )
         self.pref_handlers['Shell'] = ShellPreferences( self.app )
         self.pref_handlers['DiffTool'] = DiffToolPreferences( self.app )
-        self.pref_handlers['LogHistory'] = LogHistroyPreferences( self.app )
+        self.pref_handlers['LogHistory'] = LogHistoryPreferences( self.app )
+        self.pref_handlers['Toolbar'] = ToolbarPreferences( self.app )
+        self.pref_handlers['Advanced'] = AdvancedPreferences( self.app )
 
         # read preferences into the handlers
         self.readPreferences()
@@ -111,7 +114,7 @@ class Preferences:
                 os.rename( self.pref_filename, old_name )
             os.rename( new_name, self.pref_filename )
 
-            self.app.log.info( 'Wrote preferences to %s' % self.pref_filename )
+            self.app.log.info( T_('Wrote preferences to %s') % self.pref_filename )
 
         except EnvironmentError, e:
             self.app.log.error( 'write preferences: %s' % e )
@@ -121,10 +124,10 @@ class PreferenceData:
         self.all_sections = {}
 
         if os.path.exists( xml_pref_filename ):
-            log.info( 'Reading preferences from %s' % xml_pref_filename )
+            log.info( T_('Reading preferences from %s') % xml_pref_filename )
             self.__readXml( xml_pref_filename )
         else:
-            log.info( 'Reading preferences from %s' % ini_pref_filename )
+            log.info( T_('Reading preferences from %s') % ini_pref_filename )
             self.__readIni( ini_pref_filename )
 
     def __readXml( self, xml_pref_filename ):
@@ -234,6 +237,8 @@ class PreferenceData:
         return section_name in self.all_sections
 
     def len_section( self, section_name, option_name ):
+        if not self.all_sections[ section_name ].has_key( option_name ):
+            return 0
         if type(self.all_sections[ section_name ][ option_name ]) == types.ListType:
             length = len( self.all_sections[ section_name ][ option_name ] )
         else:
@@ -471,7 +476,7 @@ class BookmarksPreferences(PreferenceSection):
         set_option = SetOption( pref_data, self.section_name )
 
         all_bookmarks = self.all_bookmarks.items()
-        all_bookmarks.sort( self.__cmpBookmarksByMenuAndName )
+        all_bookmarks.sort( key=self.__keyBookmarksMenuAndName )
 
         for bookmark_name, bookmark in all_bookmarks:
             pref_dict = {}
@@ -481,27 +486,26 @@ class BookmarksPreferences(PreferenceSection):
 
             pref_data.append_dict( self.section_name, 'bookmark', pref_dict )
 
-    def __cmpBookmarksByMenuAndName( self, a_kv, b_kv ):
+    def __keyBookmarksMenuAndName( self, a_kv ):
         a = a_kv[1]
-        b = b_kv[1]        
+        k = []
         if a.menu_folder != '':
-            a_key = a.menu_folder + '\001' + a.menu_name
-        else:
-            a_key = a.menu_name
+            k.append( a.menu_folder )
 
-        if b.menu_folder != '':
-            b_key = b.menu_folder + '\001' + b.menu_name
-        else:
-            b_key = b.menu_name
+        if a.menu_folder2 != '':
+            k.append( a.menu_folder2 )
 
-        rc = cmp( a_key, b_key )
-        if rc == 0:
-            rc = cmp( a.wc_path, b.wc_path )
-        return rc
+        if a.menu_folder3 != '':
+            k.append( a.menu_folder3 )
+
+        k.append( a.menu_name )
+
+        return k
 
     def addBookmark( self, pi, name=None ):
         if name is None:
             name = pi.wc_path
+
         self.all_bookmarks[ name ] = pi
         self.__defaultMenuName( pi )
 
@@ -564,7 +568,7 @@ class WindowPreferences(PreferenceSection):
         self.h_sash_ratio = 0.7
         self.v_sash_ratio = 0.2
 
-        self.frame_size = wx.Size( 700, 500 )
+        self.__frame_size = wx.Size( 700, 500 )
         self.frame_position = wx.DefaultPosition
         self.maximized = False
         self.zoom = 0
@@ -581,7 +585,7 @@ class WindowPreferences(PreferenceSection):
 
         w = get_option.getint( 'width' )
         h = get_option.getint( 'height' )
-        self.frame_size = wx.Size( w, h )
+        self.__frame_size = wx.Size( w, h )
 
         self.maximized = get_option.getbool( 'maximized' )
         if get_option.has( 'zoom' ):
@@ -596,19 +600,25 @@ class WindowPreferences(PreferenceSection):
 
         set_option.set( 'pos_x', self.frame_position.x )
         set_option.set( 'pos_y', self.frame_position.y )
-        set_option.set( 'width', self.frame_size.GetWidth() )
-        set_option.set( 'height', self.frame_size.GetHeight() )
+        set_option.set( 'width', self.__frame_size.GetWidth() )
+        set_option.set( 'height', self.__frame_size.GetHeight() )
         set_option.set( 'maximized', self.maximized )
         set_option.set( 'zoom', self.zoom )
         set_option.set( 'h_sash_ratio', self.h_sash_ratio )
         set_option.set( 'v_sash_ratio', self.v_sash_ratio )
 
+    def getFrameSize( self ):
+        return self.__frame_size
+
+    def setFrameSize( self, size ):
+        self.__frame_size = size
+
 class DiffWindowPreferences(PreferenceSection):
     def __init__( self, app ):
         PreferenceSection.__init__( self, 'DiffWindow' )
         self.app = app
 
-        self.frame_size = wx.Size( 700, 500 )
+        self.__frame_size = wx.Size( 700, 500 )
         self.frame_position = wx.DefaultPosition
         self.maximized = False
         self.zoom = 0
@@ -625,7 +635,7 @@ class DiffWindowPreferences(PreferenceSection):
 
         w = get_option.getint( 'width' )
         h = get_option.getint( 'height' )
-        self.frame_size = wx.Size( w, h )
+        self.__frame_size = wx.Size( w, h )
 
         self.maximized = get_option.getbool( 'maximized' )
         if get_option.has( 'zoom' ):
@@ -637,11 +647,17 @@ class DiffWindowPreferences(PreferenceSection):
 
         set_option.set( 'pos_x', self.frame_position.x )
         set_option.set( 'pos_y', self.frame_position.y )
-        set_option.set( 'width', self.frame_size.GetWidth() )
-        set_option.set( 'height', self.frame_size.GetHeight() )
+        set_option.set( 'width', self.__frame_size.GetWidth() )
+        set_option.set( 'height', self.__frame_size.GetHeight() )
         set_option.set( 'maximized', self.maximized )
         set_option.set( 'zoom', self.zoom )
 
+    def getFrameSize( self ):
+        return self.__frame_size
+
+    def setFrameSize( self, size ):
+        self.__frame_size = size
+
 class ViewPreferences(PreferenceSection):
     def __init__( self, app ):
         PreferenceSection.__init__( self, 'View' )
@@ -655,8 +671,8 @@ class ViewPreferences(PreferenceSection):
         self.view_uncontrolled = True
         self.view_recursive = False
         self.view_onlychanges = False
-        self.column_order = ['Name','State','Date','Rev','Author','Type']
-        self.column_widths = ['25','4','14','4','10','4']
+        self.column_order = ['State','Name','Date','Rev','Author','Type']
+        self.column_widths = ['4','25','14','4','10','4']
 
     def readPreferences( self, pref_data ):
         get_option = GetOption( pref_data, self.section_name )
@@ -796,7 +812,7 @@ class DiffToolPreferences(PreferenceSection):
         if self.shell_diff_tool_options != '':
             set_option.set( 'shell_diff_tool_options', self.shell_diff_tool_options )
 
-class LogHistroyPreferences(PreferenceSection):
+class LogHistoryPreferences(PreferenceSection):
     def __init__( self, app ):
         PreferenceSection.__init__( self, 'LogHistory' )
         self.app = app
@@ -826,6 +842,53 @@ class LogHistroyPreferences(PreferenceSection):
         set_option.set( 'default_since_days_interval', self.default_since_days_interval )
         set_option.set( 'default_include_tags', self.default_include_tags )
 
+class ToolbarPreferences(PreferenceSection):
+    def __init__( self, app ):
+        PreferenceSection.__init__( self, 'Toolbar' )
+        self.app = app
+
+        self.toolbar_enable = True
+        self.horizontal_orientation = True
+        self.bitmap_size = 32
+        self.group_order = wb_toolbars.toolbar_main.getAllGroupNames()
+
+    def readPreferences( self, pref_data ):
+        get_option = GetOption( pref_data, self.section_name )
+
+        if get_option.has( 'toolbar_enable' ):
+            self.toolbar_enable = get_option.getbool( 'toolbar_enable' )
+        if get_option.has( 'horizontal_orientation' ):
+            self.horizontal_orientation = get_option.getbool( 'horizontal_orientation' )
+        if get_option.has( 'bitmap_size' ):
+            self.bitmap_size = get_option.getint( 'bitmap_size' )
+        if get_option.has( 'group_order' ):
+            self.group_order = get_option.getstrlist( 'group_order', ',' )
+
+    def writePreferences( self, pref_data ):
+        set_option = SetOption( pref_data, self.section_name )
+
+        set_option.set( 'toolbar_enable', self.toolbar_enable )
+        set_option.set( 'horizontal_orientation', self.horizontal_orientation )
+        set_option.set( 'bitmap_size', self.bitmap_size )
+        set_option.set( 'group_order', self.group_order, ',' )
+
+class AdvancedPreferences(PreferenceSection):
+    def __init__( self, app ):
+        PreferenceSection.__init__( self, 'Advanced' )
+        self.app = app
+
+        self.arbitrary_tag_branch = False
+
+    def readPreferences( self, pref_data ):
+        get_option = GetOption( pref_data, self.section_name )
+
+        if get_option.has( 'arbitrary_tag_branch' ):
+            self.arbitrary_tag_branch = get_option.getbool('arbitrary_tag_branch')
+
+    def writePreferences( self, pref_data ):
+        set_option = SetOption( pref_data, self.section_name )
+        set_option.set( 'arbitrary_tag_branch', self.arbitrary_tag_branch )
+
 if __name__ == '__main__':
     class FakeApp:
         def __init__( self ):
