@@ -15,6 +15,9 @@ import wb_exceptions
 import os
 import wb_subversion_list_handler_common
 import wb_shell_commands
+import wb_dialogs
+import wb_tree_panel
+import wb_toolbars
 
 class PreferencesDialog( wx.Dialog ):
     def __init__( self, parent, app ):
@@ -26,14 +29,14 @@ class PreferencesDialog( wx.Dialog ):
         try:
             self.initControls()
         except:
-            app.log.exception(T_('PreferencesDialog'))
+            app.log.exception( T_('PreferencesDialog') )
+
         self.SetSizer( self.v_sizer )
         self.Layout()
         self.Fit()
 
         self.CentreOnParent()
 
-
     def initControls( self ):
         self.v_sizer = wx.BoxSizer( wx.VERTICAL )
 
@@ -47,8 +50,11 @@ class PreferencesDialog( wx.Dialog ):
         self.pages.append( ShellPage( self.notebook, self.app ) )
         self.pages.append( ListColumnsPage( self.notebook, self.app ) )
         self.pages.append( LogHistoryPage( self.notebook, self.app ) )
+        self.pages.append( ToolbarPage( self.notebook, self.app ) )
         # may want view page for editing the control file
         #self.pages.append( ViewPage( self.notebook, self.app ) )
+        self.pages.append( AdvancedPage( self.notebook, self.app ) )
+
 
         self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
@@ -238,6 +244,7 @@ class DiffToolPage(PagePanel):
         p.shell_diff_tool = self.diff_tools['external-shell-diff']
         p.gui_diff_tool_options = self.options['external-gui-diff']
         p.shell_diff_tool_options = self.options['external-shell-diff']
+        p.diff_tool_mode = self.mode
 
         if p.diff_tool_mode == 'external-gui-diff' and p.gui_diff_tool == '':
             p.diff_tool_mode = 'built-in'
@@ -472,7 +479,7 @@ class ListColumnsPage(PagePanel):
 
     def __init__( self, notebook, app ):
         self.app = app
-        self.selected_name = None
+        self.selected_col_id = None
         self.column_info = wb_subversion_list_handler_common.ViewColumnInfo()
         PagePanel.__init__( self, notebook, T_('Columns') )
 
@@ -495,17 +502,19 @@ class ListColumnsPage(PagePanel):
         self.included_list.SetColumnWidth( 1, 80 )
 
         for name in self.column_info.getColumnOrder():
-            info = self.column_info.getInfo( name )
+            info = self.column_info.getInfoByName( name )
             info.included =  True
             index = self.included_list.GetItemCount()
 
-            self.included_list.InsertStringItem( index, info.name )
+            self.included_list.InsertStringItem( index, T_( info.label ) )
+            self.included_list.SetItemData( index, info.col_id )
             self.included_list.SetStringItem( index, 1, str(info.width) )
     
         for info in self.column_info.excludedInfo():
             index = self.excluded_list.GetItemCount()
 
-            self.excluded_list.InsertStringItem( index, info.name )
+            self.excluded_list.InsertStringItem( index, T_( info.label ) )
+            self.excluded_list.SetItemData( index, info.col_id )
             self.excluded_list.SetStringItem( index, 1, str(info.width) )
 
 
@@ -541,11 +550,11 @@ class ListColumnsPage(PagePanel):
 
         wx.EVT_TEXT_ENTER( self, ListColumnsPage.id_width, self.OnWidthTextEnter )
 
-        wx.EVT_LIST_ITEM_SELECTED( self, ListColumnsPage.id_excluded_list, self.OnExcludeSelected )
-        wx.EVT_LIST_ITEM_DESELECTED( self, ListColumnsPage.id_excluded_list, self.OnExcludeDeselected )
+        wx.EVT_LIST_ITEM_SELECTED( self, ListColumnsPage.id_excluded_list, self.OnExcludedListItemSelected )
+        wx.EVT_LIST_ITEM_DESELECTED( self, ListColumnsPage.id_excluded_list, self.OnExcludedListItemDeselected )
 
-        wx.EVT_LIST_ITEM_SELECTED( self, ListColumnsPage.id_included_list, self.OnIncludeSelected )
-        wx.EVT_LIST_ITEM_DESELECTED( self, ListColumnsPage.id_included_list, self.OnIncludeDeselected )
+        wx.EVT_LIST_ITEM_SELECTED( self, ListColumnsPage.id_included_list, self.OnIncludedListItemSelected )
+        wx.EVT_LIST_ITEM_DESELECTED( self, ListColumnsPage.id_included_list, self.OnIncludedListItemDeselected )
 
         return self.h_sizer
 
@@ -556,13 +565,13 @@ class ListColumnsPage(PagePanel):
         self.changeInclusionColumn( False, self.included_list, self.excluded_list )
 
     def changeInclusionColumn( self, include, from_list, to_list ):
-        info = self.column_info.getInfo( self.selected_name )
+        info = self.column_info.getInfoById( self.selected_col_id )
 
         try:
             width = int(self.width_text_ctrl.GetValue())
         except ValueError:
             wx.MessageBox( T_('Width for %(name)s must be an number between %(min)d and %(max)d') %
-                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
+                        {'name': T_( info.label ), 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
@@ -573,7 +582,7 @@ class ListColumnsPage(PagePanel):
             info.width = width
         else:
             wx.MessageBox( T_('Width for %(name)s must be between %(min)d and %(max)d') %
-                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
+                        {'name': T_( info.label ), 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
@@ -582,13 +591,14 @@ class ListColumnsPage(PagePanel):
         info.include = include
 
         # remove from from_list
-        from_index = from_list.FindItem( -1, info.name )
+        from_index = from_list.FindItemData( -1, info.col_id )
         from_list.DeleteItem( from_index )
 
         # add to end of to_list
         index = to_list.GetItemCount()
 
-        to_list.InsertStringItem( index, info.name )
+        to_list.InsertStringItem( index, T_( info.label ) )
+        to_list.SetItemData( index, info.col_id )
         to_list.SetStringItem( index, 1, str(info.width) )
 
     def OnMoveUp( self, event ):
@@ -598,13 +608,16 @@ class ListColumnsPage(PagePanel):
         self.moveColumn( 1 )
 
     def moveColumn( self, direction ):
-        info = self.column_info.getInfo( self.selected_name )
+        info = self.column_info.getInfoById( self.selected_col_id )
 
-        index = self.included_list.FindItem( -1, self.selected_name )
+        index = self.included_list.FindItemData( -1, info.col_id )
+        name = self.included_list.GetItemText( index )
 
         self.included_list.DeleteItem( index )
+
         index += direction
-        self.included_list.InsertStringItem( index, info.name )
+        self.included_list.InsertStringItem( index, T_( info.label ) )
+        self.included_list.SetItemData( index, info.col_id )
         self.included_list.SetStringItem( index, 1, str( info.width ) )
         self.included_list.SetItemState( index, wx.LIST_STATE_SELECTED, wx.LIST_STATE_SELECTED )
 
@@ -615,12 +628,12 @@ class ListColumnsPage(PagePanel):
 
 
     def OnWidthTextEnter( self, event ):
-        info = self.column_info.getInfo( self.selected_name )
+        info = self.column_info.getInfoById( self.selected_col_id )
         try:
             width = int(self.width_text_ctrl.GetValue())
         except ValueError:
             wx.MessageBox( T_('Width for %(name)s must be an number between %(min)d and %(max)d') %
-                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
+                        {'name': T_( info.label ), 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
@@ -629,62 +642,70 @@ class ListColumnsPage(PagePanel):
         if( width >= info.min_width
         and width <= info.max_width ):
             info.width = width
-            index = self.included_list.FindItem( -1, info.name )
+            index = self.included_list.FindItemData( -1, info.col_id )
             self.included_list.SetStringItem( index, 1, str(width) )
         else:
             wx.MessageBox( T_('Width for %(name)s must be between %(min)d and %(max)d') %
-                        {'name': info.name, 'min': info.min_width, 'max': info.max_width},
+                        {'name': T_( info.label ), 'min': info.min_width, 'max': info.max_width},
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
         
 
-    def OnExcludeSelected( self, event ):
+    def OnExcludedListItemSelected( self, event ):
+        self.selected_col_id = self.excluded_list.GetItemData( event.m_itemIndex )
+        info = self.column_info.getInfoById( self.selected_col_id )
+
         self.button_up.Enable( False )
         self.button_down.Enable( False )
         self.button_include.Enable( True )
+        self.button_exclude.Enable( False )
 
-        self.selected_name = self.excluded_list.GetItemText( event.m_itemIndex )
-        info = self.column_info.getInfo( self.selected_name )
         self.width_text_ctrl.SetValue( str(info.width) )
         self.width_text_ctrl.Enable( True )
 
-    def OnExcludeDeselected( self, event ):
+    def OnExcludedListItemDeselected( self, event ):
         self.button_include.Enable( False )
         self.width_text_ctrl.Enable( False )
+        self.button_up.Enable( False )
+        self.button_down.Enable( False )
 
-    def OnIncludeSelected( self, event ):
-        self.button_exclude.Enable( True )
+    def OnIncludedListItemSelected( self, event ):
+        self.selected_col_id = self.included_list.GetItemData( event.m_itemIndex )
+        info = self.column_info.getInfoById( self.selected_col_id )
+
+        self.button_exclude.Enable( info.name != 'Name' )
         self.button_include.Enable( False )
 
-        # enable up and down if no at the ends
+        # enable up and down if not at the ends
         item_count = self.included_list.GetItemCount()
         self.button_up.Enable( item_count > 1 and event.m_itemIndex != 0 )
         self.button_down.Enable( item_count > 1 and event.m_itemIndex != (item_count-1) )
 
-        self.selected_name = self.included_list.GetItemText( event.m_itemIndex )
-        info = self.column_info.getInfo( self.selected_name )
         self.width_text_ctrl.SetValue( str(info.width) )
         self.width_text_ctrl.Enable( True )
 
-    def OnIncludeDeselected( self, event ):
+    def OnIncludedListItemDeselected( self, event ):
         self.button_exclude.Enable( False )
         self.width_text_ctrl.Enable( False )
+        self.button_up.Enable( False )
+        self.button_down.Enable( False )
 
     def savePreferences( self ):
         p = self.app.prefs.getView()
         column_order = []
         for index in range( self.included_list.GetItemCount() ):
-            name = self.included_list.GetItemText( index )
-            column_order.append( name )
+            col_id = self.included_list.GetItemData( index )
+            column_order.append( self.column_info.getNameById( col_id ) )
 
         self.column_info.setColumnOrder( column_order )
         p.column_order = self.column_info.getColumnOrder()
         p.column_widths = self.column_info.getColumnWidths()
 
     def validate( self ):
-        if self.included_list.FindItem( -1, 'Name' ) < 0:
-            wx.MessageBox( T_('You must include the Name column'),
+        info = self.column_info.getInfoByName( 'Name' )
+        if self.included_list.FindItemData( -1, info.col_id ) < 0:
+            wx.MessageBox( T_('You must include the %s column') % (T_( info.label ),),
                 T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
@@ -769,3 +790,222 @@ class LogHistoryPage(PagePanel):
             return False
 
         return True
+
+class ToolbarPage(PagePanel):
+    id_exclude = wx.NewId()
+    id_include = wx.NewId()
+    id_move_up = wx.NewId()
+    id_move_down = wx.NewId()
+    id_excluded_list = wx.NewId()
+    id_included_list = wx.NewId()
+
+    def __init__( self, notebook, app ):
+        self.app = app
+        self.selected_name = None
+        PagePanel.__init__( self, notebook, T_('Toolbar') )
+
+    def initControls( self ):
+        p = self.app.prefs.getToolbar()
+        self.all_groups = wb_toolbars.toolbar_main.getAllGroupNames()
+        self.group_order = p.group_order
+
+        self.excluded_list = wx.ListCtrl( self, ToolbarPage.id_excluded_list, wx.DefaultPosition,
+                wx.Size( 200, 100 ), wx.LC_REPORT )
+        self.excluded_list.InsertColumn( 0, T_('Toolbar Group') )
+        self.excluded_list.SetColumnWidth( 0, 100 )
+
+        self.included_list = wx.ListCtrl( self, ToolbarPage.id_included_list, wx.DefaultPosition,
+                wx.Size( 200, 100 ), wx.LC_REPORT )
+        self.included_list.InsertColumn( 0, T_('Toolbar Group') )
+        self.included_list.SetColumnWidth( 0, 100 )
+
+        for name in self.group_order:
+            index = self.included_list.GetItemCount()
+
+            self.included_list.InsertStringItem( index, name )
+    
+        for name in [name for name in self.all_groups if name not in self.group_order]:
+            index = self.excluded_list.GetItemCount()
+
+            self.excluded_list.InsertStringItem( index, name )
+
+        self.button_include = wx.Button( self, ToolbarPage.id_include, T_(' Include --> ') )
+        self.button_include.Enable( False )
+        self.button_exclude = wx.Button( self, ToolbarPage.id_exclude, T_(' <-- Exclude ') )
+        self.button_exclude.Enable( False )
+
+        self.button_up = wx.Button( self, ToolbarPage.id_move_up, T_(' Move Up ') )
+        self.button_up.Enable( False )
+        self.button_down = wx.Button( self, ToolbarPage.id_move_down, T_(' Move Down ') )
+        self.button_down.Enable( False )
+
+        # qqq
+        self.enable_label = wx.StaticText( self, -1, T_('Display toolbar: '), style=wx.ALIGN_RIGHT )
+        self.enable_ctrl = wx.CheckBox( self, -1, T_('Enabled') )
+        self.enable_ctrl.SetValue( p.toolbar_enable )
+        self.horizontal_label = wx.StaticText( self, -1, T_('Orientation: '), style=wx.ALIGN_RIGHT )
+        self.horizontal_ctrl = wx.Choice( self, -1, choices=[T_('Horizontal'), T_('Vertical')] )
+        if p.horizontal_orientation:
+            self.horizontal_ctrl.SetSelection( 0 )
+        else:
+            self.horizontal_ctrl.SetSelection( 1 )
+
+        sizes = [T_('Small'), T_('Large'), T_('Huge')]
+        pixtoidx = {64: 2, 32: 1, 16: 0}
+        self.size_label = wx.StaticText( self, -1, T_('Icon size: '), style=wx.ALIGN_RIGHT )
+        self.ctrl_image_size = wx.Choice( self, -1, choices=sizes )
+        self.ctrl_image_size.SetSelection( pixtoidx.get( p.bitmap_size, 1 ) )
+
+        # build the sizers
+        self.v_sizer = wx.BoxSizer( wx.VERTICAL )
+        self.v_sizer.Add( self.button_include, 0, wx.EXPAND|wx.EAST, 5 )
+        self.v_sizer.Add( self.button_exclude, 0, wx.EXPAND|wx.EAST, 5 )
+        self.v_sizer.Add( self.button_up, 0, wx.EXPAND|wx.EAST, 5 )
+        self.v_sizer.Add( self.button_down, 0, wx.EXPAND|wx.EAST, 5 )
+
+        self.h_sizer = wx.BoxSizer( wx.HORIZONTAL )
+        self.h_sizer.Add( self.excluded_list, 0, wx.EXPAND|wx.WEST, 5 )
+        self.h_sizer.Add( self.v_sizer, 0, wx.EXPAND|wx.EAST, 5 )
+        self.h_sizer.Add( self.included_list, 0, wx.EXPAND|wx.EAST, 5 )
+
+        self.grid_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
+        self.grid_sizer.AddGrowableCol( 1 )
+
+        self.grid_sizer.Add( self.enable_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( self.enable_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.grid_sizer.Add( self.horizontal_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( self.horizontal_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.grid_sizer.Add( self.size_label, 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( self.ctrl_image_size, 0, wx.EXPAND|wx.ALL, 5 )
+
+        self.v_sizer2 = wx.BoxSizer( wx.VERTICAL )
+        self.v_sizer2.Add( self.grid_sizer )
+        self.v_sizer2.Add( self.h_sizer )
+
+        wx.EVT_BUTTON( self, ToolbarPage.id_include, self.OnInclude )
+        wx.EVT_BUTTON( self, ToolbarPage.id_exclude, self.OnExclude )
+        wx.EVT_BUTTON( self, ToolbarPage.id_move_up, self.OnMoveUp )
+        wx.EVT_BUTTON( self, ToolbarPage.id_move_down, self.OnMoveDown )
+
+        wx.EVT_LIST_ITEM_SELECTED( self, ToolbarPage.id_excluded_list, self.OnExcludeSelected )
+        wx.EVT_LIST_ITEM_DESELECTED( self, ToolbarPage.id_excluded_list, self.OnExcludeDeselected )
+
+        wx.EVT_LIST_ITEM_SELECTED( self, ToolbarPage.id_included_list, self.OnIncludeSelected )
+        wx.EVT_LIST_ITEM_DESELECTED( self, ToolbarPage.id_included_list, self.OnIncludeDeselected )
+
+        return self.v_sizer2
+
+    def OnInclude( self, event ):
+        self.changeInclusionGroup( self.excluded_list, self.included_list )
+
+    def OnExclude( self, event ):
+        self.changeInclusionGroup( self.included_list, self.excluded_list )
+
+    def changeInclusionGroup( self, from_list, to_list ):
+        # remove from from_list
+        from_index = from_list.FindItem( -1, self.selected_name )
+        
+        from_list.DeleteItem( from_index )
+
+        # add to end of to_list
+        index = to_list.GetItemCount()
+
+        to_list.InsertStringItem( index, self.selected_name )
+
+    def OnMoveUp( self, event ):
+        self.moveColumn( -1 )
+
+    def OnMoveDown( self, event ):
+        self.moveColumn( 1 )
+
+    def moveColumn( self, direction ):
+        index = self.included_list.FindItem( -1, self.selected_name )
+
+        self.included_list.DeleteItem( index )
+        index += direction
+        self.included_list.InsertStringItem( index, self.selected_name )
+        self.included_list.SetItemState( index, wx.LIST_STATE_SELECTED, wx.LIST_STATE_SELECTED )
+
+        # enable up and down if not at the ends
+        item_count = self.included_list.GetItemCount()
+        self.button_up.Enable( item_count > 1 and index != 0 )
+        self.button_down.Enable( item_count > 1 and index != (item_count-1) )
+
+    def OnExcludeSelected( self, event ):
+        self.button_up.Enable( False )
+        self.button_down.Enable( False )
+        self.button_include.Enable( True )
+
+        self.selected_name = self.excluded_list.GetItemText( event.m_itemIndex )
+
+    def OnExcludeDeselected( self, event ):
+        self.button_include.Enable( False )
+        self.width_text_ctrl.Enable( False )
+
+    def OnIncludeSelected( self, event ):
+        self.button_exclude.Enable( True )
+        self.button_include.Enable( False )
+
+        self.selected_name = self.included_list.GetItemText( event.m_itemIndex )
+
+        # enable up and down if no at the ends
+        item_count = self.included_list.GetItemCount()
+        self.button_up.Enable( item_count > 1 and event.m_itemIndex != 0 )
+        self.button_down.Enable( item_count > 1 and event.m_itemIndex != (item_count-1) )
+
+    def OnIncludeDeselected( self, event ):
+        self.button_exclude.Enable( False )
+
+    def savePreferences( self ):
+        p = self.app.prefs.getToolbar()
+
+        p.toolbar_enable = self.enable_ctrl.GetValue()
+
+        p = self.app.prefs.getToolbar()
+        group_order = []
+        for index in range( self.included_list.GetItemCount() ):
+            name = self.included_list.GetItemText( index )
+            group_order.append( name )
+
+        p.group_order = group_order
+
+        p.horizontal_orientation = self.horizontal_ctrl.GetSelection() == 0
+
+        size_to_pixels = {0:16, 1:32, 2:64}
+        p.bitmap_size = size_to_pixels[ self.ctrl_image_size.GetSelection() ]
+
+    def validate( self ):
+        if self.included_list.GetItemCount() == 0:
+            wx.MessageBox( T_('You must include at least one Toolbar group'),
+                T_('Warning'),
+                wx.OK | wx.ICON_EXCLAMATION,
+                self )
+            return False
+
+        return True
+
+class AdvancedPage(PagePanel):
+    def __init__( self, notebook, app ):
+        self.app = app
+        PagePanel.__init__( self, notebook, T_('Advanced') )
+
+    def initControls( self ):
+        p = self.app.prefs.getAdvanced()
+
+        self.v_sizer = wx.BoxSizer( wx.VERTICAL )
+
+        self.tagbranch_ctrl = wx.CheckBox( self, -1, T_("Allow arbitrary paths for tag/branch") )
+        self.tagbranch_ctrl.SetValue( p.arbitrary_tag_branch )
+
+        self.v_sizer.Add( self.tagbranch_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+
+        return self.v_sizer
+
+    def savePreferences( self ):
+        p = self.app.prefs.getAdvanced()
+        p.arbitrary_tag_branch = self.tagbranch_ctrl.GetValue()
+
+    def validate( self ):
+        return True
