@@ -45,64 +45,64 @@ class ProjectDialog(wx.Dialog):
 
         self.g_sizer = wx.GridBagSizer( 5, 20 )
 
-        self.border = wx.StaticBox( self, -1, 'Project' )
+        self.border = wx.StaticBox( self, -1, T_('Project') )
         self.box = wx.StaticBoxSizer( self.border, wx.VERTICAL )
         self.box.Add( self.g_sizer, 0, wx.EXPAND )
 
-        self.name_label = wx.StaticText( self, -1, 'Project Name:', style=wx.ALIGN_RIGHT )
+        self.name_label = wx.StaticText( self, -1, T_('Project Name:'), style=wx.ALIGN_RIGHT )
         self.name_ctrl = wx.TextCtrl( self, -1, '', size=(400,-1) )
 
         self.g_sizer.Add( self.name_label, (0,0), (1,1), wx.ALIGN_RIGHT )
         self.g_sizer.Add( self.name_ctrl,  (0,1), (1,2), wx.EXPAND )
 
-        self.wc_path_browse = wx.Button( self, wc_path_browse_id, " Browse... ")
+        self.wc_path_browse = wx.Button( self, wc_path_browse_id, T_(" Browse... ") )
 
-        self.wc_path_label = wx.StaticText(self, -1, 'Working copy Path:', style=wx.ALIGN_RIGHT )
+        self.wc_path_label = wx.StaticText(self, -1, T_('Working copy Path:'), style=wx.ALIGN_RIGHT )
         self.wc_path_ctrl = wx.TextCtrl(self, wc_path_text_ctrl_id, '' )
 
         self.g_sizer.Add( self.wc_path_label,  (1,0), (1,1), wx.ALIGN_RIGHT )
         self.g_sizer.Add( self.wc_path_ctrl,   (1,1), (1,2), wx.EXPAND )
         self.g_sizer.Add( self.wc_path_browse, (1,3), (1,1)  )
 
-        self.url_trunk_label = wx.StaticText( self, -1, 'Subversion Trunk URL:', style=wx.ALIGN_RIGHT )
+        self.url_trunk_label = wx.StaticText( self, -1, T_('Subversion Trunk URL:'), style=wx.ALIGN_RIGHT )
         self.url_trunk_ctrl = wx.TextCtrl( self, url_trunk_path_text_ctrl_id, '' )
 
         self.g_sizer.Add( self.url_trunk_label, (2,0), (1,1), wx.ALIGN_RIGHT )
         self.g_sizer.Add( self.url_trunk_ctrl,  (2,1), (1,2), wx.EXPAND )
 
-        self.url_tags_label = wx.StaticText( self, -1, 'Subversion Tags URL:', style=wx.ALIGN_RIGHT )
+        self.url_tags_label = wx.StaticText( self, -1, T_('Subversion Tags URL:'), style=wx.ALIGN_RIGHT )
         self.url_tags_ctrl = wx.TextCtrl( self, url_tags_path_text_ctrl_id, '' )
 
         self.g_sizer.Add( self.url_tags_label, (3,0), (1,1), wx.ALIGN_RIGHT )
         self.g_sizer.Add( self.url_tags_ctrl,  (3,1), (1,2), wx.EXPAND )
 
-        self.url_branches_label = wx.StaticText( self, -1, 'Subversion Branches URL:', style=wx.ALIGN_RIGHT )
+        self.url_branches_label = wx.StaticText( self, -1, T_('Subversion Branches URL:'), style=wx.ALIGN_RIGHT )
         self.url_branches_ctrl = wx.TextCtrl( self, url_tags_path_text_ctrl_id, '' )
 
         self.g_sizer.Add( self.url_branches_label, (4,0), (1,1), wx.ALIGN_RIGHT )
         self.g_sizer.Add( self.url_branches_ctrl,  (4,1), (1,2), wx.EXPAND )
 
-        self.newfile_dir_label = wx.StaticText( self, -1, "New File Template Folder: ", style=wx.ALIGN_RIGHT)
+        self.newfile_dir_label = wx.StaticText( self, -1, T_("New File Template Folder: "), style=wx.ALIGN_RIGHT)
         self.newfile_dir_ctrl = wx.TextCtrl( self, -1, '' )
-        self.newfile_dir_browse = wx.Button( self, -1, " Browse... ")
+        self.newfile_dir_browse = wx.Button( self, -1, T_(" Browse... ") )
 
         self.g_sizer.Add( self.newfile_dir_label,  (5,0), (1,1), wx.ALIGN_RIGHT )
         self.g_sizer.Add( self.newfile_dir_ctrl,   (5,1), (1,2), wx.EXPAND )
         self.g_sizer.Add( self.newfile_dir_browse, (5,3), (1,1) )
 
-        self.list_background_colour_label = wx.StaticText( self, -1, "Background Colour: ", style=wx.ALIGN_RIGHT)
-        self.list_background_colour_ctrl = wx.CheckBox( self, -1, "Use custom background colour" )
-        self.list_background_colour_example = wx.StaticText( self, -1, "Example", style=wx.ALIGN_CENTER )
-        self.list_background_colour_picker = wx.Button( self, -1, " Pick Colour... ")
+        self.list_background_colour_label = wx.StaticText( self, -1, T_("Background Colour: ") , style=wx.ALIGN_RIGHT)
+        self.list_background_colour_ctrl = wx.CheckBox( self, -1, T_("Use custom background colour") )
+        self.list_background_colour_example = wx.StaticText( self, -1, T_("Example") , style=wx.ALIGN_CENTER )
+        self.list_background_colour_picker = wx.Button( self, -1, T_(" Pick Colour... ") )
 
         self.g_sizer.Add( self.list_background_colour_label,   (6,0), (1,1), wx.ALIGN_RIGHT )
         self.g_sizer.Add( self.list_background_colour_ctrl,    (6,1), (1,1), wx.EXPAND )
         self.g_sizer.Add( self.list_background_colour_example, (6,2), (1,1), wx.ALIGN_CENTER|wx.EXPAND )
         self.g_sizer.Add( self.list_background_colour_picker,  (6,3), (1,1) )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (250, 20), 1, wx.EXPAND)
@@ -182,38 +182,38 @@ class ProjectDialog(wx.Dialog):
 
         name = self.name_ctrl.GetValue().strip()
         if name == '':
-            wx.MessageBox( 'Enter a project name', style=wx.OK|wx.ICON_ERROR );
+            wx.MessageBox( T_('Enter a project name'), style=wx.OK|wx.ICON_ERROR );
             return
 
         if name in self.pi_names:
-            wx.MessageBox( 'Project %s already exist. Choose another name' % name,
+            wx.MessageBox( T_('Project %s already exist. Choose another name') % name,
                 style=wx.OK|wx.ICON_ERROR );
             return
 
         url = self.url_trunk_ctrl.GetValue().strip()
         if url == '':
-            wx.MessageBox( 'Enter a Subversion trunk URL', style=wx.OK|wx.ICON_ERROR );
+            wx.MessageBox( T_('Enter a Subversion trunk URL'), style=wx.OK|wx.ICON_ERROR );
             return
 
         if not is_url( url ):
-            wx.MessageBox( '%s is not a valid Subversion trunk URL' % url,
+            wx.MessageBox( T_('%s is not a valid Subversion trunk URL') % url,
                 style=wx.OK|wx.ICON_ERROR );
             return
 
         url = self.url_tags_ctrl.GetValue().strip()
         if url and not is_url( url ):
-            wx.MessageBox( '%s is not a valid Subversion tags URL' % url,
+            wx.MessageBox( T_('%s is not a valid Subversion tags URL') % url,
                 style=wx.OK|wx.ICON_ERROR );
             return
 
         url = self.url_branches_ctrl.GetValue().strip()
         if url and not is_url( url ):
-            wx.MessageBox( '%s is not a valid Subversion tags URL' % url,
+            wx.MessageBox( T_('%s is not a valid Subversion tags URL') % url,
                 style=wx.OK|wx.ICON_ERROR );
             return
 
         if self.wc_path_ctrl.GetValue().strip() == '':
-            wx.MessageBox( 'Enter a Working copy path', style=wx.OK|wx.ICON_ERROR );
+            wx.MessageBox( T_('Enter a Working copy path'), style=wx.OK|wx.ICON_ERROR );
             return
 
         self.EndModal( wx.ID_OK )
@@ -225,7 +225,7 @@ class ProjectDialog(wx.Dialog):
         filename = os.path.expanduser( self.wc_path_ctrl.GetValue() )
         dir_dialog = wx.DirDialog( 
             self,
-            "Select Working Copy directory",
+            T_("Select Working Copy directory"),
             filename,
             style=wx.DD_DEFAULT_STYLE|wx.DD_NEW_DIR_BUTTON )
 
@@ -244,7 +244,7 @@ class ProjectDialog(wx.Dialog):
 
         dir_dialog = wx.DirDialog( 
             self,
-            "Select New File Template directory",
+            T_("Select New File Template directory"),
             filename,
             style=wx.DD_DEFAULT_STYLE|wx.DD_NEW_DIR_BUTTON )
 
@@ -300,7 +300,7 @@ class ProjectDialog(wx.Dialog):
 
 class UpdateProjectDialog(ProjectDialog):
     def __init__( self, app, parent, project_info ):
-        ProjectDialog.__init__( self, app, parent, 'Project Settings' )
+        ProjectDialog.__init__( self, app, parent, T_('Project Settings') )
 
         self.project_info = project_info
 
@@ -344,7 +344,7 @@ class AddProjectDialog:
         pi_list = self.app.prefs.getProjects().getProjectList()
         self.pi_names = [pi.project_name for pi in pi_list]
 
-        self.wizard = wx.wizard.Wizard( parent, wizard_id, "Add Project" )
+        self.wizard = wx.wizard.Wizard( parent, wizard_id, T_("Add Project") )
 
         self.page_wc_choice = WorkingCopyChoicePage( self )
         self.page_wc_exists = WorkingCopyExistsPage( self )
@@ -441,9 +441,9 @@ class TitledPage(wx.wizard.PyWizardPage):
 
 class WorkingCopyChoicePage(TitledPage):
     def __init__( self, parent ):
-        TitledPage.__init__( self, parent, "Working Copy" )
-        self.radio_new = wx.RadioButton( self, -1, " Use new working copy directory ", style = wx.RB_GROUP )
-        self.radio_existing = wx.RadioButton( self, -1, " Use existing Working copy directory " )
+        TitledPage.__init__( self, parent, T_("Working Copy") )
+        self.radio_new = wx.RadioButton( self, -1, T_(" Use new working copy directory "), style = wx.RB_GROUP )
+        self.radio_existing = wx.RadioButton( self, -1, T_(" Use existing Working copy directory ") )
 
         self.sizer.Add( (10, 50) )
         self.sizer.Add( self.radio_new, 0, wx.ALL, 5 )
@@ -467,14 +467,14 @@ class WorkingCopyChoicePage(TitledPage):
 
 class WorkingCopyExistsPage(TitledPage):
     def __init__( self, parent ):
-        TitledPage.__init__( self, parent, "Select Working Copy" )
+        TitledPage.__init__( self, parent, T_("Select Working Copy") )
 
         self.g_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
-        self.wc_path_label = wx.StaticText(self, -1, 'Working copy Path:', style=wx.ALIGN_RIGHT )
+        self.wc_path_label = wx.StaticText(self, -1, T_('Working copy Path:'), style=wx.ALIGN_RIGHT )
         self.wc_path_ctrl = wx.TextCtrl(self, wc_path_text_ctrl_id, '' )
-        self.wc_path_browse = wx.Button( self, wc_path_browse_id, " Browse... ")
+        self.wc_path_browse = wx.Button( self, wc_path_browse_id, T_(" Browse... ") )
 
         self.g_sizer.Add( self.wc_path_label, 0, wx.EXPAND|wx.ALL|wx.ALIGN_BOTTOM, 5 )
         self.g_sizer.Add( self.wc_path_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_BOTTOM, 3 )
@@ -484,7 +484,7 @@ class WorkingCopyExistsPage(TitledPage):
         self.g_sizer.Add( (400,10) )
         self.g_sizer.Add( (10,10) )
 
-        self.url_label = wx.StaticText( self, -1, 'Subversion URL:', style=wx.ALIGN_RIGHT )
+        self.url_label = wx.StaticText( self, -1, T_('Subversion URL:'), style=wx.ALIGN_RIGHT )
         self.url_ctrl = wx.StaticText( self, -1, '' )
 
         self.g_sizer.Add( self.url_label, 0, wx.EXPAND|wx.ALL|wx.ALIGN_BOTTOM, 5 )
@@ -503,27 +503,29 @@ class WorkingCopyExistsPage(TitledPage):
         self.updateControls()
 
     def saveState( self, state ):
-        state.wc_path = os.path.expanduser( self.wc_path_ctrl.GetValue().strip() )
+        # must get the abspath to convert c:/dir1/dir2 to c:\dir1\dir2
+        # otherwise all sorts of things break inside workbench
+        state.wc_path = os.path.abspath( os.path.expanduser( self.wc_path_ctrl.GetValue().strip() ) )
         state.url_path = self.url_ctrl.GetLabel().strip()
 
         if not os.path.exists( state.wc_path ):
-            wx.MessageBox( 'Path %s\n'
+            wx.MessageBox( T_('Path %s\n'
                     'Does not exist\n'
-                    'Choose an existing subversion working copy directory'
+                    'Choose an existing subversion working copy directory')
                     % state.wc_path, style=wx.OK|wx.ICON_ERROR );
             return False
 
         if not os.path.isdir( state.wc_path ):
-            wx.MessageBox( 'Path %s\n'
+            wx.MessageBox( T_('Path %s\n'
                     'Is not a directory\n'
-                    'Choose an existing subversion working copy directory'
+                    'Choose an existing subversion working copy directory')
                     % state.wc_path, style=wx.OK|wx.ICON_ERROR );
             return False
 
         if state.url_path == '':
-            wx.MessageBox( 'Path %s\n'
+            wx.MessageBox( T_('Path %s\n'
                     'Is not a subversion working copy\n'
-                    'Choose an existing subversion working copy directory'
+                    'Choose an existing subversion working copy directory')
                     % state.wc_path, style=wx.OK|wx.ICON_ERROR );
             return False
 
@@ -533,7 +535,7 @@ class WorkingCopyExistsPage(TitledPage):
         filename = os.path.expanduser( self.wc_path_ctrl.GetValue() )
         dir_dialog = wx.DirDialog( 
             self,
-            "Select Working Copy directory",
+            T_("Select Working Copy directory"),
             filename,
             style=wx.DD_DEFAULT_STYLE|wx.DD_NEW_DIR_BUTTON )
 
@@ -572,13 +574,13 @@ class WorkingCopyExistsPage(TitledPage):
 
 class SubversionUrlPage(TitledPage):
     def __init__( self, parent ):
-        TitledPage.__init__( self, parent, "Select Subversion URL" )
+        TitledPage.__init__( self, parent, T_("Select Subversion URL") )
 
         self.g_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
 
-        self.url_path_label = wx.StaticText(self, -1, 'Subversion URL:', style=wx.ALIGN_RIGHT )
+        self.url_path_label = wx.StaticText(self, -1, T_('Subversion URL:'), style=wx.ALIGN_RIGHT )
         self.url_path_ctrl = wx.TextCtrl(self, url_trunk_path_text_ctrl_id, '' )
 
         self.g_sizer.Add( self.url_path_label, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 5 )
@@ -598,11 +600,11 @@ class SubversionUrlPage(TitledPage):
         state.url_path = self.url_path_ctrl.GetValue().strip()
 
         if state.url_path == '':
-            wx.MessageBox( 'Enter a Subversion URL', style=wx.OK|wx.ICON_ERROR );
+            wx.MessageBox( T_('Enter a Subversion URL'), style=wx.OK|wx.ICON_ERROR );
             return False
 
         if not self.parent.client_pi.client_fg.is_url( state.url_path ):
-            wx.MessageBox( '%s is not a valid Subversion URL' % state.url_path,
+            wx.MessageBox( T_('%s is not a valid Subversion URL') % state.url_path,
                 style=wx.OK|wx.ICON_ERROR );
             return False
 
@@ -610,8 +612,10 @@ class SubversionUrlPage(TitledPage):
             head = pysvn.Revision( pysvn.opt_revision_kind.head )
             self.parent.client_pi.client_fg.log( state.url_path, revision_start=head, revision_end=head )
         except pysvn.ClientError, e:
-            wx.MessageBox( '%s is not a accessable Subversion URL\n'
-                    '%s' % (state.url_path, e.args[0]),
+            wx.MessageBox( T_('%(url)s is not a accessable Subversion URL\n'
+                                '%(error)s') %
+                            {'url': state.url_path
+                            ,'error': e.args[0]},
                 style=wx.OK|wx.ICON_ERROR )
 
             return False
@@ -621,15 +625,15 @@ class SubversionUrlPage(TitledPage):
 
 class WorkingCopyCreatePage(TitledPage):
     def __init__( self, parent ):
-        TitledPage.__init__( self, parent, "Create new Working Copy" )
+        TitledPage.__init__( self, parent, T_("Create new Working Copy") )
 
         self.g_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
 
-        self.wc_path_label = wx.StaticText(self, -1, 'Working copy Path:', style=wx.ALIGN_RIGHT )
+        self.wc_path_label = wx.StaticText(self, -1, T_('Working copy Path:'), style=wx.ALIGN_RIGHT )
         self.wc_path_ctrl = wx.TextCtrl(self, wc_path_text_ctrl_id, '' )
-        self.wc_path_browse = wx.Button( self, wc_path_browse_id, " Browse... ")
+        self.wc_path_browse = wx.Button( self, wc_path_browse_id, T_(" Browse... ") )
 
         self.g_sizer.Add( self.wc_path_label, 0, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.wc_path_ctrl, 0, wx.EXPAND|wx.ALL, 3 )
@@ -639,7 +643,7 @@ class WorkingCopyCreatePage(TitledPage):
         self.g_sizer.Add( (400,10) )
         self.g_sizer.Add( (10,10) )
 
-        self.url_label = wx.StaticText( self, -1, 'Subversion URL:', style=wx.ALIGN_RIGHT )
+        self.url_label = wx.StaticText( self, -1, T_('Subversion URL:'), style=wx.ALIGN_RIGHT )
         self.url_ctrl = wx.StaticText( self, -1, '' )
 
         self.g_sizer.Add( self.url_label, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 5 )
@@ -657,23 +661,23 @@ class WorkingCopyCreatePage(TitledPage):
     def saveState( self, state ):
         state.wc_path = os.path.expanduser( self.wc_path_ctrl.GetValue().strip() )
         if state.wc_path == '':
-            wx.MessageBox( 'Choose a directory that is empty and not in used by subversion',
+            wx.MessageBox( T_('Choose a directory that is empty and not in used by subversion'),
                     style=wx.OK|wx.ICON_ERROR );
             return False
 
         if os.path.exists( state.wc_path ):
             if not os.path.isdir( state.wc_path ):
-                wx.MessageBox( 'Path %s\n'
+                wx.MessageBox( T_('Path %s\n'
                         'Is not a directory\n'
-                        'Choose a directory that is empty and not in use by subversion'
+                        'Choose a directory that is empty and not in use by subversion')
                         % state.wc_path, style=wx.OK|wx.ICON_ERROR );
                 return False
 
             try:
                 info = self.parent.client_pi.client_fg.info( state.wc_path )
-                wx.MessageBox( 'Path %s\n'
+                wx.MessageBox( T_('Path %s\n'
                     'Is a subversion working copy\n'
-                    'Choose a directory that is empty and not in use by subversion'
+                    'Choose a directory that is empty and not in use by subversion')
                     % state.wc_path, style=wx.OK|wx.ICON_ERROR );
                 return False
             except pysvn.ClientError:
@@ -683,16 +687,22 @@ class WorkingCopyCreatePage(TitledPage):
             try:
                 dir_list = os.listdir( state.wc_path )
                 if len(dir_list) > 0:
-                    wx.MessageBox( 'Path %s\n'
-                        'Is not an empty directory\n'
-                        'Choose a directory that is empty and not in use by subversion'
-                        % state.wc_path, style=wx.OK|wx.ICON_ERROR );
+                    wx.MessageBox(
+                        T_('Path %s\n'
+                            'Is not an empty directory\n'
+                            'Choose a directory that is empty and not in use by subversion') %
+                                state.wc_path,
+                        style=wx.OK|wx.ICON_ERROR );
                     return False
+
             except (OSError,IOError), e:
-                wx.MessageBox( 'Path %s\n'
-                    '%s\n'
-                    'Choose a directory that is empty and not in use by subversion'
-                    % (state.wc_path, str(e)), style=wx.OK|wx.ICON_ERROR );
+                wx.MessageBox(
+                    T_('Path %(path)s\n'
+                        '%(error)s\n'
+                        'Choose a directory that is empty and not in use by subversion') %
+                        {'path': state.wc_path
+                        ,'error': str(e)},
+                    style=wx.OK|wx.ICON_ERROR );
                 return False
 
         return True
@@ -701,7 +711,7 @@ class WorkingCopyCreatePage(TitledPage):
         filename = os.path.expanduser( self.wc_path_ctrl.GetValue() )
         dir_dialog = wx.DirDialog( 
             self,
-            "Select Working Copy directory",
+            T_("Select Working Copy directory"),
             filename,
             style=wx.DD_DEFAULT_STYLE|wx.DD_NEW_DIR_BUTTON )
 
@@ -714,13 +724,13 @@ class WorkingCopyCreatePage(TitledPage):
 
 class ProjectNamePage(TitledPage):
     def __init__( self, parent ):
-        TitledPage.__init__( self, parent, "Project Name" )
+        TitledPage.__init__( self, parent, T_("Project Name") )
 
         self.g_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
 
-        self.name_label = wx.StaticText(self, -1, 'Project name:', style=wx.ALIGN_RIGHT )
+        self.name_label = wx.StaticText(self, -1, T_('Project name:'), style=wx.ALIGN_RIGHT )
         self.name_ctrl = wx.TextCtrl(self, -1, '' )
 
         self.g_sizer.Add( self.name_label, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 5 )
@@ -731,14 +741,14 @@ class ProjectNamePage(TitledPage):
         self.g_sizer.Add( (400,10) )
         self.g_sizer.Add( (10,10) )
 
-        self.wc_path_label = wx.StaticText(self, -1, 'Working copy Path:', style=wx.ALIGN_RIGHT )
+        self.wc_path_label = wx.StaticText(self, -1, T_('Working copy Path:'), style=wx.ALIGN_RIGHT )
         self.wc_path_ctrl = wx.StaticText(self, -1, '' )
 
         self.g_sizer.Add( self.wc_path_label, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.wc_path_ctrl, 0, wx.EXPAND|wx.ALL|wx.ALIGN_CENTER_HORIZONTAL , 5 )
         self.g_sizer.Add( (1,1), 0, wx.EXPAND )
 
-        self.url_label = wx.StaticText( self, -1, 'Subversion URL:', style=wx.ALIGN_RIGHT )
+        self.url_label = wx.StaticText( self, -1, T_('Subversion URL:'), style=wx.ALIGN_RIGHT )
         self.url_ctrl = wx.StaticText( self, -1, '' )
 
         self.g_sizer.Add( self.url_label, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 5 )
@@ -755,14 +765,14 @@ class ProjectNamePage(TitledPage):
         state.project_name = self.name_ctrl.GetValue().strip()
 
         if state.project_name == '':
-            wx.MessageBox( 'Project name is blank.\n'
-                    'Enter a project name',
+            wx.MessageBox( T_('Project name is blank.\n'
+                    'Enter a project name'),
                     style=wx.OK|wx.ICON_ERROR );
             return False
 
         if state.project_name in self.parent.pi_names:
-            wx.MessageBox( 'Project %s already exist.\n'
-                    'Choose another name' % state.project_name,
+            wx.MessageBox( T_('Project %s already exist.\n'
+                    'Choose another name') % state.project_name,
                     style=wx.OK|wx.ICON_ERROR );
             return False
 
