@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -11,9 +11,12 @@
 
 '''
 import os
-import popen2
+import signal
+import subprocess
 import xml.sax.saxutils
 
+__sigchld_handler_installed = False
+
 def getTerminalProgramList():
     return ['Terminal','iTerm']
 
@@ -23,7 +26,7 @@ def getFileBrowserProgramList():
 def GuiDiffFiles( app, options ):
     cmd_line = "'%s' %s &" % (app.prefs.getDiffTool().gui_diff_tool, options)
     app.log.info( cmd_line )
-    os.system( cmd_line )
+    __run_command_with_output( cmd_line )
 
 def ShellDiffFiles( app, options ):
     cmd_line = "'%s' %s" % (app.prefs.getDiffTool().shell_diff_tool, options)
@@ -52,11 +55,11 @@ def EditFile( app, project_info, filename ):
         os.chdir( cur_dir )
 
 def ShellOpen( app, project_info, filename ):
-    app.log.info( 'Open %s' % filename )
+    app.log.info( T_('Open %s') % filename )
     cur_dir = os.getcwd()
     try:
         os.chdir( project_info.getWorkingDir() )
-        os.system( 'open "%s"' % filename )
+        __run_command_with_output( 'open "%s"' % filename )
     finally:
         os.chdir( cur_dir )
 
@@ -119,7 +122,7 @@ end
     command_line = '"osascript" "%s" &' % shell_script_filename
 
     app.log.info( command_line )
-    os.system( command_line )
+    __run_command_with_output( command_line )
 
 def CommandShell_Terminal( app, project_info ):
     shell_script_filename = os.path.join( '/tmp', 'wb.term' )
@@ -161,30 +164,80 @@ def CommandShell_Terminal( app, project_info ):
     command_line = '"open" "%s" &' % shell_script_filename
 
     app.log.info( command_line )
-    os.system( command_line )
+    __run_command_with_output( command_line )
 
 def FileBrowser( app, project_info ):
     command_line = 'open -a "Finder" "%s" &' % project_info.getWorkingDir()
 
     app.log.info( command_line )
-    os.system( command_line )
+    __run_command_with_output( command_line )
+
+def __sigchld_handler( signum, frame ):
+    try:
+        while True:
+            pid, status = os.waitpid( -1, os.WNOHANG )
+            if pid == 0:
+                break
+
+    except OSError, e:
+        pass
+
+def _run_command( command_line ):
+    err_prefix = 'Error running %s' % command_line
+
+    # install the sig child handler to get rid of the zomie processes
+    global __sigchld_handler_installed
+    if not __sigchld_handler_installed:
+        signal.signal( signal.SIGCHLD, __sigchld_handler )
+        __sigchld_handler_installed = True
+
+    try:
+        proc = subprocess.Popen(
+                    command_line,
+                    shell=True,
+                    close_fds=True,
+                    stdin=subprocess.PIPE,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT
+                    )
+
+        output = proc.stdout.read()
+        rc = proc.wait()
+
+    except EnvironmentError, e:
+        print '%s - %s' % (err_prefix, str(e))
+        return
+
+    # check for OK
+    if os.WIFEXITED( rc ):
+        print output
+        return
+
+    # some error
+    print '%s, rc=%d' % (err_prefix, rc)
 
 def __run_command_with_output( command_line ):
-    print 'command_line',command_line
     err_prefix = 'error running %s' % command_line
+
     try:
-        proc = popen2.Popen3( '%s 2>&1' % command_line )
-        output = proc.fromchild.read()
+        proc = subprocess.Popen(
+                    command_line,
+                    shell=True,
+                    close_fds=True,
+                    stdin=subprocess.PIPE,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT
+                    )
+
+        output = proc.stdout.read()
         rc = proc.wait()
+
     except EnvironmentError, e:
         return '%s - %s' % (err_prefix, str(e))
 
-    return __run_command_with_output_error_return( err_prefix, rc, output )
-
-def __run_command_with_output_error_return( prefix, rc, output ):
     # check for OK
     if os.WIFEXITED( rc ):
         return output
 
     # some error
-    return '%s, rc=%d' % (prefix, rc)
+    return '%s, rc=%d' % (err_prefix, rc)
