@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -12,12 +12,12 @@
 '''
 import os
 import signal
-import popen2
+import subprocess
 
 __sigchld_handler_installed = False
 
-gui_terminals = ['gnome-terminal','konsole','xterm']
-gui_file_browsers = ['nautilus','konqueror']
+gui_terminals = ['gnome-terminal', 'konsole', 'xterm', 'xfce4-terminal']
+gui_file_browsers = ['nautilus', 'konqueror', 'thunar']
 
 def getTerminalProgramList():
     return gui_terminals[:]
@@ -48,7 +48,7 @@ def EditFile( app, project_info, filename ):
         os.chdir( cur_dir )
 
 def ShellOpen( app, project_info, filename ):
-    app.log.info( 'Open %s' % filename )
+    app.log.info( T_('Open %s') % filename )
     cur_dir = os.getcwd()
     try:
         os.chdir( project_info.getWorkingDir() )
@@ -106,7 +106,7 @@ def CommandShell( app, project_info ):
     if terminal_program == 'konsole':
         __run_command( app, terminal_program,
             ['-T',  ' '.join( title ), '--workdir', working_dir, '-e', shell_script_filename] )
-    elif terminal_program == 'gnome-terminal':
+    elif terminal_program in ('gnome-terminal', 'xfce4-terminal'):
         __run_command( app, terminal_program,
             ['--title',  ' '.join( title ), '--working-directory', working_dir, '-x', shell_script_filename] )
     elif terminal_program == 'xterm':
@@ -132,7 +132,7 @@ def FileBrowser( app, project_info ):
 
     if browser_program == 'konsole':
         __run_command( app, browser_program, ['--mimetype', 'inode/directory', project_info.getWorkingDir()] )
-    elif browser_program == 'nautilus':
+    elif browser_program in ('nautilus', 'thunar'):
         __run_command( app, browser_program, [project_info.getWorkingDir()] )
 
 def __run_command( app, cmd, args ):
@@ -163,29 +163,35 @@ def __run_command( app, cmd, args ):
 def __sigchld_handler( signum, frame ):
     try:
         while True:
-            pid, status = os.waitpid( 0, os.WNOHANG )
+            pid, status = os.waitpid( -1, os.WNOHANG )
             if pid == 0:
                 break
 
-    except OSError:
+    except OSError, e:
         pass
 
 def __run_command_with_output( command_line ):
     err_prefix = 'error running %s' % command_line
+
     try:
-        proc = popen2.Popen3( '%s 2>&1' % command_line )
-        all_lines = proc.fromchild.read()
+        proc = subprocess.Popen(
+                    command_line,
+                    shell=True,
+                    close_fds=True,
+                    stdin=subprocess.PIPE,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.STDOUT
+                    )
+
+        output = proc.stdout.read()
         rc = proc.wait()
+
     except EnvironmentError, e:
-        all_lines = []
         return '%s - %s' % (err_prefix, str(e))
 
-    return __run_command_with_output_error_return( err_prefix, rc, all_lines )
-
-def __run_command_with_output_error_return( prefix, rc, output ):
     # check for OK
     if os.WIFEXITED( rc ):
         return output
 
     # some error
-    return '%s, rc=%d' % (prefix, rc)
+    return '%s, rc=%d' % (err_prefix, rc)
