@@ -50,7 +50,7 @@ def ShellDiffFiles( app, options ):
     return __run_command_with_output( cmd_line )
 
 def ShellOpen( app, project_info, filename ):
-    app.log.info( 'Open %s' % filename )
+    app.log.info( T_('Open %s') % filename )
     try:
         win32api.ShellExecute( 0, 'open',
                     filename, '',
@@ -58,10 +58,12 @@ def ShellOpen( app, project_info, filename ):
                     win32con.SW_SHOWNORMAL )
     except win32api.error, e:
         if e[0] == 31:
-            app.log.error( 'Unable to shell open %s\n'
-                 'Is an application associated with this file type?' % filename )
+            app.log.error( T_('Unable to shell open %s\n'
+                 'Is an application associated with this file type?') % filename )
         else:
-            app.log.error( 'Unable to shell open %s - %s' % (filename, e[2]) )
+            app.log.error( T_('Unable to shell open %(filename)s - %(error)s') %
+                            {'filename': filename
+                            ,'error': e[2]} )
 
 def CommandShell( app, project_info ):
     shell_script_filename = os.path.join( os.environ['TEMP'], 'wb_shell_tmp.cmd' )
@@ -117,20 +119,25 @@ def CreateProcess( app, command_line, current_dir ):
             si                  # startupinfo
             )
     except win32process.error, detail:
-        app.log.error( 'Create process failed for command - %s\n'
-                        'Reason %s' % (command_line, detail) )
+        app.log.error( T_('Create process failed for command - %(command)s\n'
+                        'Reason %(reason)s') %
+                            {'command': command_line
+                            ,'reason': detail} )
 
 def ensureDirectory( app, current_dir ):
     if not os.path.exists( current_dir ):
         try:
             os.makedirs( current_dir )
-            app.log.info( 'Created directory %s' % current_dir )
-        except IOError, detail:
-            app.log.error( 'Create directory %s - %s' % (current_dir, detail) )
+            app.log.info( T_('Created directory %s') % current_dir )
+
+        except IOError, e:
+            app.log.error( T_('Create directory %(dir)s - %(error)s') %
+                            {'dir': current_dir
+                            ,'error': e} )
             return 0
 
     elif not os.path.isdir( current_dir ):
-        app.log.error( '%s is not a directory' % current_dir )
+        app.log.error( T_('%s is not a directory') % current_dir )
         return 0
 
     return 1
