@@ -56,6 +56,8 @@ class ProjectInfo:
         self.new_file_template_dir = ''
         self.menu_name = None
         self.menu_folder = ''
+        self.menu_folder2 = ''
+        self.menu_folder3 = ''
         self.use_background_colour = False
         self.background_colour = (255,255,255)
 
@@ -78,6 +80,12 @@ class ProjectInfo:
         if get_option.has( 'menu_folder' ):
             self.menu_folder = get_option.getstr( 'menu_folder' )
 
+        if get_option.has( 'menu_folder2' ):
+            self.menu_folder2 = get_option.getstr( 'menu_folder2' )
+
+        if get_option.has( 'menu_folder3' ):
+            self.menu_folder3 = get_option.getstr( 'menu_folder3' )
+
         if get_option.has( 'menu_name' ):
             self.menu_name = get_option.getstr( 'menu_name' )
 
@@ -104,7 +112,10 @@ class ProjectInfo:
 
         if self.menu_name is not None:
             pref_dict[ 'menu_name' ] = self.menu_name
+
         pref_dict[ 'menu_folder' ] = self.menu_folder
+        pref_dict[ 'menu_folder2' ] = self.menu_folder2
+        pref_dict[ 'menu_folder3' ] = self.menu_folder3
 
         if self.use_background_colour:
             pref_dict[ 'use_background_colour' ] = self.use_background_colour
