@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -11,13 +11,16 @@
 
 '''
 import wx
+import time
+import itertools
+
 import wb_images
 import wb_read_file
-import time
+import wb_subversion_utils
 
 class AnnotateFrame(wx.Frame):
     def __init__( self, app, project_info, filename, annotation ):
-        wx.Frame.__init__( self, None, -1, "Annotation of %s" % filename )
+        wx.Frame.__init__( self, None, -1, T_("Annotation of %s") % filename )
 
         self.panel = AnnotatePanel( self, app, project_info, filename, annotation )
 
@@ -51,11 +54,11 @@ class AnnotatePanel(wx.Panel):
 
         self.list_ctrl = wx.ListCtrl( self, self.id_list, wx.DefaultPosition, wx.DefaultSize, wx.LC_REPORT|wx.NO_BORDER)
 
-        self.list_ctrl.InsertColumn( self.col_line, "Line")
-        self.list_ctrl.InsertColumn( self.col_revision, "Revision")
-        self.list_ctrl.InsertColumn( self.col_author, "Author")
-        self.list_ctrl.InsertColumn( self.col_date, "Date")
-        self.list_ctrl.InsertColumn( self.col_text, "Text")
+        self.list_ctrl.InsertColumn( self.col_line, T_("Line") )
+        self.list_ctrl.InsertColumn( self.col_revision, T_("Revision") )
+        self.list_ctrl.InsertColumn( self.col_author, T_("Author") )
+        self.list_ctrl.InsertColumn( self.col_date, T_("Date") )
+        self.list_ctrl.InsertColumn( self.col_text, T_("Text") )
 
         char_width = 9
         self.list_ctrl.SetColumnWidth( self.col_line, 6*char_width )
@@ -86,10 +89,20 @@ class AnnotatePanel(wx.Panel):
 
         encoding = wb_read_file.encodingFromContents( self.annotation[0]['line'] )
 
+        last_revision = None
+
+        all_row_colours = itertools.cycle(
+                        (wx.Colour( 0xff, 0xff, 0xff )
+                        ,wx.Colour( 0xf8, 0xf8, 0xf8 )
+                        ) )
+
+        row_colour = all_row_colours.next()
+
         for index, entry in enumerate( self.annotation ):
             raw_line = entry['line']
             try:
                 line = raw_line.decode( encoding )
+
             except UnicodeDecodeError:
                 # fall back to latin-1
                 try:
@@ -116,7 +129,23 @@ class AnnotatePanel(wx.Panel):
                 tab_expanded_line = line
 
             self.list_ctrl.InsertStringItem( index, str(entry['number']+1) )
-            self.list_ctrl.SetStringItem( index, self.col_revision, str(entry['revision'].number) )
-            self.list_ctrl.SetStringItem( index, self.col_author, entry['author'] )
-            self.list_ctrl.SetStringItem( index, self.col_date, entry['date'] )
+
+            if entry['revision'].number <= 0:
+                revision = ' - '
+            else:
+                revision = str( entry['revision'].number )
+
+            if revision != last_revision:
+                # Only populate Revision, Author, Date columns when revision number changes.
+                last_revision = revision
+                row_colour = all_row_colours.next()
+
+                entry_date = time.strptime( entry['date'].split('.')[0], '%Y-%m-%dT%H:%M:%S' )
+
+                self.list_ctrl.SetStringItem( index, self.col_revision, revision )
+                self.list_ctrl.SetStringItem( index, self.col_author, entry['author'] )
+                self.list_ctrl.SetStringItem( index, self.col_date, wb_subversion_utils.fmtDateTime( entry_date ) )
+
             self.list_ctrl.SetStringItem( index, self.col_text, tab_expanded_line )
+
+            self.list_ctrl.SetItemBackgroundColour( index, row_colour )
