@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2006-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -23,76 +23,81 @@ import wb_list_panel_common
 import wb_subversion_utils
 import wb_subversion_list_handler_common
 import wb_platform_specific
+import wb_dialogs
 
 id_exclude = wx.NewId()
 id_include = wx.NewId()
 
 class CheckinFrame(wx.Frame):
     def __init__( self, app, project_info, all_files ):
-        wx.Frame.__init__( self, None, -1, 'Check in for %s' % project_info.wc_path, size=(700,500) )
+        wx.Frame.__init__( self, None, -1, T_('Check in for %s') % project_info.wc_path, size=(700,500) )
 
         self.app = app
 
         self.menu_actions = wx.Menu()
-        self.menu_actions.Append(  wb_ids.id_File_Edit, 'Edit', 'Edit' )
+        self.menu_actions.Append(  wb_ids.id_File_Edit, T_('Edit'), T_('Edit') )
         if wx.Platform in ['__WXMSW__','__WXMAC__']:
-            self.menu_actions.Append(  wb_ids.id_Shell_Open, 'Open', 'Open' )
+            self.menu_actions.Append(  wb_ids.id_Shell_Open, T_('Open'), T_('Open') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBase, 'Diff WC vs. BASE...', 'Diff WC vs. BASE...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...', 'Diff WC vs. HEAD...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...', 'Diff WC vs. branch origin BASE...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...', 'Diff WC vs. branch origin HEAD...' )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBase, T_('Diff WC vs. BASE...'), T_('Diff WC vs. BASE...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...'), T_('Diff WC vs. HEAD...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...'), T_('Diff WC vs. branch origin BASE...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...'), T_('Diff WC vs. branch origin HEAD...') )
 
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Annotate, 'Annotate...', 'Annotate...' )
-        self.menu_actions.Append( wb_ids.id_SP_History, 'Log history...', 'Log history...' )
-        self.menu_actions.Append( wb_ids.id_SP_Info, 'Information...', 'Information...' )
-        self.menu_actions.Append( wb_ids.id_SP_Properties, 'Properties...', 'Properties...' )
+        self.menu_actions.Append( wb_ids.id_SP_Annotate, T_('Annotate...'), T_('Annotate...') )
+        self.menu_actions.Append( wb_ids.id_SP_History, T_('Log history...'), T_('Log history...') )
+        self.menu_actions.Append( wb_ids.id_SP_Info, T_('Information...'), T_('Information...') )
+        self.menu_actions.Append( wb_ids.id_SP_Properties, T_('Properties...'), T_('Properties...') )
 
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SelectAll, 'Select All', 'Select ALl' )
+        self.menu_actions.Append( wb_ids.id_SelectAll, T_('Select All'), T_('Select All') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( id_exclude, 'Exclude...', 'Exclude from check in' )
-        self.menu_actions.Append( id_include, 'Include...', 'Include from check in' )
+        self.menu_actions.Append( id_exclude, T_('Exclude...'), T_('Exclude from check in') )
+        self.menu_actions.Append( id_include, T_('Include...'), T_('Include from check in') )
 
         self.menu_bar = wx.MenuBar()
-        self.menu_bar.Append( self.menu_actions, "&Actions" )
+        self.menu_bar.Append( self.menu_actions, T_('&Actions') )
 
         self.SetMenuBar( self.menu_bar )
 
         # Add tool bar
-        t = self.CreateToolBar( name="main",
+        t = self.CreateToolBar( name='main',
                                 style=wx.TB_HORIZONTAL ) # | wx.NO_BORDER | wx.TB_TEXT )
 
         bitmap_size = (32,32)
         t.SetToolBitmapSize( bitmap_size )
         t.AddSimpleTool( wb_ids.id_File_Edit,
             wb_images.getBitmap( 'toolbar_images/edit.png', bitmap_size ),
-            'Edit File', 'Edit File' )
+            T_('Edit File'), T_('Edit File') )
         if wx.Platform in ['__WXMSW__','__WXMAC__']:
             t.AddSimpleTool( wb_ids.id_Shell_Open,
                 wb_images.getBitmap( 'toolbar_images/open.png', bitmap_size ),
-                'Open File', 'Open File' )
+                T_('Open File'), T_('Open File') )
         t.AddSeparator()
         t.AddSimpleTool( wb_ids.id_SP_DiffWorkBase,
             wb_images.getBitmap( 'toolbar_images/diff.png', bitmap_size ),
-            'Diff changes against base', 'Diff changes against base' )
+            T_('Diff changes against base'), T_('Diff changes against base') )
         t.AddSimpleTool( wb_ids.id_SP_History,
             wb_images.getBitmap( 'toolbar_images/history.png', bitmap_size ),
-            'Show History log', 'Show History log' )
+            T_('Show History log'), T_('Show History log') )
         t.AddSimpleTool( wb_ids.id_SP_Info,
             wb_images.getBitmap( 'toolbar_images/info.png', bitmap_size ),
-            'File Information', 'File Information' )
+            T_('File Information'), T_('File Information') )
         t.AddSimpleTool( wb_ids.id_SP_Properties,
             wb_images.getBitmap( 'toolbar_images/property.png', bitmap_size ),
-            'File Properties', 'File Properties' )
+            T_('File Properties'), T_('File Properties') )
+        t.AddSeparator()
+        t.AddSimpleTool( wb_ids.id_SP_Revert,
+            wb_images.getBitmap( 'toolbar_images/revert.png', bitmap_size ),
+            T_('Revert'), T_('Revert selected Files and Folders') )
         t.AddSeparator()
         t.AddSimpleTool( id_exclude,
             wb_images.getBitmap( 'toolbar_images/exclude.png', bitmap_size ),
-            'Exclude from check in', 'Exclude from check in' )
+            T_('Exclude from check in'), T_('Exclude from check in') )
         t.AddSimpleTool( id_include,
             wb_images.getBitmap( 'toolbar_images/include.png', bitmap_size ),
-            'Include in check in', 'Include in check in' )
+            T_('Include in check in'), T_('Include in check in') )
         t.Realize()
 
 
@@ -125,14 +130,14 @@ class CheckinFrame(wx.Frame):
         self.v_sizer = wx.BoxSizer( wx.VERTICAL )
         self.h_sizer = wx.BoxSizer( wx.HORIZONTAL )
 
-        self.label_ctrl = wx.StaticText( self.panel_log, -1, 'Log message', style=wx.ALIGN_LEFT )
+        self.label_ctrl = wx.StaticText( self.panel_log, -1, T_('Log message'), style=wx.ALIGN_LEFT )
         self.log_message_ctrl = wx.TextCtrl( self.panel_log, -1, style=wx.TE_MULTILINE )
 
-        self.button_ok = wx.Button( self.panel_log, wx.ID_OK, " Check In " )
-        self.button_cancel = wx.Button( self.panel_log, wx.ID_CANCEL, " Cancel " )
+        self.button_ok = wx.Button( self.panel_log, wx.ID_OK, T_(' Check In ') )
+        self.button_cancel = wx.Button( self.panel_log, wx.ID_CANCEL, T_(' Cancel ') )
         self.button_ok.SetDefault()
 
-        self.button_last_log_message = wx.Button( self.panel_log, -1, "Insert Last Message" )
+        self.button_last_log_message = wx.Button( self.panel_log, -1, T_('Insert Last Message') )
         self.button_last_log_message.Enable( len(self.last_log_message_text) > 0 )
         self.h_sizer.Add( self.button_last_log_message )
 
@@ -179,6 +184,7 @@ class CheckinFrame(wx.Frame):
         wx.EVT_MENU( self, wb_ids.id_SP_History, self.app.eventWrapper( self.OnSpHistory ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Info, self.app.eventWrapper( self.OnSpInfo ) )
         wx.EVT_MENU( self, wb_ids.id_SP_Properties, self.app.eventWrapper( self.OnSpProperties ) )
+        wx.EVT_MENU( self, wb_ids.id_SP_Revert, self.app.eventWrapper( self.OnSpRevert) )
 
         wx.EVT_MENU( self, wb_ids.id_SelectAll, self.app.eventWrapper( self.OnSelectAll ) )
 
@@ -233,32 +239,39 @@ class CheckinFrame(wx.Frame):
             pass
 
         all_filenames = self.list_handler.getCheckinFiles()
-        self.app.setAction( 'Check in %s...' % self.project_info.wc_path )
-        self.app.setProgress( 'Sent %(count)d of %(total)d', len( all_filenames ) )
+        self.app.setAction( T_('Check in %s...') % self.project_info.wc_path )
+        self.app.setProgress( T_('Sent %(count)d of %(total)d'), len( all_filenames ) )
 
         yield self.app.backgroundProcess
 
         ok = False
         try:
-            rev = self.project_info.client_bg.checkin( all_filenames, message )
+            commit_info = self.project_info.client_bg.checkin( all_filenames, message )
             ok = True
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
         yield self.app.foregroundProcess
 
-        if ok:
-            if rev:
-                self.app.log.info( 'Checkin created revision %d' % rev.number )
-            else:
-                self.app.log.warning( 'No changes to checkin ' )
-
         self.app.refreshFrame()
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.clearProgress()
 
         self.Destroy()
 
+        if ok:
+            rev = commit_info['revision']
+            if rev:
+                self.app.log.info( T_('Checkin created revision %d') % rev.number )
+            else:
+                self.app.log.warning( T_('No changes to checkin ') )
+
+            post_commit_err = commit_info['post_commit_err']
+            if post_commit_err is not None:
+                self.app.log.error( post_commit_err )
+                wx.MessageBox( post_commit_err, (T_('Post commit error')),
+                                style=wx.OK|wx.ICON_ERROR )
+
     # command events
     def OnFileEdit( self, event ):
         return self.panel_list.OnFileEdit()
@@ -290,29 +303,53 @@ class CheckinFrame(wx.Frame):
     def OnSpProperties( self, event ):
         return self.panel_list.OnSpProperties()
 
+    def OnSpRevert( self, event ):
+        self.Hide()
+        # Invoke the revert handler
+        result = self.panel_list.OnSpRevert()
+
+        # If all files have been reverted, don't show the checkin box.
+        if len(self.project_info.all_files) == 0:
+            wx.MessageBox( T_('There are no changes to check in'),
+                T_('Warning'), style=wx.OK|wx.ICON_EXCLAMATION )
+            self.Destroy()
+        else:    
+            # Redraw the panel
+            self.panel_list.drawList()
+            self.Show()
+
+        # update the main frame
+        self.app.refreshFrame()
+
+        return result
+    
 class CheckinListHandler(wb_subversion_list_handler_common.SubversionListHandlerCommon):
     def __init__( self, app, parent, project_info ):
         wb_subversion_list_handler_common.SubversionListHandlerCommon.__init__( self, app, parent, project_info )
 
         self.all_excluded_files = {}
-
+        self.__parent = parent
+        
     def getContextMenu( self ):
-        menu_template = \
-            [('', wb_ids.id_File_Edit, 'Edit' )]
+        menu_template = [
+            ('', wb_ids.id_File_Edit, T_('Edit') )
+            ]
         if wx.Platform in ['__WXMSW__','__WXMAC__']:
-            menu_template += \
-                [('', wb_ids.id_Shell_Open, 'Open' )]
-        menu_template += \
-            [('-', 0, 0 )
-            ,('', wb_ids.id_SP_DiffWorkBase, 'Diff WC vs. BASE...' )
-            ,('', wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...' )
-            ,('', wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...' )
-            ,('', wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...' )
-            ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_Annotate, 'Annotate...' )
-            ,('', wb_ids.id_SP_History, 'Log history...' )
-            ,('', wb_ids.id_SP_Info, 'Information...' )
-            ,('', wb_ids.id_SP_Properties, 'Properties...' )
+            menu_template += [
+                ('', wb_ids.id_Shell_Open, T_('Open') )
+                ]
+        menu_template += [
+            ('-', 0, 0 ),
+            ('', wb_ids.id_SP_DiffWorkBase, T_('Diff WC vs. BASE...') ),
+            ('', wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...') ),
+            ('', wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...') ),
+            ('', wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...') ),
+            ('-', 0, 0 ),
+            ('', wb_ids.id_SP_Annotate, T_('Annotate...') ),
+            ('', wb_ids.id_SP_History, T_('Log history...') ),
+            ('', wb_ids.id_SP_Info, T_('Information...') ),
+            ('', wb_ids.id_SP_Properties, T_('Properties...') ),
+            ('', wb_ids.id_SP_Revert, T_('Revert...') ),
             ]
 
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_template )
@@ -336,6 +373,32 @@ class CheckinListHandler(wb_subversion_list_handler_common.SubversionListHandler
         return [entry.path for entry in self.project_info.all_files
                 if entry.path not in self.all_excluded_files]
 
+    def Cmd_File_Revert( self, all_rows ):
+        # Pop up a confirm dialog box.
+        dialog = wb_dialogs.ConfirmAction( self.__parent, T_('Revert'), self.getStatusAndFilenames( all_rows ) )
+        result = dialog.ShowModal()
+        if result != wx.ID_OK:
+            return
+
+        try:
+            #Revert each file
+            for filename in [self.getFilename( row ) for row in all_rows]:
+                self.project_info.client_fg.revert( filename )
+        except pysvn.ClientError, e:
+            self.app.log_client_error( e )
+
+         # Build up a list of files that are still dirty.
+        all_files = self.project_info.client_bg.status(
+            self.project_info.wc_path,
+            recurse=True, get_all=False,
+            ignore=True, update=False )
+        all_files = [entry for entry in all_files
+                        if wb_subversion_utils.wc_status_checkin_map[ entry.text_status ]
+                        or wb_subversion_utils.wc_status_checkin_map[ entry.prop_status ]]       
+
+        # Set the project files to be this new list
+        self.project_info.all_files = all_files
+            
 class CheckinProjectInfo:
     def __init__( self, project_info, all_files ):
         self.all_files = all_files
