@@ -15,7 +15,6 @@ import wx.lib.splitter
 import wx.calendar
 
 import os
-import tempfile
 import time
 import types
 
@@ -24,10 +23,12 @@ import pysvn
 import wb_images
 import wb_subversion_utils
 import wb_subversion_diff
+import wb_subversion_annotate
 import wb_config
 
 id_view_cmd = wx.NewId()
 id_diff_cmd = wx.NewId()
+id_annotate_cmd = wx.NewId()
 id_revision_changes_cmd = wx.NewId()
 id_list = wx.NewId()
 id_paths = wx.NewId()
@@ -67,11 +68,11 @@ class LogEntry:
         if self.label != '':
             return True
 
-        if filter_field == 'Author':
+        if filter_field == T_('Author'):
             return filter_text.lower() in self.author.lower()
-        elif filter_field == 'Comment':
+        elif filter_field == T_('Comment'):
             return filter_text.lower() in self.message.lower()
-        elif filter_field == 'Path':
+        elif filter_field == T_('Path'):
             for changed_path in self.changed_paths:
                 if filter_text.lower() in changed_path.path.lower():
                     return True
@@ -179,7 +180,7 @@ def __findTaggedUrl( all_history_entries, tag_revnum ):
 
 class LogHistoryDialog(wx.Dialog):
     def __init__( self, app, parent ):
-        wx.Dialog.__init__( self, parent, -1, 'Log History' )
+        wx.Dialog.__init__( self, parent, -1, T_('Log History') )
 
         p = app.prefs.getLogHistory()
 
@@ -190,13 +191,13 @@ class LogHistoryDialog(wx.Dialog):
         is_show_limit = p.default_mode == 'show_limit'
         is_show_since = p.default_mode == 'show_since'
 
-        self.all_radio = wx.RadioButton( self, -1, 'Show all entries' )
+        self.all_radio = wx.RadioButton( self, -1, T_('Show all entries') )
         self.all_radio.SetValue( is_show_all )
 
         self.g_sizer.Add( self.all_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( (0,0), 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
-        self.limit_radio = wx.RadioButton( self, -1, 'Show only:' )
+        self.limit_radio = wx.RadioButton( self, -1, T_('Show only:') )
         self.limit_radio.SetValue( is_show_limit )
         self.limit_text = wx.TextCtrl( self, -1, str(p.default_limit), style=wx.TE_RIGHT )
         self.limit_text.Enable( is_show_limit )
@@ -207,7 +208,7 @@ class LogHistoryDialog(wx.Dialog):
         self.date = wx.DateTime_Now()
         self.date.SubtractDS( wx.DateSpan( days=p.default_since_days_interval ) )
 
-        self.since_radio = wx.RadioButton( self, -1, 'Show since:' )
+        self.since_radio = wx.RadioButton( self, -1, T_('Show since:') )
         self.since_radio.SetValue( is_show_since )
         self.since_date = wx.calendar.CalendarCtrl( self, -1,
                                 self.date,
@@ -217,16 +218,16 @@ class LogHistoryDialog(wx.Dialog):
         self.g_sizer.Add( self.since_radio, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT|wx.ALIGN_TOP, 3 )
         self.g_sizer.Add( self.since_date, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
-        self.tags_label = wx.StaticText( self, -1, 'Include tags: ', style=wx.ALIGN_RIGHT)
-        self.tags_ctrl = wx.CheckBox( self, -1, 'Include tags in log history' )
+        self.tags_label = wx.StaticText( self, -1, T_('Include tags: '), style=wx.ALIGN_RIGHT)
+        self.tags_ctrl = wx.CheckBox( self, -1, T_('Include tags in log history') )
         self.tags_ctrl.SetValue( p.default_include_tags )
 
         self.g_sizer.Add( self.tags_label, 1, wx.EXPAND|wx.ALL, 3 )
         self.g_sizer.Add( self.tags_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (150, 20), 1, wx.EXPAND )
@@ -308,7 +309,7 @@ class LogHistoryDialog(wx.Dialog):
 
 class HistoryFileFrame(wx.Frame):
     def __init__( self, app, project_info, filename, url, all_log_entries ):
-        wx.Frame.__init__( self, None, -1, "History of %s" % filename, size=(700,500) )
+        wx.Frame.__init__( self, None, -1, T_("History of %s") % filename, size=(700,500) )
 
         self.panel = LogHistoryPanel( self, app, project_info, filename, url, all_log_entries )
 
@@ -327,7 +328,7 @@ class HistoryFileFrame(wx.Frame):
 
 class HistoryDirFrame(wx.Frame):
     def __init__( self, app, project_info, filename, url, all_log_entries ):
-        wx.Frame.__init__( self, None, -1, "History of %s" % filename, size=(700,500) )
+        wx.Frame.__init__( self, None, -1, T_("History of %s") % filename, size=(700,500) )
 
         self.panel = LogHistoryPanel( self, app, project_info, filename, url, all_log_entries )
 
@@ -373,7 +374,7 @@ class PanelFilter(wx.Panel):
 
         self.filter_changed_handler = None
 
-        self.filter_field_choices = ['Author','Comment','Path']
+        self.filter_field_choices = [ T_('Author'), T_('Comment'), T_('Path') ]
         self.filter_choice_ctrl = wx.Choice( self, wx.NewId(), choices=self.filter_field_choices )
         self.filter_choice_ctrl.SetSelection( self.filter_field_choices.index( filter_field ) )
         if wx.Platform == '__WXMAC__':
@@ -463,7 +464,7 @@ class LogHistoryPanel:
         # run from recent to old
         self.all_log_entries.sort( self.by_rev )
 
-        self.filter_field = 'Comment'
+        self.filter_field = T_('Comment')
         self.filter_text = ''
         self.all_filtered_log_entries = all_log_entries
 
@@ -498,11 +499,11 @@ class LogHistoryPanel:
         self.list_ctrl.SetFocus()
         self.all_item_attr = {}
 
-        self.list_ctrl.InsertColumn( self.col_revision, "Revision" )
-        self.list_ctrl.InsertColumn( self.col_author, "Author" )
-        self.list_ctrl.InsertColumn( self.col_date, "Date" )
-        self.list_ctrl.InsertColumn( self.col_label, "Label" )
-        self.list_ctrl.InsertColumn( self.col_message, "Message" )
+        self.list_ctrl.InsertColumn( self.col_revision, T_("Revision") )
+        self.list_ctrl.InsertColumn( self.col_author, T_("Author") )
+        self.list_ctrl.InsertColumn( self.col_date, T_("Date") )
+        self.list_ctrl.InsertColumn( self.col_label, T_("Label") )
+        self.list_ctrl.InsertColumn( self.col_message, T_("Message") )
 
         char_width = 9
         self.list_ctrl.SetColumnWidth( self.col_revision, 7*char_width )
@@ -517,10 +518,10 @@ class LogHistoryPanel:
 
         self.paths_ctrl = wx.ListCtrl( self.panel_changed_paths, id_paths, wx.DefaultPosition, wx.DefaultSize, wx.LC_REPORT|wx.NO_BORDER)
 
-        self.paths_ctrl.InsertColumn( self.col_action, "Action" )
-        self.paths_ctrl.InsertColumn( self.col_path, "Path" )
-        self.paths_ctrl.InsertColumn( self.col_copyfrom_revision, "Copied Revision" )
-        self.paths_ctrl.InsertColumn( self.col_copyfrom_path, "Copied from" )
+        self.paths_ctrl.InsertColumn( self.col_action, T_("Action") )
+        self.paths_ctrl.InsertColumn( self.col_path, T_("Path") )
+        self.paths_ctrl.InsertColumn( self.col_copyfrom_revision, T_("Copied Revision") )
+        self.paths_ctrl.InsertColumn( self.col_copyfrom_path, T_("Copied from") )
 
         char_width = 9
         self.paths_ctrl.SetColumnWidth( self.col_action, 7*char_width )
@@ -530,9 +531,9 @@ class LogHistoryPanel:
 
         self.initButtons( self.v_sizer_history )
 
-        self.comment_label = wx.StaticText( self.panel_comment, -1, 'Comment' )
+        self.comment_label = wx.StaticText( self.panel_comment, -1, T_('Comment') )
 
-        self.paths_label = wx.StaticText( self.panel_changed_paths, -1, 'Changed Paths' )
+        self.paths_label = wx.StaticText( self.panel_changed_paths, -1, T_('Changed Paths') )
 
         self.v_sizer_history.Add( self.panel_filter, 0, wx.EXPAND|wx.ALL, 0 )
         self.v_sizer_history.Add( self.list_ctrl, 2, wx.EXPAND|wx.ALL, 5 )
@@ -619,24 +620,28 @@ class LogHistoryPanel:
         #self.button_view = wx.Button( self.panel_history, id_view_cmd, " View " )
         #self.button_view.Enable( False )
 
-        self.button_diff = wx.Button( self.panel_history, id_diff_cmd, " Diff " )
+        self.button_diff = wx.Button( self.panel_history, id_diff_cmd, T_('Diff') )
         self.button_diff.Enable( False )
-        self.button_revision_changes = wx.Button( self.panel_history, id_revision_changes_cmd, " Revision Changes " )
+        self.button_annotate = wx.Button( self.panel_history, id_annotate_cmd, T_('Annotate') )
+        self.button_annotate.Enable( False )
+        self.button_revision_changes = wx.Button( self.panel_history, id_revision_changes_cmd, T_('Revision Changes') )
         self.button_revision_changes.Enable( False )
 
-
         # leave View off screen until its implemented
         #self.h_sizer.Add( self.button_view, 0, wx.EXPAND|wx.LEFT, 5 )
         self.h_sizer.Add( self.button_diff, 0, wx.EXPAND|wx.LEFT, 5 )
+        self.h_sizer.Add( self.button_annotate, 0, wx.EXPAND|wx.LEFT, 5 )
         self.h_sizer.Add( self.button_revision_changes, 0, wx.EXPAND|wx.LEFT, 5 )
 
         sizer.Add( self.h_sizer, 0, wx.EXPAND|wx.ALL, 5 )
 
         wx.EVT_BUTTON( self.panel_history, id_view_cmd, self.OnViewCommand )
         wx.EVT_BUTTON( self.panel_history, id_diff_cmd, self.OnDiffCommand )
+        wx.EVT_BUTTON( self.panel_history, id_annotate_cmd, self.OnAnnotateCommand )
         wx.EVT_BUTTON( self.panel_history, id_revision_changes_cmd, self.OnRevisionChangesCommand )
 
         wx.EVT_UPDATE_UI( self.panel_history, id_diff_cmd, self.OnUpdateUiDiffCommand )
+        wx.EVT_UPDATE_UI( self.panel_history, id_annotate_cmd, self.OnUpdateUiAnnotateCommand )
         wx.EVT_UPDATE_UI( self.panel_history, id_revision_changes_cmd, self.OnUpdateUiRevisionChangesCommand )
 
     def getSelectedRows( self ):
@@ -716,7 +721,7 @@ class LogHistoryPanel:
 
     #---------- Command handlers ----------------------------------------------------------
     def OnViewCommand( self, event ):
-        print 'Log history View not implemented'
+        print T_('Log history View not implemented')
 
     def OnUpdateUiDiffCommand( self, event ):
         all_rows = self.getSelectedRows()
@@ -772,6 +777,45 @@ class LogHistoryPanel:
                     # no problem all done
                     break
 
+    def OnUpdateUiAnnotateCommand( self, event ):
+        all_rows = self.getSelectedRows()
+        self.button_annotate.Enable( len( all_rows ) in (1,2) )
+
+    def OnAnnotateCommand( self, event ):
+        indices = self.getSelectedRows()
+
+        indices.sort()
+
+        if len( indices ) not in (1,2):
+            return
+
+        if len( indices ) == 2:
+            rev_start = pysvn.Revision( pysvn.opt_revision_kind.number,
+                                    self.all_filtered_log_entries[ indices[1] ].rev_number )
+            rev_end = pysvn.Revision( pysvn.opt_revision_kind.number,
+                                    self.all_filtered_log_entries[ indices[0] ].rev_number )
+
+        elif len( indices ) == 1:
+            rev_start = pysvn.Revision( pysvn.opt_revision_kind.number, 0 )
+            rev_end = pysvn.Revision( pysvn.opt_revision_kind.number,
+                                    self.all_filtered_log_entries[ indices[0] ].rev_number )
+
+        try:
+            annotation = self.project_info.client_fg.annotate(
+                            url_or_path=self.filename,
+                            revision_start=rev_start,
+                            revision_end=rev_end,
+                            peg_revision=rev_end )
+
+        except pysvn.ClientError, e:
+            self.app.log_client_error( e )
+            return
+
+        h_frame = wb_subversion_annotate.AnnotateFrame( self.app, self.project_info, self.filename, annotation )
+        h_frame.Show( True )
+
+
+
     def OnUpdateUiRevisionChangesCommand( self, event ):
         self.button_revision_changes.Enable( len( self.getSelectedRows() ) in (1, 2) )
 
@@ -859,10 +903,11 @@ class LogHistoryPanel:
                                 ,'text_status': pysvn.wc_status_kind.normal})
                     changed_states[repository_path] = status
             else:
-               self.app.log.info( 'Revision changes for r%d ignored. Its URL "%s" does not match r%d URL "%s".' %
-                                   ( log_entry.rev_number, log_entry.url, 
-                                     self.all_filtered_log_entries[row_indices[0]].rev_number,
-                                     self.all_filtered_log_entries[row_indices[0]].url ) )
+               self.app.log.info( T_('Revision changes for r%(rev1)d ignored. Its URL "%(url1)s" does not match r%(rev2)d URL "%(url2)s".') %
+                                    {'rev1': log_entry.rev_number
+                                    ,'url1': log_entry.url
+                                    ,'rev2': self.all_filtered_log_entries[row_indices[0]].rev_number
+                                    ,'url2': self.all_filtered_log_entries[row_indices[0]].url} )
 
         changed_files = [changed_states[status] for status in changed_states]
 
