@@ -36,47 +36,47 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
     def getContextMenu( self ):
         if self.project_info.need_checkout:
             menu_template = \
-                [('', wb_ids.id_SP_Checkout, 'Checkout' )]
+                [('', wb_ids.id_SP_Checkout, T_('Checkout') )]
         else:
             menu_template = \
-                [('', wb_ids.id_File_Edit, 'Edit' )]
+                [('', wb_ids.id_File_Edit, T_('Edit') )]
             if wx.Platform in ['__WXMSW__','__WXMAC__']:
                 menu_template += \
-                    [('', wb_ids.id_Shell_Open, 'Open' )]
+                    [('', wb_ids.id_Shell_Open, T_('Open') )]
             menu_template += \
                 [('-', 0, 0 )
-                ,('', wb_ids.id_SP_DiffWorkBase, 'Diff WC vs. BASE...' )
-                ,('', wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...' )
-                ,('', wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...' )
-                ,('', wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...' )
-                ,('>', wb_ids.id_SP_ConflictMenu, 'Conflict',
-                    [('', wb_ids.id_SP_DiffOldMine, 'Diff Conflict Old vs. Mine...' )
-                    ,('', wb_ids.id_SP_DiffMineNew, 'Diff Conflict Mine vs. New...' )
-                    ,('', wb_ids.id_SP_DiffOldNew, 'Diff Conflict Old vs. New...' )
+                ,('', wb_ids.id_SP_DiffWorkBase, T_('Diff WC vs. BASE...') )
+                ,('', wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...') )
+                ,('', wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...') )
+                ,('', wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...') )
+                ,('>', wb_ids.id_SP_ConflictMenu, T_('Conflict'),
+                    [('', wb_ids.id_SP_DiffOldMine, T_('Diff Conflict Old vs. Mine...') )
+                    ,('', wb_ids.id_SP_DiffMineNew, T_('Diff Conflict Mine vs. New...') )
+                    ,('', wb_ids.id_SP_DiffOldNew, T_('Diff Conflict Old vs. New...') )
                     ,('-', 0, 0 )
-                    ,('', wb_ids.id_SP_Resolved, 'Resolved Conflict' )
+                    ,('', wb_ids.id_SP_Resolved, T_('Resolved Conflict') )
                     ])
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Annotate, 'Annotate...' )
-                ,('', wb_ids.id_SP_History, 'Log history...' )
-                ,('', wb_ids.id_SP_Info, 'Information...' )
-                ,('', wb_ids.id_SP_Properties, 'Properties...' )
+                ,('', wb_ids.id_SP_Annotate, T_('Annotate...') )
+                ,('', wb_ids.id_SP_History, T_('Log history...') )
+                ,('', wb_ids.id_SP_Info, T_('Information...') )
+                ,('', wb_ids.id_SP_Properties, T_('Properties...') )
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Lock, 'Lock...' )
-                ,('', wb_ids.id_SP_Unlock, 'Unlock...' )
+                ,('', wb_ids.id_SP_Lock, T_('Lock...') )
+                ,('', wb_ids.id_SP_Unlock, T_('Unlock...') )
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Update, 'Update' )
-                ,('', wb_ids.id_SP_Update_To, 'Update to' )
+                ,('', wb_ids.id_SP_Update, T_('Update') )
+                ,('', wb_ids.id_SP_UpdateTo, T_('Update to..') )
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Checkin, 'Checkin...' )
+                ,('', wb_ids.id_SP_Checkin, T_('Checkin...') )
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Add, 'Add' )
-                ,('', wb_ids.id_SP_Rename, 'Rename...' )
+                ,('', wb_ids.id_SP_Add, T_('Add') )
+                ,('', wb_ids.id_SP_Rename, T_('Rename...') )
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Delete, 'Delete...' )
-                ,('', wb_ids.id_SP_Revert, 'Revert...' )
+                ,('', wb_ids.id_SP_Delete, T_('Delete...') )
+                ,('', wb_ids.id_SP_Revert, T_('Revert...') )
                 ,('-', 0, 0 )
-                ,('', wb_ids.id_SP_Cleanup, 'Clean up' )
+                ,('', wb_ids.id_SP_Cleanup, T_('Clean up') )
                 ]
 
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_template )
@@ -99,12 +99,12 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
     #------------------------------------------------------------
     def Cmd_File_EditCopy( self, all_rows ):
         self.app.setPasteData( wb_clipboard.Clipboard( [self.getFilename( row ) for row in all_rows], is_copy=True ) )
-        print 'Copied %d files to the Clipboard' % len(all_rows)
+        print T_('Copied %d files to the Clipboard') % len(all_rows)
         self.app.refreshFrame()
  
     def Cmd_File_EditCut( self, all_rows ):
         self.app.setPasteData( wb_clipboard.Clipboard( [self.getFilename( row ) for row in all_rows], is_copy=False ) )
-        print 'Cut %d files to the Clipboard' % len(all_rows)
+        print T_('Cut %d files to the Clipboard') % len(all_rows)
         self.app.refreshFrame()
 
     def Cmd_File_EditPaste( self, all_rows ):
@@ -127,9 +127,9 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
             return
 
         if paste_data.isCopy():
-            title = 'Paste Copy'
+            title = T_('Paste Copy')
         else:
-            title = 'Paste Move'
+            title = T_('Paste Move')
 
         confirmed, force = self.app.confirmForceAction( title, self.getStatusAndFilenames( all_status ) )
         if not confirmed:
@@ -145,9 +145,9 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
             new_filename = os.path.join( self.project_info.wc_path, basename )
 
             if paste_data.isCopy():
-                rename_title = 'Save As'
+                rename_title = T_('Save As')
             else:
-                rename_title = 'Rename'
+                rename_title = T_('Rename')
 
             while os.path.exists( new_filename ):
                 new_name, force = self.app.renameFile( rename_title, os.path.basename( old_filename ), None )
@@ -155,8 +155,12 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
                     return
                 new_filename = os.path.join( self.project_info.wc_path, new_name )
 
-            self.app.log.info( '%s: From %s' % (title, old_filename) )
-            self.app.log.info( '%s:   To %s' % (title, new_filename) )
+            self.app.log.info( T_('%(title)s: From %(filename)s') %
+                                {'title': title
+                                ,'filename': old_filename} )
+            self.app.log.info( T_('%(title)s:   To %(filename)s') %
+                                {'title': title
+                                ,'filename': new_filename} )
 
             is_controlled = self.isControlled( status )
 
@@ -216,8 +220,8 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
 
     def Cmd_File_Checkin( self, all_rows ):
         if len(all_rows) == 0:
-            wx.MessageBox( "There are no changes to check in",
-                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+            wx.MessageBox( T_("There are no changes to check in"),
+                T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
             return
 
         all_files = [self.all_files[ row ] for row in all_rows]
@@ -235,7 +239,7 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
         self.app.refreshFrame()
 
     def Cmd_File_Delete( self, all_rows ):
-        if not self.app.confirmAction( 'Delete File', self.getStatusAndFilenames( all_rows ) ):
+        if not self.app.confirmAction( T_('Delete File'), self.getStatusAndFilenames( all_rows ) ):
             return
 
         for filename, is_controlled, text_status, prop_status in [
@@ -316,7 +320,9 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
             all_prop_lists = self.project_info.client_fg.proplist( old_filename,
                             revision=pysvn.Revision( pysvn.opt_revision_kind.working ) )
             self.project_info.client_fg.revert( old_filename )
-            print 'Rename %s %s' % (old_filename, new_full_filename)
+            print( T_('Rename %(from)s %(to)s') %
+                    {'from': old_filename
+                    ,'to': new_full_filename} )
             os.rename( old_filename, new_full_filename )
             self.project_info.client_fg.add( new_full_filename )
 
@@ -338,19 +344,23 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
                     break
 
             if new_full_tmp_filename is None:
-                self.app.log.error( 'Failed to create tmp file for rename' )
+                self.app.log.error( T_('Failed to create tmp file for rename') )
             else:
                 # need to save and restore the props around the rename dance
                 all_props = self.project_info.client_fg.proplist( old_filename,
                                 revision=pysvn.Revision( pysvn.opt_revision_kind.working ) )
 
-                print 'Rename %s %s' % (old_filename, new_full_tmp_filename)
+                print( T_('Rename %(from)s %(to)s') %
+                        {'from': old_filename
+                        ,'to': new_full_tmp_filename} )
                 os.rename( old_filename, new_full_tmp_filename )
                 self.project_info.client_fg.revert( old_filename )
                 self.project_info.client_fg.move( old_filename, new_full_filename )
                 os.remove( new_full_filename )
 
-                print 'Rename %s %s' % (new_full_tmp_filename, new_full_tmp_filename)
+                print( T_('Rename %(from)s %(to)s') %
+                            {'from': new_full_tmp_filename
+                            ,'to': new_full_tmp_filename} )
                 os.rename( new_full_tmp_filename, new_full_filename )
 
                 if len(all_props) > 0:
@@ -366,14 +376,14 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
                     for row in all_rows]:
             old_name = os.path.basename( old_filename )
 
-            new_name, force = self.app.renameFile( "Rename", old_name, None )
+            new_name, force = self.app.renameFile( T_("Rename"), old_name, None )
 
             if new_name is None:
                 break
 
             if new_name != old_name:
                 new_full_filename = os.path.join( os.path.dirname( old_filename ), new_name )
-                print 'Rename',old_filename, new_full_filename
+                print T_('Rename'),old_filename, new_full_filename
                 try:
                     self.__moveFile( old_filename, new_full_filename, is_controlled, text_status, prop_status )
                 except pysvn.ClientError, e:
@@ -386,7 +396,7 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
         self.app.refreshFrame()
 
     def Cmd_File_Revert( self, all_rows ):
-        if not self.app.confirmAction( 'Revert', self.getStatusAndFilenames( all_rows ) ):
+        if not self.app.confirmAction( T_('Revert'), self.getStatusAndFilenames( all_rows ) ):
             return
 
         try:
@@ -397,7 +407,7 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
         self.app.refreshFrame()
 
     def Cmd_File_Resolved( self, all_rows ):
-        if not self.app.confirmAction( 'Resolved', self.getStatusAndFilenames( all_rows ) ):
+        if not self.app.confirmAction( T_('Resolved'), self.getStatusAndFilenames( all_rows ) ):
             return
 
         try:
@@ -409,19 +419,22 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
 
     # Cmd_File_Unlock= from SubversionListHandlerCommon
     def Cmd_File_Update( self, all_rows ):
-        self.app.setProgress( 'Updated %(count)d', 0 )
+        rev = pysvn.Revision( pysvn.opt_revision_kind.head )
+
+        self.app.setProgress( T_('Updated %(count)d'), 0 )
 
         self.project_info.initNotify()
 
         for filename in [self.getFilename( row ) for row in all_rows]:
-            self.app.setAction( 'Update %s...' % filename )
+            self.app.setAction( T_('Update %s...') % filename )
 
             yield self.app.backgroundProcess
 
             ok = False
             try:
-                rev_list = self.project_info.client_bg.update( filename, recurse=False )
+                rev_list = self.project_info.client_bg.update( filename, recurse=False, revision=rev )
                 ok = True
+
             except pysvn.ClientError, e:
                 self.app.log_client_error( e )
 
@@ -435,57 +448,74 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
                     basename = os.path.basename( filename )
                     count = self.app.getProgressValue( 'count' )
                     if count == 0:
-                        self.app.log.info( 'Updated %s to revision %d, no new updates' % (basename, rev.number) )
-                    elif count == 1:
-                        self.app.log.info( 'Updated %s to revision %d, 1 new update' % (basename, rev.number) )
+                        self.app.log.info( T_('Updated %(filename)s to revision %(rev)d, no new updates') %
+                                                {'filename': basename
+                                                ,'rev': rev.number} )
                     else:
-                        self.app.log.info( 'Updated %s to revision %d, %d new updates' % (basename, rev.number, count) )
+                        self.app.log.info( S_('Updated %(filename)s to revision %(rev)d, %(count)d new update', 
+                                              'Updated %(filename)s to revision %(rev)d, %(count)d new updates', count) %
+                                                {'filename': basename
+                                                ,'rev': rev.number
+                                                ,'count': count} )
 
-        if self.project_info.notification_of_files_in_conflict == 1:
-            wx.MessageBox( "%d file is in conflict" % self.project_info.notification_of_files_in_conflict,
-                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
-        elif self.project_info.notification_of_files_in_conflict > 1:
-            wx.MessageBox( "%d files are in conflict" % self.project_info.notification_of_files_in_conflict,
-                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+        if self.project_info.notification_of_files_in_conflict > 0:
+            wx.MessageBox( S_("%d file is in conflict", 
+                              "%d files are in conflict", self.project_info.notification_of_files_in_conflict) % self.project_info.notification_of_files_in_conflict,
+                T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
 
         self.app.clearProgress()
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
-    def Cmd_File_Update_To( self, all_rows ):
-        dialog = wb_dialogs.UpdateTo( None )
-        if dialog.ShowModal() == wx.ID_OK:
+    def Cmd_File_UpdateTo( self, all_rows ):
+        dialog = wb_dialogs.UpdateTo( None, T_('Update to revision') )
+        if dialog.ShowModal() != wx.ID_OK:
+            return
 
-            self.app.setProgress( 'Updated %(count)d', 0 )
+        rev = dialog.getRevision()
 
-            for filename in [self.getFilename( row ) for row in all_rows]:
-                self.app.setAction( 'Update %s...' % filename )
+        self.app.setProgress( T_('Updated %(count)d'), 0 )
 
-                yield self.app.backgroundProcess
+        self.project_info.initNotify()
 
-                ok = False
-                try:
-                    rev_list = self.project_info.client_bg.update( filename, False, dialog.getRevision() )
-                    ok = True
-                except pysvn.ClientError, e:
-                    self.app.log_client_error( e )
+        for filename in [self.getFilename( row ) for row in all_rows]:
+            self.app.setAction( T_('Update %s...') % filename )
 
-                yield self.app.foregroundProcess
+            yield self.app.backgroundProcess
 
-                if not ok:
-                    break
+            ok = False
+            try:
+                rev_list = self.project_info.client_bg.update( filename, recurse=False, revision=rev )
+                ok = True
 
-                for rev in rev_list:
-                    if rev.number > 0:
-                        basename = os.path.basename( filename )
-                        count = self.app.getProgressValue( 'count' )
-                        if count == 0:
-                            self.app.log.info( 'Updated %s to revision %d, no new updates' % (basename, rev.number) )
-                        elif count == 1:
-                            self.app.log.info( 'Updated %s to revision %d, 1 new update' % (basename, rev.number) )
-                        else:
-                            self.app.log.info( 'Updated %s to revision %d, %d new updates' % (basename, rev.number, count) )
+            except pysvn.ClientError, e:
+                self.app.log_client_error( e )
 
-            self.app.clearProgress()
-            self.app.setAction( 'Ready' )
-            self.app.refreshFrame()
+            yield self.app.foregroundProcess
+
+            if not ok:
+                break
+
+            for rev in rev_list:
+                if rev.number > 0:
+                    basename = os.path.basename( filename )
+                    count = self.app.getProgressValue( 'count' )
+                    if count == 0:
+                        self.app.log.info( T_('Updated %(filename)s to revision %(rev)d, no new updates') % 
+                                                {'filename': basename
+                                                ,'rev': rev.number} )
+                    else:
+                        self.app.log.info( S_('Updated %(filename)s to revision %(rev)d, %(count)d new update', 
+                                              'Updated %(filename)s to revision %(rev)d, %(count)d new updates', count) %
+                                                {'filename': basename
+                                                ,'rev': rev.number
+                                                ,'count': count} )
+
+        if self.project_info.notification_of_files_in_conflict > 0:
+            wx.MessageBox( S_("%d file is in conflict", 
+                              "%d files are in conflict", self.project_info.notification_of_files_in_conflict) % self.project_info.notification_of_files_in_conflict,
+                              T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
+
+        self.app.clearProgress()
+        self.app.setAction( T_('Ready') )
+        self.app.refreshFrame()
