@@ -11,7 +11,6 @@
 
 '''
 import os
-import tempfile
 import types
 
 import pysvn
@@ -29,22 +28,24 @@ import wb_subversion_diff
 import wb_config
 
 col_labels = [
-        ('Name',        25, 10, 100, wx.LIST_FORMAT_LEFT),
-        ('State',        4,  2,   8, wx.LIST_FORMAT_LEFT),
-        ('Date',        12,  4,  20, wx.LIST_FORMAT_RIGHT),
-        ('Rev',          4,  2,   8, wx.LIST_FORMAT_RIGHT),
-        ('Author',      10,  4,  80, wx.LIST_FORMAT_LEFT),
-#        ('Size',        6,  4,  10, wx.LIST_FORMAT_RIGHT),
-        ('Mimetype',    10,  6,  50, wx.LIST_FORMAT_LEFT),
-        ('EOL',         6,  2,  10, wx.LIST_FORMAT_LEFT),
-        ('Type',        4,  4,  10, wx.LIST_FORMAT_LEFT),
-        ('Lock Owner',  10,  4,  80, wx.LIST_FORMAT_LEFT),
-        ('Lock Comment',60,  10,  100, wx.LIST_FORMAT_LEFT),
+        ('Name',            U_('Name'),        25, 10, 100, wx.LIST_FORMAT_LEFT),
+        ('State',           U_('State'),        4,  2,   8, wx.LIST_FORMAT_LEFT),
+        ('Date',            U_('Date'),        12,  4,  20, wx.LIST_FORMAT_RIGHT),
+        ('Rev',             U_('Rev'),          4,  2,   8, wx.LIST_FORMAT_RIGHT),
+        ('Author',          U_('Author'),      10,  4,  80, wx.LIST_FORMAT_LEFT),
+#       ('Size',            U_('Size'),         6,  4,  10, wx.LIST_FORMAT_RIGHT),
+        ('Mimetype',        U_('Mimetype'),    10,  6,  50, wx.LIST_FORMAT_LEFT),
+        ('EOL',             U_('EOL'),          6,  2,  10, wx.LIST_FORMAT_LEFT),
+        ('Type',            U_('Type'),         4,  4,  10, wx.LIST_FORMAT_LEFT),
+        ('Lock Owner',      U_('Lock Owner'),  10,  4,  80, wx.LIST_FORMAT_LEFT),
+        ('Lock Comment',    U_('Lock Comment'),60, 10, 100, wx.LIST_FORMAT_LEFT),
         ]
 
 class ColumnInfo:
-    def __init__( self, name, width, min_width, max_width, alignment ):
+    def __init__( self, col_id, name, label, width, min_width, max_width, alignment ):
+        self.col_id = col_id
         self.name = name
+        self.label = label
         self.width = int(width)
         self.min_width = int(min_width)
         self.max_width = int(max_width)
@@ -54,11 +55,14 @@ class ColumnInfo:
 
 class ViewColumnInfo:
     def __init__( self ):
-        self.column_info = {}
+        self.column_info_by_name = {}
+        self.column_info_by_id = {}
         self.column_order = []
-        for col_info in col_labels:
-            name, width, min_width, max_width, alignment = col_info
-            self.column_info[ name ] = ColumnInfo( name, width, min_width, max_width, alignment )
+        for col_id, col_info in enumerate( col_labels ):
+            name, label, width, min_width, max_width, alignment = col_info
+            ci = ColumnInfo( col_id, name, label, width, min_width, max_width, alignment )
+            self.column_info_by_name[ name ] = ci
+            self.column_info_by_id[ col_id ] = ci
 
     def setFromPreferenceData( self, p ):
         self.setFrom( p.column_order[:], p.column_widths[:] )
@@ -70,13 +74,14 @@ class ViewColumnInfo:
             column_widths.insert( 0, '0' )
 
         for index, name in enumerate( column_order ):
-            if self.column_info.has_key( name ):
+            if self.column_info_by_name.has_key( name ):
                 if len(column_widths) > index:
                     try:
                         width = int(column_widths[index])
-                        if( width >= self.column_info[ name ].min_width
-                        and width <= self.column_info[ name ].max_width ):
-                            self.column_info[ name ].width = width
+                        info = self.column_info_by_name[ name ]
+                        if( width >= info.min_width
+                        and width <= info.max_width ):
+                            info.width = width
 
                     except ValueError:
                         pass
@@ -84,16 +89,22 @@ class ViewColumnInfo:
         self.setColumnOrder( column_order )
 
 
-    def getInfo( self, name ):
-        return self.column_info[ name ]
+    def getInfoByName( self, name ):
+        return self.column_info_by_name[ name ]
+
+    def getInfoById( self, col_id ):
+        return self.column_info_by_id[ col_id ]
+
+    def getNameById( self, col_id ):
+        return self.column_info_by_id[ col_id ].name
 
     def excludedInfo( self ):
-        return [info for info in self.column_info.values() if not info.included]
+        return [info for info in self.column_info_by_name.values() if not info.included]
 
     def setColumnOrder( self, column_order ):
         self.column_order = column_order[:]
         for index, name in enumerate( self.column_order ):
-            self.column_info[ name ].column = index
+            self.column_info_by_name[ name ].column = index
 
     def getColumnOrder( self ):
         return self.column_order
@@ -102,23 +113,23 @@ class ViewColumnInfo:
         return self.column_order[ col ]
 
     def getInfoByColumn( self, col ):
-        return self.column_info[ self.column_order[ col ] ]
+        return self.column_info_by_name[ self.column_order[ col ] ]
 
     def getColumnWidths( self ):
-        return [str(self.column_info[name].width) for name in self.column_order]
+        return [str(self.column_info_by_name[name].width) for name in self.column_order]
 
 class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
-    col_name = 'Name'
-    col_state = 'State'
-    col_date = 'Date'
-    col_revision = 'Rev'
-    col_author = 'Author'
-    col_type = 'Type'
-    col_size = 'Size'
-    col_mime_type = 'Mimetype'
-    col_eol_style = 'EOL'
-    col_lock_owner = 'Lock Owner'
-    col_lock_comment = 'Lock Comment'
+    col_name =          'Name'
+    col_state =         'State'
+    col_date =          'Date'
+    col_revision =      'Rev'
+    col_author =        'Author'
+    col_type =          'Type'
+    col_size =          'Size'
+    col_mime_type =     'Mimetype'
+    col_eol_style =     'EOL'
+    col_lock_owner =    'Lock Owner'
+    col_lock_comment =  'Lock Comment'
 
     def __init__( self, app, list_panel, project_info ):
         wb_list_panel_common.ListHandler.__init__( self, list_panel )
@@ -203,8 +214,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
         char_width = 11
         for index, name in enumerate( self.column_info.getColumnOrder() ):
-            info = self.column_info.getInfo( name )
-            g.InsertColumn( index, info.name, info.alignment, info.width*char_width )
+            info = self.column_info.getInfoByName( name )
+            g.InsertColumn( index, T_(info.label), info.alignment, info.width*char_width )
             if name in [self.col_mime_type, self.col_eol_style]:
                 need_properties = True
 
@@ -241,10 +252,10 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
         prefix_len = len( self.project_info.wc_path ) + 1
         if len(filter_text) > 0:
-            if filter_field == 'Name':
+            if filter_field ==  T_('Name'):
                 self.all_files = [f for f in self.project_info.getFilesStatus()
                             if filter_text.lower() in f.path[prefix_len:].lower()]
-            elif filter_field == 'Author':
+            elif filter_field ==  T_('Author'):
                 self.all_files = [f for f in self.project_info.getFilesStatus()
                             if f.entry is not None and filter_text.lower() in f.entry.commit_author.lower()]
         else:
@@ -346,9 +357,9 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         if self.project_info.need_checkout:
             if column == self.col_name:
                 if self.isProjectParent():
-                    return 'Use the Checkout command to fetch files'
+                    return T_('Use the Checkout command to fetch files')
                 else:
-                    return 'Use the Update command to fetch files'
+                    return T_('Use the Update command to fetch files')
             else:
                 return ''
 
@@ -519,6 +530,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         state.conflict = True
         state.file_exists = True
         state.is_folder = True
+        state.revertable = True
 
         for row in all_rows:
             filename = self.all_files[ row ].path
@@ -530,6 +542,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                 state.modified = False
                 state.conflict = False
                 state.file_exists = False
+                state.revertable = False
             else:
                 state.is_folder = False
 
@@ -540,24 +553,43 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
             if text_status not in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
                 state.unversioned = False
 
-            state.new_versioned = state.new_versioned and text_status in [pysvn.wc_status_kind.added]
+            if text_status not in [pysvn.wc_status_kind.added]:
+                state.new_versioned = False
 
             prop_status = self.getPropStatus( row )
-            state.modified = state.modified and (text_status in [pysvn.wc_status_kind.modified,
-                                pysvn.wc_status_kind.conflicted]
-                        or
-                        prop_status in [pysvn.wc_status_kind.modified,
-                                pysvn.wc_status_kind.conflicted])
-            state.need_checkin = state.need_checkin and (text_status in [pysvn.wc_status_kind.added,
-                                    pysvn.wc_status_kind.deleted,
-                                    pysvn.wc_status_kind.replaced,
-                                    pysvn.wc_status_kind.modified]
-                            or
-                            prop_status in [pysvn.wc_status_kind.added,
-                                    pysvn.wc_status_kind.deleted,
-                                    pysvn.wc_status_kind.replaced,
-                                    pysvn.wc_status_kind.modified])
-            state.conflict = state.conflict and text_status in [pysvn.wc_status_kind.conflicted]
+            if( text_status not in [pysvn.wc_status_kind.modified
+                                   ,pysvn.wc_status_kind.conflicted]
+            and prop_status not in [pysvn.wc_status_kind.modified
+                                   ,pysvn.wc_status_kind.conflicted] ):
+                state.modified = False
+
+            if( text_status not in [pysvn.wc_status_kind.added
+                                   ,pysvn.wc_status_kind.deleted
+                                   ,pysvn.wc_status_kind.replaced
+                                   ,pysvn.wc_status_kind.modified]
+            and prop_status not in [pysvn.wc_status_kind.added
+                                   ,pysvn.wc_status_kind.deleted
+                                   ,pysvn.wc_status_kind.replaced
+                                   ,pysvn.wc_status_kind.modified] ):
+                state.need_checkin = False
+
+            if text_status not in [pysvn.wc_status_kind.conflicted]:
+                state.conflict = False
+
+            # revertable status calculation
+            text_reverable = (text_status in [pysvn.wc_status_kind.added
+                                             ,pysvn.wc_status_kind.deleted
+                                             ,pysvn.wc_status_kind.missing
+                                             ,pysvn.wc_status_kind.replaced
+                                             ,pysvn.wc_status_kind.modified
+                                             ,pysvn.wc_status_kind.conflicted])
+            prop_revertable = (prop_status in [pysvn.wc_status_kind.modified
+                                              ,pysvn.wc_status_kind.deleted
+                                              ,pysvn.wc_status_kind.replaced
+                                              ,pysvn.wc_status_kind.conflicted])
+
+            if not text_reverable and not prop_revertable:
+                state.revertable = False
 
         #state.printState( 'getState' )
 
@@ -659,9 +691,9 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
     #------------------------------------------------------------
     def Cmd_File_Annotate( self, all_rows ):
         for filename in [self.getFilename( row ) for row in all_rows]:
-            self.app.setProgress( 'Annotating %(count)d', 0 )
+            self.app.setProgress( T_('Annotating %(count)d'), 0 )
 
-            self.app.setAction( 'Annotate %s...' % filename )
+            self.app.setAction( T_('Annotate %s...') % filename )
 
             yield self.app.backgroundProcess
 
@@ -681,11 +713,11 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
             h_frame.Show( True )
 
         self.app.clearProgress()
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
     def Cmd_File_DiffWorkBase( self, all_rows ):
         for filename in [self.getFilename( row ) for row in all_rows]:
-            self.app.setAction( 'Diff BASE %s...' % filename )
+            self.app.setAction( T_('Diff BASE %s...') % filename )
 
             info1 = wb_subversion_diff.PathInfoForDiff()
 
@@ -714,13 +746,13 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
                     yield where_to_go_next
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
     def Cmd_File_DiffWorkHead( self, all_rows ):
         for filename, url in [(self.getFilename( row ), self.getUrl( row ))
                                 for row in all_rows]:
 
-            self.app.setAction( 'Diff HEAD %s...' % filename )
+            self.app.setAction( T_('Diff HEAD %s...') % filename )
 
             info1 = wb_subversion_diff.PathInfoForDiff()
 
@@ -750,17 +782,17 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
                     yield where_to_go_next
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
     def Cmd_File_DiffWorkBranchOriginBase( self, all_rows ):
-        self.app.setAction( "Retrieving branch info..." )
+        self.app.setAction( T_("Retrieving branch info...") )
 
         yield self.app.backgroundProcess
         branch_url = self.getBranchUrl()
         yield self.app.foregroundProcess
 
         if branch_url is None:
-            wx.MessageBox( '"%s" is not a branch.' % self.project_info.url, "Error", style=wx.OK|wx.ICON_ERROR )
+            wx.MessageBox( T_('"%s" is not a branch.') % self.project_info.url, T_("Error"), style=wx.OK|wx.ICON_ERROR )
         else:
             branch_origin_url = self.getBranchOriginUrl()
 
@@ -768,7 +800,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                                     for row in all_rows]:
                 origin_url = branch_origin_url + url[len(branch_url):]
 
-                self.app.setAction( 'Diff branch origin BASE %s...' % filename )
+                self.app.setAction( T_('Diff branch origin BASE %s...') % filename )
 
                 info1 = wb_subversion_diff.PathInfoForDiff()
 
@@ -798,16 +830,16 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
                         yield where_to_go_next
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
     def Cmd_File_DiffWorkBranchOriginHead( self, all_rows ):
-        self.app.setAction( "Retrieving branch info..." )
+        self.app.setAction( T_("Retrieving branch info...") )
         yield self.app.backgroundProcess
         branch_url = self.getBranchUrl()
         yield self.app.foregroundProcess
 
         if branch_url is None:
-            wx.MessageBox( '"%s" is not a branch.' % self.project_info.url, "Error", style=wx.OK|wx.ICON_ERROR )
+            wx.MessageBox( T_('"%s" is not a branch.') % self.project_info.url, T_("Error"), style=wx.OK|wx.ICON_ERROR )
         else:
             branch_origin_url = self.getBranchOriginUrl()
 
@@ -815,7 +847,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                                     for row in all_rows]:
                 origin_url = branch_origin_url + url[len(branch_url):]
 
-                self.app.setAction( 'Diff branch origin HEAD %s...' % filename )
+                self.app.setAction( T_('Diff branch origin HEAD %s...') % filename )
 
                 info1 = wb_subversion_diff.PathInfoForDiff()
 
@@ -845,7 +877,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
                         yield where_to_go_next
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
     def Cmd_File_History( self, all_rows ):
         dialog = wb_subversion_history.LogHistoryDialog( self.app, self.app.frame.tree_panel.tree_ctrl )
@@ -854,7 +886,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
             return
 
         for filename in [self.getFilename( row ) for row in all_rows]:
-            self.app.setAction( 'Log history %s...' % filename )
+            self.app.setAction( T_('Log history %s...') % filename )
 
             yield self.app.backgroundProcess
 
@@ -883,7 +915,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                         history_entries )
             h_frame.Show( True )
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
     def Cmd_File_Info( self, all_rows ):
         for filename in [self.getFilename( row ) for row in all_rows]:
@@ -904,14 +936,14 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
     def Cmd_File_Lock( self, all_rows ):
         all_filenames = [self.getFilename( row ) for row in all_rows]
-        comment, force = self.app.getLockMessage( 'Lock', self.getStatusAndFilenames( all_rows ) )
+        comment, force = self.app.getLockMessage( T_('Lock'), self.getStatusAndFilenames( all_rows ) )
         if not comment:
             return
 
         for filename in all_filenames:
-            self.app.setProgress( 'Locking %(count)d', 0 )
+            self.app.setProgress( T_('Locking %(count)d'), 0 )
 
-            self.app.setAction( 'Locking %s...' % filename )
+            self.app.setAction( T_('Locking %s...') % filename )
 
             yield self.app.backgroundProcess
 
@@ -928,7 +960,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                 break
 
         self.app.clearProgress()
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
     def Cmd_File_Properties( self, all_rows ):
@@ -967,14 +999,14 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
             self.app.refreshFrame()
 
     def Cmd_File_Unlock( self, all_rows ):
-        confirmed, force = self.app.confirmForceAction( 'Unlock', self.getStatusAndFilenames( all_rows ) )
+        confirmed, force = self.app.confirmForceAction( T_('Unlock'), self.getStatusAndFilenames( all_rows ) )
         if not confirmed:
             return
 
         for filename, url in [(self.getFilename( row ), self.getUrl( row )) for row in all_rows]:
-            self.app.setProgress( 'Unlocking %(count)d', 0 )
+            self.app.setProgress( T_('Unlocking %(count)d'), 0 )
 
-            self.app.setAction( 'Unlocking %s...' % filename )
+            self.app.setAction( T_('Unlocking %s...') % filename )
 
             yield self.app.backgroundProcess
 
@@ -994,7 +1026,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                 break
 
         self.app.clearProgress()
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
 class SortList:
