@@ -74,11 +74,13 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             # need one client/project/thread
             self.client_fg = pysvn.Client()
             self.client_fg.exception_style = 1
+            self.client_fg.commit_info_style = 1
             self.client_fg.callback_get_login = wb_exceptions.TryWrapper( self.app.log, self.app.getCredentials )
             self.client_fg.callback_ssl_server_trust_prompt = wb_exceptions.TryWrapper( self.app.log, self.getServerTrust )
 
             self.client_bg = pysvn.Client()
             self.client_bg.exception_style = 1
+            self.client_bg.commit_info_style = 1
             self.client_bg.callback_get_login = CallFunctionOnMainThread( self.app, self.app.getCredentials )
             self.client_bg.callback_ssl_server_trust_prompt = CallFunctionOnMainThread( self.app, self.getServerTrust )
 
@@ -149,7 +151,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             self.app.foregroundProcess( self.app.incProgress, () )
             return
 
-        if hasattr( pysvn.wc_notify_action, 'failed_lock' ):
+        if wb_subversion_utils.version_info.notify_action_has_failed_lock:
             if action in [pysvn.wc_notify_action.failed_lock,
                             pysvn.wc_notify_action.failed_unlock]:
                 self.app.log_client_error( ErrorWrapper( arg_dict['error'] ) )
@@ -239,11 +241,11 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         realm = trust_data['realm']
 
         info_list = []
-        info_list.append( ('Hostname', trust_data['hostname']) )
-        info_list.append( ('Valid From', trust_data['valid_from']) )
-        info_list.append( ('Valid Until', trust_data['valid_until']) )
-        info_list.append( ('Issuer Name', trust_data['issuer_dname']) )
-        info_list.append( ('Finger Print', trust_data['finger_print']) )
+        info_list.append( ( T_('Hostname'), trust_data['hostname']) )
+        info_list.append( ( T_('Valid From'), trust_data['valid_from']) )
+        info_list.append( ( T_('Valid Until'), trust_data['valid_until']) )
+        info_list.append( ( T_('Issuer Name'), trust_data['issuer_dname']) )
+        info_list.append( ( T_('Finger Print'), trust_data['finger_print']) )
 
         trust, save = self.app.getServerTrust( realm, info_list, True )
         return trust, trust_data['failures'], save
@@ -294,7 +296,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
 
         if self.need_properties:
             # see if the depth API is available
-            if hasattr( pysvn, 'depth' ):
+            if wb_subversion_utils.version_info.has_depth:
                 try:
                     if p.view_recursive:
                         path_properties = self.client_fg.proplist( self.wc_path, depth=pysvn.depth.infinity )
