@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -89,8 +89,8 @@ class SinglePropertyText(SingleProperty):
 
         text = self.value_ctrl.GetValue()
         if text.strip() == '':
-            wx.MessageBox( 'Enter a value for %s' % self.name,
-                'Warning', style=wx.OK|wx.ICON_EXCLAMATION )
+            wx.MessageBox( T_('Enter a value for %s') % self.name,
+                T_('Warning'), style=wx.OK|wx.ICON_EXCLAMATION )
             return False
         return True
 
@@ -110,8 +110,8 @@ class SinglePropertyMultiLine(SingleProperty):
 
         text = self.value_ctrl.GetValue()
         if text.strip() == '':
-            wx.MessageBox( 'Enter a value for %s' % self.name,
-                'Warning', style=wx.OK|wx.ICON_EXCLAMATION )
+            wx.MessageBox( T_('Enter a value for %s') % self.name,
+                T_('Warning'), style=wx.OK|wx.ICON_EXCLAMATION )
             return False
         return True
 
@@ -148,6 +148,7 @@ class PropertiesDialogBase(wx.Dialog):
         self.path = path
         self.prop_dict = prop_dict
         self.known_properties_names = []
+        self.ignore_properties_names = []
 
     def initDialog( self ):
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
@@ -161,7 +162,8 @@ class PropertiesDialogBase(wx.Dialog):
         keys.sort()
 
         for prop in keys:
-            if prop not in self.known_properties_names:
+            if( prop not in self.known_properties_names
+            and prop not in self.ignore_properties_names ):
                 self.property_ctrls[ prop ] = SinglePropertyText( self, prop, True, self.prop_dict[ prop ] )
 
         self.new_name_ctrl  = wx.TextCtrl( self, new_name_id, '', size=(100,-1) )
@@ -170,9 +172,9 @@ class PropertiesDialogBase(wx.Dialog):
         self.g_sizer.Add( self.new_name_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.new_value_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer_buttons = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_buttons.Add( (300, 20), 1, wx.EXPAND )
@@ -225,6 +227,7 @@ class FilePropertiesDialog(PropertiesDialogBase):
         self.known_properties_names = ['svn:eol-style', 'svn:executable',
                                         'svn:mime-type', 'svn:needs-lock',
                                         'svn:keywords', 'svn:special']
+        self.ignore_properties_names = ['svn:mergeinfo']
         self.initDialog()
 
     def initKnownProperties( self ):
@@ -254,6 +257,7 @@ class DirPropertiesDialog(PropertiesDialogBase):
     def __init__( self, app, parent, path, prop_dict ):
         PropertiesDialogBase.__init__( self, app, parent, path, prop_dict )
         self.known_properties_names = ['svn:ignore', 'svn:externals']
+        self.ignore_properties_names = ['svn:mergeinfo']
         self.initDialog()
 
     def initKnownProperties( self ):
