@@ -22,22 +22,22 @@ import wb_platform_specific
 
 class ReportBranchChangesFrame(wx.Frame):
     def __init__( self, app, project_info, all_files ):
-        wx.Frame.__init__( self, None, -1, "Branch changes report", size=(700,500) )
+        wx.Frame.__init__( self, None, -1, T_("Branch changes report"), size=(700,500) )
 
         self.app = app
 
         self.menu_actions = wx.Menu()
-        self.menu_actions.Append( wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...', 'Diff WC vs. HEAD...' )
-        self.menu_actions.Append( wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...', 'Diff WC vs. branch origin BASE...' )
-        self.menu_actions.Append( wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...', 'Diff WC vs. branch origin HEAD...' )
+        self.menu_actions.Append( wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...'), T_('Diff WC vs. HEAD...') )
+        self.menu_actions.Append( wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...'), T_('Diff WC vs. branch origin BASE...') )
+        self.menu_actions.Append( wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...'), T_('Diff WC vs. branch origin HEAD...') )
 
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Annotate, 'Annotate...', 'Annotate...' )
-        self.menu_actions.Append( wb_ids.id_SP_History, 'Log history...', 'Log history...' )
-        self.menu_actions.Append( wb_ids.id_SP_Info, 'Information...', 'Information...' )
+        self.menu_actions.Append( wb_ids.id_SP_Annotate, T_('Annotate...'), T_('Annotate...') )
+        self.menu_actions.Append( wb_ids.id_SP_History, T_('Log history...'), T_('Log history...') )
+        self.menu_actions.Append( wb_ids.id_SP_Info, T_('Information...'), T_('Information...') )
 
         self.menu_bar = wx.MenuBar()
-        self.menu_bar.Append( self.menu_actions, "&Actions" )
+        self.menu_bar.Append( self.menu_actions, T_("&Actions") )
 
         self.SetMenuBar( self.menu_bar )
 
@@ -49,13 +49,13 @@ class ReportBranchChangesFrame(wx.Frame):
         t.SetToolBitmapSize( bitmap_size )
         t.AddSimpleTool( wb_ids.id_SP_DiffWorkHead,
             wb_images.getBitmap( 'toolbar_images/diff.png', bitmap_size ),
-            'Diff changes against HEAD', 'Diff changes against HEAD' )
+            T_('Diff changes against HEAD'), T_('Diff changes against HEAD') )
         t.AddSimpleTool( wb_ids.id_SP_History,
             wb_images.getBitmap( 'toolbar_images/history.png', bitmap_size ),
-            'Show History log', 'Show History log' )
+            T_('Show History log'), T_('Show History log') )
         t.AddSimpleTool( wb_ids.id_SP_Info,
             wb_images.getBitmap( 'toolbar_images/info.png', bitmap_size ),
-            'File Information', 'File Information' )
+            T_('File Information'), T_('File Information') )
 
         try_wrapper = wb_exceptions.TryWrapperFactory( self.app.log )
 
@@ -144,7 +144,7 @@ class ReportBranchChangesListHandler(wb_subversion_list_handler_common.Subversio
         return file.get('branch_text_states', '') + text_code + prop_code
 
     def setupColumnInfo( self ):
-        self.column_info.setFrom( ['State','Name'], [5, 100] )
+        self.column_info.setFrom( [ T_('State'), T_('Name') ], [5, 100] )
 
     def statusColour( self, file ):
         # show that a file is on the exclude list
@@ -155,13 +155,13 @@ class ReportBranchChangesListHandler(wb_subversion_list_handler_common.Subversio
 
     def getContextMenu( self ):
         menu_template = \
-            [('', wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...' )
-            ,('', wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...' )
-            ,('', wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...' )
+            [('', wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...') )
+            ,('', wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...') )
+            ,('', wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...') )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_Annotate, 'Annotate...' )
-            ,('', wb_ids.id_SP_History, 'Log history...' )
-            ,('', wb_ids.id_SP_Info, 'Information...' )
+            ,('', wb_ids.id_SP_Annotate, T_('Annotate...') )
+            ,('', wb_ids.id_SP_History, T_('Log history...') )
+            ,('', wb_ids.id_SP_Info, T_('Information...') )
             ]
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_template )
 
