@@ -30,25 +30,25 @@ id_include = wx.NewId()
 
 class ReportUpdatesFrame(wx.Frame):
     def __init__( self, app, project_info, all_files ):
-        wx.Frame.__init__( self, None, -1, "Updates Report", size=(700,500) )
+        wx.Frame.__init__( self, None, -1, T_("Updates Report"), size=(700,500) )
 
         self.app = app
 
         self.menu_actions = wx.Menu()
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...', 'Diff WC vs. HEAD...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...', 'Diff WC vs. branch origin BASE...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...', 'Diff WC vs. branch origin HEAD...' )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...'), T_('Diff WC vs. HEAD...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...'), T_('Diff WC vs. branch origin BASE...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...'), T_('Diff WC vs. branch origin HEAD...') )
 
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Annotate, 'Annotate...', 'Annotate...' )
-        self.menu_actions.Append( wb_ids.id_SP_History, 'Log history...', 'Log history...' )
+        self.menu_actions.Append( wb_ids.id_SP_Annotate, T_('Annotate...'), T_('Annotate...') )
+        self.menu_actions.Append( wb_ids.id_SP_History, T_('Log history...'), T_('Log history...') )
 
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( id_exclude, 'Exclude...', 'Exclude from update' )
-        self.menu_actions.Append( id_include, 'Include...', 'Include in update' )
+        self.menu_actions.Append( id_exclude, T_('Exclude...'), T_('Exclude from update') )
+        self.menu_actions.Append( id_include, T_('Include...'), T_('Include in update') )
 
         self.menu_bar = wx.MenuBar()
-        self.menu_bar.Append( self.menu_actions, "&Actions" )
+        self.menu_bar.Append( self.menu_actions, T_("&Actions") )
 
         self.SetMenuBar( self.menu_bar )
 
@@ -60,17 +60,17 @@ class ReportUpdatesFrame(wx.Frame):
         t.SetToolBitmapSize( bitmap_size )
         t.AddSimpleTool( wb_ids.id_SP_DiffWorkHead,
             wb_images.getBitmap( 'toolbar_images/diff.png', bitmap_size ),
-            'Diff changes against HEAD', 'Diff changes against HEAD' )
+            T_('Diff changes against HEAD'), T_('Diff changes against HEAD') )
         t.AddSimpleTool( wb_ids.id_SP_History,
             wb_images.getBitmap( 'toolbar_images/history.png', bitmap_size ),
-            'Show History log', 'Show History log' )
+            T_('Show History log'), T_('Show History log') )
         t.AddSeparator()
         t.AddSimpleTool( id_exclude,
             wb_images.getBitmap( 'toolbar_images/exclude.png', bitmap_size ),
-            'Exclude from check in', 'Exclude from check in' )
+            T_('Exclude from check in'), T_('Exclude from check in') )
         t.AddSimpleTool( id_include,
             wb_images.getBitmap( 'toolbar_images/include.png', bitmap_size ),
-            'Include in check in', 'Include in check in' )
+            T_('Include in check in'), T_('Include in check in') )
         t.Realize()
 
         try_wrapper = wb_exceptions.TryWrapperFactory( self.app.log )
@@ -128,8 +128,8 @@ class ReportUpdatesFrame(wx.Frame):
         self.Hide()
 
         all_filenames = self.list_handler.getReportUpdatesFiles()
-        self.app.setAction( 'Update %s...' % self.project_info.wc_path )
-        self.app.setProgress( 'Updated %(count)d', 0 )
+        self.app.setAction( T_('Update %s...') % self.project_info.wc_path )
+        self.app.setProgress( T_('Updated %(count)d'), 0 )
 
         yield self.app.backgroundProcess
 
@@ -140,11 +140,15 @@ class ReportUpdatesFrame(wx.Frame):
                     if rev.number > 0:
                         count = self.app.getProgressValue( 'count' )
                         if count == 0:
-                            self.app.log.info( 'Updated %s to revision %d, no new updates' % (filename, rev.number) )
-                        elif count == 1:
-                            self.app.log.info( 'Updated %s to revision %d, 1 new update' % (filename, rev.number) )
+                            self.app.log.info( T_('Updated %(filename)s to revision %(rev)d, no new updates') %
+                                                {'filename': filename
+                                                ,'rev': rev.number} )
                         else:
-                            self.app.log.info( 'Updated %s to revision %d, %d new updates' % (filename, rev.number, count) )
+                            self.app.log.info( S_('Updated %(filename)s to revision %(rev)d, %(count)d new update', 
+                                                  'Updated %(filename)s to revision %(rev)d, %(count)d new updates', count) %
+                                                {'filename': filename
+                                                ,'rev': rev.number
+                                                ,'count': count} )
 
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
@@ -152,7 +156,7 @@ class ReportUpdatesFrame(wx.Frame):
         yield self.app.foregroundProcess
 
         self.app.clearProgress()
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
         self.Destroy()
@@ -198,7 +202,7 @@ class ReportUpdatesListHandler(wb_subversion_list_handler_common.SubversionListH
         return '%s%s' % (text_code, prop_code)
 
     def setupColumnInfo( self ):
-        self.column_info.setFrom( ['State','Name'], [5, 100] )
+        self.column_info.setFrom( [ T_('State'), T_('Name') ], [5, 100] )
 
     def statusColour( self, file ):
         # show that a file is on the exclude list
@@ -209,18 +213,18 @@ class ReportUpdatesListHandler(wb_subversion_list_handler_common.SubversionListH
 
     def getContextMenu( self ):
         menu_template = \
-            [('', wb_ids.id_File_Edit, 'Edit' )]
+            [('', wb_ids.id_File_Edit, T_('Edit') )]
         if wx.Platform in ['__WXMSW__','__WXMAC__']:
             menu_template += \
-                [('', wb_ids.id_Shell_Open, 'Open' )]
+                [('', wb_ids.id_Shell_Open, T_('Open') )]
         menu_template += \
             [('-', 0, 0 )
-            ,('', wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...' )
-            ,('', wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...' )
-            ,('', wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...' )
+            ,('', wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...') )
+            ,('', wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...') )
+            ,('', wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...') )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_Annotate, 'Annotate...' )
-            ,('', wb_ids.id_SP_History, 'Log history...' )
+            ,('', wb_ids.id_SP_Annotate, T_('Annotate...') )
+            ,('', wb_ids.id_SP_History, T_('Log history...') )
             ]
 
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_template )
@@ -279,8 +283,8 @@ class ReportUpdatesListPanel(wb_list_panel_common.WbListPanelCommon):
     def addToSizer( self, v_sizer ):
         self.h_sizer = wx.BoxSizer( wx.HORIZONTAL )
 
-        self.button_ok = wx.Button( self, wx.ID_OK, " Update " )
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, " Cancel " )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(" Update ") )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(" Cancel ") )
         self.button_ok.SetDefault()
 
         self.button_ok.Enable( True )
