@@ -128,6 +128,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             state.need_checkout = True
             state.conflict = False
             state.file_exists = False
+            state.revertable = False
 
         else:
             state.modified = True
@@ -165,47 +166,50 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                                                     pysvn.wc_status_kind.modified])
             state.conflict = text_status in [pysvn.wc_status_kind.conflicted]
 
+            state.revertable = state.conflict or state.modified or state.need_checkin or not state.file_exists
+
         return state
 
     def getContextMenu( self, state ):
-        menu_item =[('', wb_ids.id_Command_Shell, '&Command Shell')
-            ,('', wb_ids.id_File_Browser, '&File Browser')
+        menu_item =[('', wb_ids.id_Command_Shell, T_('&Command Shell') )
+            ,('', wb_ids.id_File_Browser, T_('&File Browser') )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_DiffWorkBase, 'Diff WC vs. BASE...' )
-            ,('', wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...' )
+            ,('', wb_ids.id_SP_DiffWorkBase, T_('Diff WC vs. BASE...') )
+            ,('', wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...') )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_History, 'Log history...' )
-            ,('', wb_ids.id_SP_Info, 'Information...' )
-            ,('', wb_ids.id_SP_Properties, 'Properties...' )
+            ,('', wb_ids.id_SP_History, T_('Log history...') )
+            ,('', wb_ids.id_SP_Info, T_('Information...') )
+            ,('', wb_ids.id_SP_Properties, T_('Properties...') )
             ,('-', 0, 0 )]
         if not state.file_exists and state.versioned and self.isProjectParent():
-            menu_item += [('', wb_ids.id_SP_Checkout, 'Checkout' )]
+            menu_item += [('', wb_ids.id_SP_Checkout, T_('Checkout') )]
+            menu_item += [('', wb_ids.id_SP_CheckoutTo, T_('Checkout to...') )]
         else:
-            menu_item += [('', wb_ids.id_SP_Update, 'Update' )]
-            menu_item += [('', wb_ids.id_SP_Update_To, 'Update to' )]
+            menu_item += [('', wb_ids.id_SP_Update, T_('Update') )]
+            menu_item += [('', wb_ids.id_SP_UpdateTo, T_('Update to..') )]
         menu_item += [('-', 0, '' )
-            ,('', wb_ids.id_SP_Checkin, 'Checkin...' )
+            ,('', wb_ids.id_SP_Checkin, T_('Checkin...') )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_NewFile, 'New File...' )
-            ,('', wb_ids.id_SP_Mkdir, 'Make directory...' )
-            ,('', wb_ids.id_SP_Add, 'Add...' )
-            ,('', wb_ids.id_SP_Rename, 'Rename...' )
+            ,('', wb_ids.id_SP_NewFile, T_('New File...') )
+            ,('', wb_ids.id_SP_Mkdir, T_('Make directory...') )
+            ,('', wb_ids.id_SP_Add, T_('Add...') )
+            ,('', wb_ids.id_SP_Rename, T_('Rename...') )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_Delete, 'Delete...' )
-            ,('', wb_ids.id_SP_Revert, 'Revert...' )
+            ,('', wb_ids.id_SP_Delete, T_('Delete...') )
+            ,('', wb_ids.id_SP_Revert, T_('Revert...') )
             ,('-', 0, 0 )
-            ,('', wb_ids.id_SP_Cleanup, 'Clean up' )
+            ,('', wb_ids.id_SP_Cleanup, T_('Clean up') )
             ]
 
         return wb_subversion_utils.populateMenu( wx.Menu(), menu_item )
 
     def Cmd_Dir_CreateBranch( self ):
         # must return the generator
-        return self.__copyToHelper( self.project_info.getBranchesUrl, wb_dialogs.CreateBranch, 'Creating branch %s' )
+        return self.__copyToHelper( self.project_info.getBranchesUrl, wb_dialogs.CreateBranch, T_('Creating branch %s') )
 
     def Cmd_Dir_CreateTag( self ):
         # must return the generator
-        return self.__copyToHelper( self.project_info.getTagsUrl, wb_dialogs.CreateTag, 'Creating tag %s' )
+        return self.__copyToHelper( self.project_info.getTagsUrl, wb_dialogs.CreateTag, T_('Creating tag %s') )
 
     def __getLogMessage( self ):
         return True, self.__log_message
@@ -216,12 +220,12 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         copy_from_url = info.URL
         copy_to_root_url = get_url_fn( copy_from_url )
 
-        dialog = dialog_class( self.app.frame.tree_panel.tree_ctrl, copy_from_url, copy_to_root_url )
+        dialog = dialog_class( self.app.frame.tree_panel.tree_ctrl, self.app, copy_from_url, copy_to_root_url )
         if dialog.ShowModal() != wx.ID_OK:
             return
 
         copy_to_leaf_url = dialog.getCopyToLeaf()
-        copy_to_url = '%s/%s' % (copy_to_root_url, copy_to_leaf_url)
+        copy_to_url = dialog.getCopyTo()
         self.__log_message = dialog.getLogMessage().encode( 'utf-8' )
 
         print status_title % copy_to_url
@@ -237,17 +241,17 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         self.project_info.client_bg.callback_get_log_message = None
         yield self.app.foregroundProcess
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
     def Cmd_Dir_EditCopy( self ):
         self.app.setPasteData( wb_clipboard.Clipboard( [self.project_info.wc_path], is_copy=True ) )
-        print 'Copied folder %s to the Clipboard' % self.project_info.wc_path
+        print T_('Copied folder %s to the Clipboard') % self.project_info.wc_path
         self.app.refreshFrame()
  
     def Cmd_Dir_EditCut( self ):
         self.app.setPasteData( wb_clipboard.Clipboard( [self.project_info.wc_path], is_copy=False ) )
-        print 'Cut folder %s to the Clipboard' % self.project_info.wc_path
+        print T_('Cut folder %s to the Clipboard') % self.project_info.wc_path
         self.app.refreshFrame()
 
     def Cmd_Dir_EditPaste( self ):
@@ -255,7 +259,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
     def Cmd_Dir_Add( self ):
         name = os.path.basename( self.project_info.wc_path )
-        force, recursive = self.app.addFolder( 'Add Folder', name, force=False, recursive=True )
+        force, recursive = self.app.addFolder( T_('Add Folder'), name, force=False, recursive=True )
         if force is None:
             return
 
@@ -268,25 +272,47 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         self.app.refreshFrame()
 
     def Cmd_Dir_Checkout( self ):
-        self.app.setAction( 'Checkout %s...' % self.project_info.url )
+        self.app.setAction( T_('Checkout %s...') % self.project_info.url )
 
         yield self.app.backgroundProcess
+        self.__checkoutToRevision( pysvn.Revision( pysvn.opt_revision_kind.head ), True, None )
+
+        yield self.app.foregroundProcess
+
+        self.app.setAction( T_('Ready') )
+        self.app.refreshFrame()
+
+    def Cmd_Dir_CheckoutTo( self ):
+        dialog = wb_dialogs.UpdateTo( None, T_('Checkout to revision') )
+        if dialog.ShowModal() == wx.ID_OK:
+            recursive, svndepth = dialog.getSvnDepth()
+            self.app.setAction( T_('Checkout %s...') % self.project_info.url )
+
+            yield self.app.backgroundProcess
+            self.__checkoutToRevision( dialog.getRevision(), recursive, svndepth )
+
+            yield self.app.foregroundProcess
+
+            self.app.setAction( T_('Ready') )
+            self.app.refreshFrame()
+
+    def __checkoutToRevision( self, rev, recursive, svndepth ):
         try:
             # lose any trailing / on the URL it stops checkout working
             url = self.project_info.url
             if url[-1] == '/':
                 url = url[:-1]
-            self.project_info.client_bg.checkout( url, self.project_info.wc_path, recurse=True )
+            if recursive:
+                self.project_info.client_bg.checkout( url, self.project_info.wc_path, recurse=True, revision=rev )
+
+            else:
+                self.project_info.client_bg.checkout( url, self.project_info.wc_path, depth=svndepth, revision=rev )
+
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
-        yield self.app.foregroundProcess
-
-        self.app.setAction( 'Ready' )
-        self.app.refreshFrame()
-
     def Cmd_Dir_Cleanup( self ):
-        self.app.setAction( 'Clean up %s...' % self.project_info.wc_path )
+        self.app.setAction( T_('Clean up %s...') % self.project_info.wc_path )
 
         yield self.app.backgroundProcess
         try:
@@ -296,13 +322,13 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
         yield self.app.foregroundProcess
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
     def Cmd_Dir_Checkin( self ):
         # get a status output to show the user
 
-        self.app.setAction( 'Look for changes to check in %s...' % self.project_info.wc_path )
+        self.app.setAction( T_('Look for changes to check in %s...') % self.project_info.wc_path )
 
         error = False
         yield self.app.backgroundProcess
@@ -319,14 +345,14 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             error = True
         yield self.app.foregroundProcess
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
         if error:
             return
 
         if len(all_files) == 0:
-            wx.MessageBox( "There are no changes to check in",
-                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+            wx.MessageBox( T_("There are no changes to check in"),
+                T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
             return
 
         ci_frame = wb_subversion_checkin.CheckinFrame( self.app, self.project_info, all_files )
@@ -345,7 +371,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         return output_lines
 
     def Cmd_Dir_Delete( self ):
-        confirmed, force = self.app.confirmForceAction( 'Delete Folder', [('', self.project_info.wc_path)] )
+        confirmed, force = self.app.confirmForceAction( T_('Delete Folder'), [('', self.project_info.wc_path)] )
         if confirmed:
             try:
                 self.project_info.client_fg.remove( self.project_info.wc_path, force=force )
@@ -356,7 +382,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
     def Cmd_Dir_DiffWorkBase( self ):
         filename = self.project_info.wc_path
 
-        self.app.setAction( 'Diff BASE %s...' % filename )
+        self.app.setAction( T_('Diff BASE %s...') % filename )
 
         info1 = wb_subversion_diff.PathInfoForDiff()
 
@@ -387,12 +413,12 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
                 yield where_to_go_next
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
     def Cmd_Dir_DiffWorkHead( self ):
         filename = self.project_info.wc_path
 
-        self.app.setAction( 'Diff HEAD %s...' % filename )
+        self.app.setAction( T_('Diff HEAD %s...') % filename )
 
 
         info1 = wb_subversion_diff.PathInfoForDiff()
@@ -422,7 +448,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
                 yield where_to_go_next
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
 
     def Cmd_Dir_History( self ):
@@ -433,7 +459,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         if result != wx.ID_OK:
             return
 
-        self.app.setAction( 'Log history %s...' % filename )
+        self.app.setAction( T_('Log history %s...') % filename )
 
         yield self.app.backgroundProcess
 
@@ -461,7 +487,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                 history_entries )
             h_frame.Show( True )
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
     def Cmd_Dir_Info( self ):
@@ -484,7 +510,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
 
 
     def Cmd_Dir_Mkdir( self ):
-        rc, name = self.app.getFilename( 'Make directory', 'Name:' )
+        rc, name = self.app.getFilename( T_('Make directory'), T_('Name:') )
         if not rc:
             return
 
@@ -516,8 +542,11 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                     t = file( template_filename, 'r' )
                     template_contents = t.read()
                     t.close()
+
                 except EnvironmentError, e:
-                    self.app.log.error( 'Cannot read template %s - %s' % (template_filename, str(e)) )
+                    self.app.log.error( T_('Cannot read template %(filename)s - %(error)s') %
+                                    {'filename': new_filename
+                                    , 'error': str(e)} )
                     return
 
             try:
@@ -525,8 +554,11 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
                 f = file( new_filename, 'w' )
                 f.write( template_contents )
                 f.close()
+
             except EnvironmentError, e:
-                self.app.log.error( 'Cannot create new file %s - %s' % (new_filename, str(e)) )
+                self.app.log.error( T_('Cannot create new file %(filename)s - %(error)s') %
+                                    {'filename': new_filename
+                                    , 'error': str(e)} )
                 return
 
             try:
@@ -575,9 +607,9 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
     def __reportLocksCommon( self, show_repos_locks ):
 
         if show_repos_locks:
-            self.app.setAction( 'Looking for repository locks in %s...' % self.project_info.wc_path )
+            self.app.setAction( T_('Looking for repository locks in %s...') % self.project_info.wc_path )
         else:
-            self.app.setAction( 'Looking for working copy locks in %s...' % self.project_info.wc_path )
+            self.app.setAction( T_('Looking for working copy locks in %s...') % self.project_info.wc_path )
 
         ok = True
         yield self.app.backgroundProcess
@@ -594,18 +626,18 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             ok = False
         yield self.app.foregroundProcess
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
         if not ok:
             return
 
         if len(all_files) == 0:
             if show_repos_locks:
-                wx.MessageBox( "There are no locked files in the repository",
-                    "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+                wx.MessageBox( T_("There are no locked files in the repository"),
+                    T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
             else:
-                wx.MessageBox( "There are no locked files in the working copy",
-                    "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+                wx.MessageBox( T_("There are no locked files in the working copy"),
+                    T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
             return
 
         ci_frame = wb_subversion_report_lock.ReportLockFrame(
@@ -614,7 +646,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         ci_frame.Show( True )
 
     def Cmd_Dir_ReportUpdates( self ):
-        self.app.setAction( 'Updates %s...' % self.project_info.url )
+        self.app.setAction( T_('Updates %s...') % self.project_info.url )
 
         ok = False
         all_files = []
@@ -633,11 +665,11 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         yield self.app.foregroundProcess
 
         if len(all_files) == 0:
-            wx.MessageBox( "All files are up todate",
-                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+            wx.MessageBox( T_("All files are up todate"),
+                T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
             return
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
         if ok:
             all_files = [status for status in all_files
@@ -649,7 +681,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             ci_frame.Show( True )
 
     def Cmd_Dir_ReportBranchChanges( self ):
-        self.app.setAction( 'Branch changes %s...' % self.project_info.url )
+        self.app.setAction( T_('Branch changes %s...') % self.project_info.url )
 
         changed_files = []
         is_branch = False
@@ -737,21 +769,21 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         yield self.app.foregroundProcess
 
         if not is_branch:
-            wx.MessageBox( '"%s" is not a branch.' % self.project_info.url, "Error", style=wx.OK|wx.ICON_ERROR )
+            wx.MessageBox( T_('"%s" is not a branch.') % self.project_info.url, T_("Error"), style=wx.OK|wx.ICON_ERROR )
         elif len( changed_files ) == 0:
-            wx.MessageBox( 'No files changed yet in branch "%s".' % self.project_info.url, "Error", style=wx.OK|wx.ICON_ERROR )
+            wx.MessageBox( T_('No files changed yet in branch "%s".') % self.project_info.url, T_("Error"), style=wx.OK|wx.ICON_ERROR )
         else:
             ci_frame = wb_subversion_report_branch_changes.ReportBranchChangesFrame( self.app, self.project_info, changed_files )
             ci_frame.Show( True )
 
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
 
 
     def Cmd_Dir_Rename( self ):
         old_filename = self.project_info.wc_path
         old_name = os.path.basename( old_filename )
 
-        new_name, force = self.app.renameFile( "Rename Directory", old_name, False )
+        new_name, force = self.app.renameFile( T_("Rename Directory"), old_name, False )
 
         if new_name is None:
             return
@@ -759,7 +791,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         if new_name != old_name:
             new_full_filename = os.path.join( os.path.dirname( old_filename ), new_name )
             dir_status = self.project_info.getDirStatus()
-            print 'Rename',old_filename, new_full_filename
+            print T_('Rename'), old_filename, new_full_filename
             if dir_status is None or dir_status.text_status not in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
                 try:
                     self.project_info.client_fg.move( old_filename, new_full_filename, force=force )
@@ -779,12 +811,12 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         all_files = self.project_info.client_fg.status( self.project_info.wc_path, recurse=True, get_all=False, ignore=True, update=False )
         status_output = self.__cmd_status_output( all_files )
         if len(status_output) == 0:
-            wx.MessageBox( "There are no changes to revert",
-                "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+            wx.MessageBox( T_("There are no changes to revert"),
+                T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
             return
 
 
-        if self.app.confirmAction( 'Revert', status_output ):
+        if self.app.confirmAction( T_('Revert'), status_output ):
             try:
                 self.project_info.client_fg.revert( self.project_info.wc_path, recurse=True )
             except pysvn.ClientError, e:
@@ -792,87 +824,83 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             self.app.refreshFrame()
 
     def Cmd_Dir_Update( self ):
-        self.app.setAction( 'Update %s...' % self.project_info.wc_path )
-        self.app.setProgress( 'Updated %(count)d', 0 )
+        self.app.setAction( T_('Update %s...') % self.project_info.wc_path )
+        self.app.setProgress( T_('Updated %(count)d'), 0 )
 
         yield self.app.backgroundProcess
+        rev_list = self.__updateToRevision( pysvn.Revision( pysvn.opt_revision_kind.head ), True, None )
 
+        yield self.app.foregroundProcess
+        self.__updateToRevisionProcessResults( rev_list )
+
+    def Cmd_Dir_UpdateTo( self ):
+        dialog = wb_dialogs.UpdateTo( None, T_('Update to revision') )
+        if dialog.ShowModal() != wx.ID_OK:
+            return
+
+        recursive, svndepth = dialog.getSvnDepth()
+
+        self.app.setAction( T_('Update %s...') % self.project_info.wc_path )
+        self.app.setProgress( T_('Updated %(count)d'), 0 )
+
+        yield self.app.backgroundProcess
+        rev_list = self.__updateToRevision( dialog.getRevision(), recursive, svndepth )
+
+        yield self.app.foregroundProcess
+        self.__updateToRevisionProcessResults( rev_list )
+
+    def __updateToRevision( self, rev, recursive, svndepth ):
         filename = self.project_info.wc_path
-        ok = False
         try:
             self.project_info.initNotify()
-            rev_list = self.project_info.client_bg.update( filename, recurse=True )
-            ok = True
+
+            if recursive:
+                rev_list = self.project_info.client_bg.update( filename, recurse=True, revision=rev )
+            else:
+                rev_list = self.project_info.client_bg.update( filename, depth=svndepth, revision=rev )
+
+            return rev_list
+
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
-        yield self.app.foregroundProcess
-
-        if ok:
+            return None
+        
+    def __updateToRevisionProcessResults( self, rev_list ):
+        filename = self.project_info.wc_path
+        if rev_list is not None:
             for rev in rev_list:
                 if rev.number > 0:
                     count = self.app.getProgressValue( 'count' )
                     if count == 0:
-                        self.app.log.info( 'Updated %s to revision %d, no new updates' % (filename, rev.number) )
-                    elif count == 1:
-                        self.app.log.info( 'Updated %s to revision %d, 1 new update' % (filename, rev.number) )
+                        self.app.log.info( T_('Updated %(filename)s to revision %(rev)d, no new updates') %
+                                                {'filename': filename
+                                                ,'rev': rev.number} )
                     else:
-                        self.app.log.info( 'Updated %s to revision %d, %d new updates' % (filename, rev.number, count) )
+                        self.app.log.info( S_('Updated %(filename)s to revision %(rev)d, %(count)d new update', 
+                                              'Updated %(filename)s to revision %(rev)d, %(count)d new updates', count) %
+                                              {'filename': filename
+                                              ,'rev': rev.number
+                                              ,'count': count} )
                 else:
-                    self.app.log.warning( 'Already up to date' )
+                    self.app.log.warning( T_('Already up to date') )
 
-
-            if self.project_info.notification_of_files_in_conflict == 1:
-                wx.MessageBox( "%d file is in conflict" % self.project_info.notification_of_files_in_conflict,
-                    "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
-            elif self.project_info.notification_of_files_in_conflict > 1:
-                wx.MessageBox( "%d files are in conflict" % self.project_info.notification_of_files_in_conflict,
-                    "Warning", style=wx.OK|wx.ICON_EXCLAMATION )
+            if self.project_info.notification_of_files_in_conflict > 0:
+                wx.MessageBox( S_("%d file is in conflict", 
+                                  "%d files are in conflict", self.project_info.notification_of_files_in_conflict) % self.project_info.notification_of_files_in_conflict,
+                               T_("Warning"), style=wx.OK|wx.ICON_EXCLAMATION )
 
         self.app.clearProgress()
-        self.app.setAction( 'Ready' )
+        self.app.setAction( T_('Ready') )
         self.app.refreshFrame()
 
-    def Cmd_Dir_Update_To( self ):
-        dialog = wb_dialogs.UpdateTo( None )
-        if dialog.ShowModal() == wx.ID_OK:
-            self.app.setAction( 'Update %s...' % self.project_info.wc_path )
-            self.app.setProgress( 'Updated %(count)d', 0 )
-
-            yield self.app.backgroundProcess
-
-            filename = self.project_info.wc_path
-            ok = False
-            try:
-                rev_list = self.project_info.client_bg.update( filename, True, dialog.getRevision() )
-                ok = True
-            except pysvn.ClientError, e:
-                self.app.log_client_error( e )
-
-            yield self.app.foregroundProcess
-
-            if ok:
-                for rev in rev_list:
-                    if rev.number > 0:
-                        count = self.app.getProgressValue( 'count' )
-                        if count == 0:
-                            self.app.log.info( 'Updated %s to revision %d, no new updates' % (filename, rev.number) )
-                        elif count == 1:
-                            self.app.log.info( 'Updated %s to revision %d, 1 new update' % (filename, rev.number) )
-                        else:
-                            self.app.log.info( 'Updated %s to revision %d, %d new updates' % (filename, rev.number, count) )
-                    else:
-                        self.app.log.warning( 'Already up to date' )
-
-            self.app.clearProgress()
-            self.app.setAction( 'Ready' )
-            self.app.refreshFrame()
-
     def Cmd_Dir_Copy( self, all_filenames ):
         try:
             for src_filename in all_filenames:
                 self.project_info.client_fg.copy( src_filename, self.project_info.wc_path )
-                self.app.log.info( 'Copied %s to %s' % (src_filename, self.project_info.wc_path) )
+                self.app.log.info( T_('Copied %(from)s to %(to)s') %
+                                        {'from': src_filename
+                                        ,'to': self.project_info.wc_path} )
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
@@ -882,7 +910,9 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         try:
             for src_filename in all_filenames:
                 self.project_info.client_fg.move( src_filename, self.project_info.wc_path )
-                self.app.log.info( 'Moved %s to %s' % (src_filename, self.project_info.wc_path) )
+                self.app.log.info( T_('Moved %(from)s to %(to)s') %
+                                        {'from': src_filename
+                                        ,'to': self.project_info.wc_path} )
         except pysvn.ClientError, e:
             self.app.log_client_error( e )
 
