@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2009 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -12,11 +12,28 @@
 '''
 import pysvn
 import time
+import types
+import locale
 import wx
 import wb_exceptions
 
+class svn_version_info:
+    #
+    # Keep infos about the features of the available pysvn version
+    #
+    def __init__(self):
+        self.notify_action_has_failed_lock = hasattr( pysvn.wc_notify_action, 'failed_lock' )
+        self.has_depth = hasattr( pysvn, 'depth' )
+        self.notify_action_has_property_events = hasattr( pysvn.wc_notify_action, 'property_added' )
+
+version_info = svn_version_info()
+
 def fmtDateTime( val ):
-    return time.strftime( '%d-%b-%Y %H:%M:%S', time.localtime( val ) )
+    encoding = locale.getlocale()[1]
+    if type( val ) == types.FloatType:
+        val = time.localtime( val )
+
+    return time.strftime( '%d-%b-%Y %H:%M:%S', val ).decode( encoding )
 
 wc_status_kind_map = {
 pysvn.wc_status_kind.missing:       '?',
@@ -116,12 +133,23 @@ wc_notify_action_map = {
     pysvn.wc_notify_action.annotate_revision: 'a',
     }
 
-if hasattr( pysvn.wc_notify_action, 'failed_lock' ):
+if version_info.notify_action_has_failed_lock:
     wc_notify_action_map[ pysvn.wc_notify_action.failed_lock ] = 'lock failed'
     wc_notify_action_map[ pysvn.wc_notify_action.failed_unlock ] = 'unlock failed'
     wc_notify_action_map[ pysvn.wc_notify_action.locked ] = 'Locked'
     wc_notify_action_map[ pysvn.wc_notify_action.unlocked ] = 'Unlocked'
 
+if version_info.notify_action_has_property_events:
+    wc_notify_action_map[ pysvn.wc_notify_action.property_added ] = '_A'
+    wc_notify_action_map[ pysvn.wc_notify_action.property_modified ] = '_M'
+    wc_notify_action_map[ pysvn.wc_notify_action.property_deleted ] = '_D'
+    wc_notify_action_map[ pysvn.wc_notify_action.property_deleted_nonexistent ] = 'property_deleted_nonexistent'
+    wc_notify_action_map[ pysvn.wc_notify_action.revprop_set ] = 'revprop_set'
+    wc_notify_action_map[ pysvn.wc_notify_action.revprop_deleted ] = 'revprop_deleted'
+    wc_notify_action_map[ pysvn.wc_notify_action.merge_completed ] = 'merge_completed'
+    wc_notify_action_map[ pysvn.wc_notify_action.tree_conflict ] = 'tree_conflict'
+    wc_notify_action_map[ pysvn.wc_notify_action.failed_external ] = 'failed_external'
+
 wc_notify_type_map = {
     pysvn.wc_notify_action.add: 'A',
     pysvn.wc_notify_action.commit_added: 'C',
@@ -146,11 +174,23 @@ wc_notify_type_map = {
     pysvn.wc_notify_action.annotate_revision: 'A',
     }
 
-if hasattr( pysvn.wc_notify_action, 'failed_lock' ):
-    wc_notify_type_map[ pysvn.wc_notify_action.failed_lock ] = 'lock failed'
-    wc_notify_type_map[ pysvn.wc_notify_action.failed_unlock ] = 'unlock failed'
-    wc_notify_type_map[ pysvn.wc_notify_action.locked ] = 'Locked'
-    wc_notify_type_map[ pysvn.wc_notify_action.unlocked ] = 'Unlocked'
+if version_info.notify_action_has_failed_lock:
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_lock ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_unlock ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.locked ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.unlocked ] = None
+
+if version_info.notify_action_has_property_events:
+    wc_notify_type_map[ pysvn.wc_notify_action.property_added ] = 'A'
+    wc_notify_type_map[ pysvn.wc_notify_action.property_modified ] = 'M'
+    wc_notify_type_map[ pysvn.wc_notify_action.property_deleted ] = 'D'
+    wc_notify_type_map[ pysvn.wc_notify_action.property_deleted_nonexistent ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.revprop_set ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.revprop_deleted ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.merge_completed ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.tree_conflict ] = None
+    wc_notify_type_map[ pysvn.wc_notify_action.failed_external ] = None
+
 
 #
 #    format the concise status from file
