@@ -39,6 +39,7 @@ class TreeState:
         self.file_exists = False
         self.is_folder = True
         self.is_project_parent = False
+        self.revertable = False
 
     def printState( self, title='' ):
         print '--------', title
@@ -85,7 +86,7 @@ class WbTreePanel(wx.Panel):
                 (wx.ACCEL_CMD, ord('I'), wb_ids.id_SP_Info),
                 (wx.ACCEL_CMD, ord('P'), wb_ids.id_SP_Properties),
                 (wx.ACCEL_CMD, ord('R'), wb_ids.id_SP_Revert),
-                (wx.ACCEL_CMD, ord('T'), wb_ids.id_SP_Update_To),
+                (wx.ACCEL_CMD, ord('T'), wb_ids.id_SP_UpdateTo),
                 (wx.ACCEL_CMD, ord('U'), wb_ids.id_SP_Update),
                 (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
                 (wx.ACCEL_CMD, ord('O'), wb_ids.id_Shell_Open),
@@ -240,7 +241,7 @@ class WbTreePanel(wx.Panel):
     def initTree( self, project_info_list ):
         self.__skip_update_ui = True
 
-        self.root_item = self.tree_ctrl.AddRoot("Projects:")
+        self.root_item = self.tree_ctrl.AddRoot( T_("Projects:") )
         self.tree_ctrl.SetPyData( self.root_item, RootTreeItem() )
         first_item = None
         for project_info in project_info_list:
@@ -346,7 +347,7 @@ class WbTreePanel(wx.Panel):
             if tree_pi.isChild( pi ):
                 # drill deeper
                 self.tree_ctrl.Expand( child_item )
-                # child bcomes parent at next level
+                # child becomes parent at next level
                 parent_item = child_item
                 child_item, cookie = self.tree_ctrl.GetFirstChild( parent_item )
             else:
@@ -402,7 +403,7 @@ class WbTreePanel(wx.Panel):
 
         p = self.app.prefs.getView()
         if p.view_recursive:
-            busy = wx.BusyInfo("Refreshing view...", self.frame)
+            busy = wx.BusyInfo( T_("Refreshing view..."), self.frame )
         tree_pi.updateStatus()
         self.updateTreeItem( item )
 
@@ -467,8 +468,7 @@ class WbTreePanel(wx.Panel):
 
         p = self.app.prefs.getView()
         if p.view_recursive:
-            busy = wx.BusyInfo("Refreshing view...", self.frame)
-
+            busy = wx.BusyInfo( T_("Refreshing view..."), self.frame )
         if pi is None:
             self.list_panel.clearHandler()
         else:
@@ -571,8 +571,8 @@ class WbTreePanel(wx.Panel):
         menu = handler.getContextMenu( self.frame.ui_state_tree )
         if handler.isProjectParent():
             menu.AppendSeparator()
-            menu.Append( wb_ids.id_Project_Update, 'Project Settings' )
-            menu.Append( wb_ids.id_Project_Delete, 'Delete Project' )
+            menu.Append( wb_ids.id_Project_Update, T_('Project Settings') )
+            menu.Append( wb_ids.id_Project_Delete, T_('Delete Project') )
 
         self.tree_ctrl.PopupMenu( menu, point )
         menu.Destroy()
@@ -613,7 +613,7 @@ class WbTreePanel(wx.Panel):
         if not tree_pi:
             return
 
-        dialog = wb_dialogs.ConfirmAction( self, 'Delete Project',
+        dialog = wb_dialogs.ConfirmAction( self, T_('Delete Project'),
                 [('', tree_pi.project_name)] )
 
         rc = dialog.ShowModal()
@@ -717,6 +717,9 @@ class WbTreePanel(wx.Panel):
     def OnSpCheckout( self ):
         return self.Sp_Dispatch( 'Cmd_Dir_Checkout' )
 
+    def OnSpCheckoutTo( self ):
+        return self.Sp_Dispatch( 'Cmd_Dir_CheckoutTo' )
+
     def OnSpDelete( self ):
         return self.Sp_Dispatch( 'Cmd_Dir_Delete' )
 
@@ -763,7 +766,7 @@ class WbTreePanel(wx.Panel):
         return self.Sp_Dispatch( 'Cmd_Dir_Update' )
 
     def OnSpUpdateTo( self ):
-        return self.Sp_Dispatch( 'Cmd_Dir_Update_To' )
+        return self.Sp_Dispatch( 'Cmd_Dir_UpdateTo' )
 
     #----------------------------------------
     def OnSpCopy( self, filename_list ):
@@ -991,7 +994,7 @@ class RootTreeItem(TreeProjectItem):
     def getContextMenu( self, state ):
         menu = wx.Menu()
 
-        menu.Append( wb_ids.id_Project_Add, '&Add Project' )
+        menu.Append( wb_ids.id_Project_Add, T_('&Add Project') )
 
         return menu
 
